
    (*********************************************************************
     *  FastFourierDJB.pas                                               *
     *                                                                   *
     *  author    : Milenko Mitrovic                                     *
     *  email     : dcoder@dsp-worx.de                                   *
     *  web       : http://dsp-worx.de                                   *
     *  date      : 24-07-2003                                           *
     *                                                                   *
     *  Based on D.J.Bernsteins Split Radix FFT v0.76.                  *
     *  http://cr.yp.to/djbfft.html                                      *
     *                                                                   *
     *  The contents of this file are used with permission, subject to   *
     *  the Mozilla Public License Version 1.1 (the "License"); you may  *
     *  not use this file except in compliance with the License. You may *
     *  obtain a copy of the License at                                  *
     *  http://www.mozilla.org/MPL/MPL-1.1.html                          *
     *                                                                   *
     *  Software distributed under the License is distributed on an      *
     *  "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or   *
     *  implied. See the License for the specific language governing     *
     *  rights and limitations under the License.                        *
     *                                                                   *
     *  (C) 2003, 2004 Milenko Mitrovic <dcoder@dsp-worx.de>             *
     *                                                                   *
     *********************************************************************)

// This will setup the FFT to use Single, Double or Extended Precision.

{$DEFINE SINGLE_PRECISION}
{.$DEFINE DOUBLE_PRECISION}
{.$DEFINE EXTENDED_PRECISION}

// when defined, the FFT will calculate the Reverse Bits Table, this saves some
// Space, but will make the Application load a bit slower. when undefined, the
// FFT will use the precalculated Reverse Bits Table.

{.$DEFINE CALC_REVBITS_TABLE}

// same as CALC_REVBITS_TABLE, but for the Sine/Cosine Table.

{.$DEFINE CALC_SINCOS_TABLE}

unit FastFourierDJB;

interface

uses Math;

type
  {$IFDEF SINGLE_PRECISION}
    Float = Single;
  {$ENDIF}
  {$IFDEF DOUBLE_PRECISION}
    Float = Double;
  {$ENDIF}
  {$IFDEF EXTENDED_PRECISION}
    Float = Extended;
  {$ENDIF}
  PComplex = ^TComplex;
  TComplex = record
    re,
    im: Float;
  end;
  PWORDArray = ^TWORDArray;
  TWORDArray = array[0..8191] of WORD;
  PComplexArray = ^TComplexArray;
  TComplexArray = array[0..8191] of TComplex;

  {$IFDEF CALC_REVBITS_TABLE}
var
  RevBits2: array[0..1] of WORD;
  RevBits4: array[0..3] of WORD;
  RevBits8: array[0..7] of WORD;
  RevBits16: array[0..15] of WORD;
  RevBits32: array[0..31] of WORD;
  RevBits64: array[0..63] of WORD;
  RevBits128: array[0..127] of WORD;
  RevBits256: array[0..255] of WORD;
  RevBits512: array[0..511] of WORD;
  RevBits1024: array[0..1023] of WORD;
  RevBits2048: array[0..2047] of WORD;
  RevBits4096: array[0..4095] of WORD;
  RevBits8192: array[0..8191] of WORD;
  {$ELSE}
const
  RevBits2: array[0..1] of WORD = (
        0,     1
  );
  RevBits4: array[0..3] of WORD = (
        0,     2,     1,     3
  );
  RevBits8: array[0..7] of WORD = (
        0,     4,     2,     7,     1,     5,     3,     6
  );
  RevBits16: array[0..15] of WORD = (
        0,     8,     4,    14,     2,    10,     7,    13,     1,     9,
        5,    15,     3,    11,     6,    12
  );
  RevBits32: array[0..31] of WORD = (
        0,    16,     8,    28,     4,    20,    14,    26,     2,    18,
       10,    31,     7,    23,    13,    25,     1,    17,     9,    29,
        5,    21,    15,    27,     3,    19,    11,    30,     6,    22,
       12,    24
  );
  RevBits64: array[0..63] of WORD = (
        0,    32,    16,    56,     8,    40,    28,    52,     4,    36,
       20,    62,    14,    46,    26,    50,     2,    34,    18,    58, 
       10,    42,    31,    55,     7,    39,    23,    61,    13,    45, 
       25,    49,     1,    33,    17,    57,     9,    41,    29,    53, 
        5,    37,    21,    63,    15,    47,    27,    51,     3,    35, 
       19,    59,    11,    43,    30,    54,     6,    38,    22,    60, 
       12,    44,    24,    48
  );
  RevBits128: array[0..127] of WORD = (
        0,    64,    32,   112,    16,    80,    56,   104,     8,    72, 
       40,   124,    28,    92,    52,   100,     4,    68,    36,   116, 
       20,    84,    62,   110,    14,    78,    46,   122,    26,    90, 
       50,    98,     2,    66,    34,   114,    18,    82,    58,   106, 
       10,    74,    42,   127,    31,    95,    55,   103,     7,    71, 
       39,   119,    23,    87,    61,   109,    13,    77,    45,   121, 
       25,    89,    49,    97,     1,    65,    33,   113,    17,    81, 
       57,   105,     9,    73,    41,   125,    29,    93,    53,   101, 
        5,    69,    37,   117,    21,    85,    63,   111,    15,    79, 
       47,   123,    27,    91,    51,    99,     3,    67,    35,   115, 
       19,    83,    59,   107,    11,    75,    43,   126,    30,    94, 
       54,   102,     6,    70,    38,   118,    22,    86,    60,   108, 
       12,    76,    44,   120,    24,    88,    48,    96
  );
  RevBits256: array[0..255] of WORD = (
        0,   128,    64,   224,    32,   160,   112,   208,    16,   144, 
       80,   248,    56,   184,   104,   200,     8,   136,    72,   232, 
       40,   168,   124,   220,    28,   156,    92,   244,    52,   180, 
      100,   196,     4,   132,    68,   228,    36,   164,   116,   212, 
       20,   148,    84,   254,    62,   190,   110,   206,    14,   142, 
       78,   238,    46,   174,   122,   218,    26,   154,    90,   242, 
       50,   178,    98,   194,     2,   130,    66,   226,    34,   162, 
      114,   210,    18,   146,    82,   250,    58,   186,   106,   202, 
       10,   138,    74,   234,    42,   170,   127,   223,    31,   159, 
       95,   247,    55,   183,   103,   199,     7,   135,    71,   231, 
       39,   167,   119,   215,    23,   151,    87,   253,    61,   189, 
      109,   205,    13,   141,    77,   237,    45,   173,   121,   217, 
       25,   153,    89,   241,    49,   177,    97,   193,     1,   129,
       65,   225,    33,   161,   113,   209,    17,   145,    81,   249, 
       57,   185,   105,   201,     9,   137,    73,   233,    41,   169, 
      125,   221,    29,   157,    93,   245,    53,   181,   101,   197, 
        5,   133,    69,   229,    37,   165,   117,   213,    21,   149, 
       85,   255,    63,   191,   111,   207,    15,   143,    79,   239, 
       47,   175,   123,   219,    27,   155,    91,   243,    51,   179, 
       99,   195,     3,   131,    67,   227,    35,   163,   115,   211, 
       19,   147,    83,   251,    59,   187,   107,   203,    11,   139, 
       75,   235,    43,   171,   126,   222,    30,   158,    94,   246, 
       54,   182,   102,   198,     6,   134,    70,   230,    38,   166, 
      118,   214,    22,   150,    86,   252,    60,   188,   108,   204, 
       12,   140,    76,   236,    44,   172,   120,   216,    24,   152, 
       88,   240,    48,   176,    96,   192
  );
  RevBits512: array[0..511] of WORD = (
        0,   256,   128,   448,    64,   320,   224,   416,    32,   288, 
      160,   496,   112,   368,   208,   400,    16,   272,   144,   464, 
       80,   336,   248,   440,    56,   312,   184,   488,   104,   360, 
      200,   392,     8,   264,   136,   456,    72,   328,   232,   424, 
       40,   296,   168,   508,   124,   380,   220,   412,    28,   284, 
      156,   476,    92,   348,   244,   436,    52,   308,   180,   484, 
      100,   356,   196,   388,     4,   260,   132,   452,    68,   324, 
      228,   420,    36,   292,   164,   500,   116,   372,   212,   404, 
       20,   276,   148,   468,    84,   340,   254,   446,    62,   318, 
      190,   494,   110,   366,   206,   398,    14,   270,   142,   462, 
       78,   334,   238,   430,    46,   302,   174,   506,   122,   378, 
      218,   410,    26,   282,   154,   474,    90,   346,   242,   434, 
       50,   306,   178,   482,    98,   354,   194,   386,     2,   258, 
      130,   450,    66,   322,   226,   418,    34,   290,   162,   498, 
      114,   370,   210,   402,    18,   274,   146,   466,    82,   338, 
      250,   442,    58,   314,   186,   490,   106,   362,   202,   394, 
       10,   266,   138,   458,    74,   330,   234,   426,    42,   298, 
      170,   511,   127,   383,   223,   415,    31,   287,   159,   479, 
       95,   351,   247,   439,    55,   311,   183,   487,   103,   359, 
      199,   391,     7,   263,   135,   455,    71,   327,   231,   423, 
       39,   295,   167,   503,   119,   375,   215,   407,    23,   279,
      151,   471,    87,   343,   253,   445,    61,   317,   189,   493, 
      109,   365,   205,   397,    13,   269,   141,   461,    77,   333, 
      237,   429,    45,   301,   173,   505,   121,   377,   217,   409, 
       25,   281,   153,   473,    89,   345,   241,   433,    49,   305, 
      177,   481,    97,   353,   193,   385,     1,   257,   129,   449, 
       65,   321,   225,   417,    33,   289,   161,   497,   113,   369, 
      209,   401,    17,   273,   145,   465,    81,   337,   249,   441, 
       57,   313,   185,   489,   105,   361,   201,   393,     9,   265, 
      137,   457,    73,   329,   233,   425,    41,   297,   169,   509, 
      125,   381,   221,   413,    29,   285,   157,   477,    93,   349, 
      245,   437,    53,   309,   181,   485,   101,   357,   197,   389, 
        5,   261,   133,   453,    69,   325,   229,   421,    37,   293, 
      165,   501,   117,   373,   213,   405,    21,   277,   149,   469, 
       85,   341,   255,   447,    63,   319,   191,   495,   111,   367, 
      207,   399,    15,   271,   143,   463,    79,   335,   239,   431, 
       47,   303,   175,   507,   123,   379,   219,   411,    27,   283, 
      155,   475,    91,   347,   243,   435,    51,   307,   179,   483, 
       99,   355,   195,   387,     3,   259,   131,   451,    67,   323, 
      227,   419,    35,   291,   163,   499,   115,   371,   211,   403, 
       19,   275,   147,   467,    83,   339,   251,   443,    59,   315, 
      187,   491,   107,   363,   203,   395,    11,   267,   139,   459, 
       75,   331,   235,   427,    43,   299,   171,   510,   126,   382, 
      222,   414,    30,   286,   158,   478,    94,   350,   246,   438, 
       54,   310,   182,   486,   102,   358,   198,   390,     6,   262, 
      134,   454,    70,   326,   230,   422,    38,   294,   166,   502, 
      118,   374,   214,   406,    22,   278,   150,   470,    86,   342, 
      252,   444,    60,   316,   188,   492,   108,   364,   204,   396, 
       12,   268,   140,   460,    76,   332,   236,   428,    44,   300, 
      172,   504,   120,   376,   216,   408,    24,   280,   152,   472, 
       88,   344,   240,   432,    48,   304,   176,   480,    96,   352, 
      192,   384
  );
  RevBits1024: array[0..1023] of WORD = (
        0,   512,   256,   896,   128,   640,   448,   832,    64,   576, 
      320,   992,   224,   736,   416,   800,    32,   544,   288,   928, 
      160,   672,   496,   880,   112,   624,   368,   976,   208,   720,
      400,   784,    16,   528,   272,   912,   144,   656,   464,   848, 
       80,   592,   336,  1016,   248,   760,   440,   824,    56,   568, 
      312,   952,   184,   696,   488,   872,   104,   616,   360,   968, 
      200,   712,   392,   776,     8,   520,   264,   904,   136,   648, 
      456,   840,    72,   584,   328,  1000,   232,   744,   424,   808, 
       40,   552,   296,   936,   168,   680,   508,   892,   124,   636, 
      380,   988,   220,   732,   412,   796,    28,   540,   284,   924, 
      156,   668,   476,   860,    92,   604,   348,  1012,   244,   756, 
      436,   820,    52,   564,   308,   948,   180,   692,   484,   868, 
      100,   612,   356,   964,   196,   708,   388,   772,     4,   516, 
      260,   900,   132,   644,   452,   836,    68,   580,   324,   996, 
      228,   740,   420,   804,    36,   548,   292,   932,   164,   676, 
      500,   884,   116,   628,   372,   980,   212,   724,   404,   788, 
       20,   532,   276,   916,   148,   660,   468,   852,    84,   596, 
      340,  1022,   254,   766,   446,   830,    62,   574,   318,   958, 
      190,   702,   494,   878,   110,   622,   366,   974,   206,   718, 
      398,   782,    14,   526,   270,   910,   142,   654,   462,   846, 
       78,   590,   334,  1006,   238,   750,   430,   814,    46,   558, 
      302,   942,   174,   686,   506,   890,   122,   634,   378,   986, 
      218,   730,   410,   794,    26,   538,   282,   922,   154,   666, 
      474,   858,    90,   602,   346,  1010,   242,   754,   434,   818, 
       50,   562,   306,   946,   178,   690,   482,   866,    98,   610, 
      354,   962,   194,   706,   386,   770,     2,   514,   258,   898, 
      130,   642,   450,   834,    66,   578,   322,   994,   226,   738, 
      418,   802,    34,   546,   290,   930,   162,   674,   498,   882, 
      114,   626,   370,   978,   210,   722,   402,   786,    18,   530, 
      274,   914,   146,   658,   466,   850,    82,   594,   338,  1018, 
      250,   762,   442,   826,    58,   570,   314,   954,   186,   698, 
      490,   874,   106,   618,   362,   970,   202,   714,   394,   778, 
       10,   522,   266,   906,   138,   650,   458,   842,    74,   586, 
      330,  1002,   234,   746,   426,   810,    42,   554,   298,   938, 
      170,   682,   511,   895,   127,   639,   383,   991,   223,   735, 
      415,   799,    31,   543,   287,   927,   159,   671,   479,   863, 
       95,   607,   351,  1015,   247,   759,   439,   823,    55,   567, 
      311,   951,   183,   695,   487,   871,   103,   615,   359,   967, 
      199,   711,   391,   775,     7,   519,   263,   903,   135,   647,
      455,   839,    71,   583,   327,   999,   231,   743,   423,   807, 
       39,   551,   295,   935,   167,   679,   503,   887,   119,   631, 
      375,   983,   215,   727,   407,   791,    23,   535,   279,   919, 
      151,   663,   471,   855,    87,   599,   343,  1021,   253,   765, 
      445,   829,    61,   573,   317,   957,   189,   701,   493,   877, 
      109,   621,   365,   973,   205,   717,   397,   781,    13,   525, 
      269,   909,   141,   653,   461,   845,    77,   589,   333,  1005, 
      237,   749,   429,   813,    45,   557,   301,   941,   173,   685, 
      505,   889,   121,   633,   377,   985,   217,   729,   409,   793, 
       25,   537,   281,   921,   153,   665,   473,   857,    89,   601, 
      345,  1009,   241,   753,   433,   817,    49,   561,   305,   945, 
      177,   689,   481,   865,    97,   609,   353,   961,   193,   705, 
      385,   769,     1,   513,   257,   897,   129,   641,   449,   833, 
       65,   577,   321,   993,   225,   737,   417,   801,    33,   545, 
      289,   929,   161,   673,   497,   881,   113,   625,   369,   977, 
      209,   721,   401,   785,    17,   529,   273,   913,   145,   657, 
      465,   849,    81,   593,   337,  1017,   249,   761,   441,   825, 
       57,   569,   313,   953,   185,   697,   489,   873,   105,   617, 
      361,   969,   201,   713,   393,   777,     9,   521,   265,   905, 
      137,   649,   457,   841,    73,   585,   329,  1001,   233,   745, 
      425,   809,    41,   553,   297,   937,   169,   681,   509,   893, 
      125,   637,   381,   989,   221,   733,   413,   797,    29,   541, 
      285,   925,   157,   669,   477,   861,    93,   605,   349,  1013, 
      245,   757,   437,   821,    53,   565,   309,   949,   181,   693, 
      485,   869,   101,   613,   357,   965,   197,   709,   389,   773, 
        5,   517,   261,   901,   133,   645,   453,   837,    69,   581, 
      325,   997,   229,   741,   421,   805,    37,   549,   293,   933, 
      165,   677,   501,   885,   117,   629,   373,   981,   213,   725, 
      405,   789,    21,   533,   277,   917,   149,   661,   469,   853, 
       85,   597,   341,  1023,   255,   767,   447,   831,    63,   575, 
      319,   959,   191,   703,   495,   879,   111,   623,   367,   975, 
      207,   719,   399,   783,    15,   527,   271,   911,   143,   655, 
      463,   847,    79,   591,   335,  1007,   239,   751,   431,   815, 
       47,   559,   303,   943,   175,   687,   507,   891,   123,   635, 
      379,   987,   219,   731,   411,   795,    27,   539,   283,   923, 
      155,   667,   475,   859,    91,   603,   347,  1011,   243,   755,
      435,   819,    51,   563,   307,   947,   179,   691,   483,   867, 
       99,   611,   355,   963,   195,   707,   387,   771,     3,   515, 
      259,   899,   131,   643,   451,   835,    67,   579,   323,   995, 
      227,   739,   419,   803,    35,   547,   291,   931,   163,   675, 
      499,   883,   115,   627,   371,   979,   211,   723,   403,   787, 
       19,   531,   275,   915,   147,   659,   467,   851,    83,   595, 
      339,  1019,   251,   763,   443,   827,    59,   571,   315,   955, 
      187,   699,   491,   875,   107,   619,   363,   971,   203,   715, 
      395,   779,    11,   523,   267,   907,   139,   651,   459,   843, 
       75,   587,   331,  1003,   235,   747,   427,   811,    43,   555, 
      299,   939,   171,   683,   510,   894,   126,   638,   382,   990, 
      222,   734,   414,   798,    30,   542,   286,   926,   158,   670, 
      478,   862,    94,   606,   350,  1014,   246,   758,   438,   822, 
       54,   566,   310,   950,   182,   694,   486,   870,   102,   614, 
      358,   966,   198,   710,   390,   774,     6,   518,   262,   902, 
      134,   646,   454,   838,    70,   582,   326,   998,   230,   742, 
      422,   806,    38,   550,   294,   934,   166,   678,   502,   886, 
      118,   630,   374,   982,   214,   726,   406,   790,    22,   534, 
      278,   918,   150,   662,   470,   854,    86,   598,   342,  1020, 
      252,   764,   444,   828,    60,   572,   316,   956,   188,   700, 
      492,   876,   108,   620,   364,   972,   204,   716,   396,   780, 
       12,   524,   268,   908,   140,   652,   460,   844,    76,   588, 
      332,  1004,   236,   748,   428,   812,    44,   556,   300,   940, 
      172,   684,   504,   888,   120,   632,   376,   984,   216,   728, 
      408,   792,    24,   536,   280,   920,   152,   664,   472,   856, 
       88,   600,   344,  1008,   240,   752,   432,   816,    48,   560, 
      304,   944,   176,   688,   480,   864,    96,   608,   352,   960, 
      192,   704,   384,   768
  );
  RevBits2048: array[0..2047] of WORD = (
        0,  1024,   512,  1792,   256,  1280,   896,  1664,   128,  1152, 
      640,  1984,   448,  1472,   832,  1600,    64,  1088,   576,  1856, 
      320,  1344,   992,  1760,   224,  1248,   736,  1952,   416,  1440, 
      800,  1568,    32,  1056,   544,  1824,   288,  1312,   928,  1696, 
      160,  1184,   672,  2032,   496,  1520,   880,  1648,   112,  1136, 
      624,  1904,   368,  1392,   976,  1744,   208,  1232,   720,  1936,
      400,  1424,   784,  1552,    16,  1040,   528,  1808,   272,  1296, 
      912,  1680,   144,  1168,   656,  2000,   464,  1488,   848,  1616, 
       80,  1104,   592,  1872,   336,  1360,  1016,  1784,   248,  1272, 
      760,  1976,   440,  1464,   824,  1592,    56,  1080,   568,  1848, 
      312,  1336,   952,  1720,   184,  1208,   696,  2024,   488,  1512, 
      872,  1640,   104,  1128,   616,  1896,   360,  1384,   968,  1736, 
      200,  1224,   712,  1928,   392,  1416,   776,  1544,     8,  1032, 
      520,  1800,   264,  1288,   904,  1672,   136,  1160,   648,  1992, 
      456,  1480,   840,  1608,    72,  1096,   584,  1864,   328,  1352, 
     1000,  1768,   232,  1256,   744,  1960,   424,  1448,   808,  1576, 
       40,  1064,   552,  1832,   296,  1320,   936,  1704,   168,  1192, 
      680,  2044,   508,  1532,   892,  1660,   124,  1148,   636,  1916, 
      380,  1404,   988,  1756,   220,  1244,   732,  1948,   412,  1436, 
      796,  1564,    28,  1052,   540,  1820,   284,  1308,   924,  1692, 
      156,  1180,   668,  2012,   476,  1500,   860,  1628,    92,  1116, 
      604,  1884,   348,  1372,  1012,  1780,   244,  1268,   756,  1972, 
      436,  1460,   820,  1588,    52,  1076,   564,  1844,   308,  1332, 
      948,  1716,   180,  1204,   692,  2020,   484,  1508,   868,  1636, 
      100,  1124,   612,  1892,   356,  1380,   964,  1732,   196,  1220, 
      708,  1924,   388,  1412,   772,  1540,     4,  1028,   516,  1796, 
      260,  1284,   900,  1668,   132,  1156,   644,  1988,   452,  1476, 
      836,  1604,    68,  1092,   580,  1860,   324,  1348,   996,  1764, 
      228,  1252,   740,  1956,   420,  1444,   804,  1572,    36,  1060, 
      548,  1828,   292,  1316,   932,  1700,   164,  1188,   676,  2036, 
      500,  1524,   884,  1652,   116,  1140,   628,  1908,   372,  1396, 
      980,  1748,   212,  1236,   724,  1940,   404,  1428,   788,  1556, 
       20,  1044,   532,  1812,   276,  1300,   916,  1684,   148,  1172, 
      660,  2004,   468,  1492,   852,  1620,    84,  1108,   596,  1876, 
      340,  1364,  1022,  1790,   254,  1278,   766,  1982,   446,  1470, 
      830,  1598,    62,  1086,   574,  1854,   318,  1342,   958,  1726, 
      190,  1214,   702,  2030,   494,  1518,   878,  1646,   110,  1134, 
      622,  1902,   366,  1390,   974,  1742,   206,  1230,   718,  1934, 
      398,  1422,   782,  1550,    14,  1038,   526,  1806,   270,  1294, 
      910,  1678,   142,  1166,   654,  1998,   462,  1486,   846,  1614, 
       78,  1102,   590,  1870,   334,  1358,  1006,  1774,   238,  1262, 
      750,  1966,   430,  1454,   814,  1582,    46,  1070,   558,  1838,
      302,  1326,   942,  1710,   174,  1198,   686,  2042,   506,  1530, 
      890,  1658,   122,  1146,   634,  1914,   378,  1402,   986,  1754, 
      218,  1242,   730,  1946,   410,  1434,   794,  1562,    26,  1050, 
      538,  1818,   282,  1306,   922,  1690,   154,  1178,   666,  2010, 
      474,  1498,   858,  1626,    90,  1114,   602,  1882,   346,  1370, 
     1010,  1778,   242,  1266,   754,  1970,   434,  1458,   818,  1586, 
       50,  1074,   562,  1842,   306,  1330,   946,  1714,   178,  1202, 
      690,  2018,   482,  1506,   866,  1634,    98,  1122,   610,  1890, 
      354,  1378,   962,  1730,   194,  1218,   706,  1922,   386,  1410, 
      770,  1538,     2,  1026,   514,  1794,   258,  1282,   898,  1666, 
      130,  1154,   642,  1986,   450,  1474,   834,  1602,    66,  1090, 
      578,  1858,   322,  1346,   994,  1762,   226,  1250,   738,  1954, 
      418,  1442,   802,  1570,    34,  1058,   546,  1826,   290,  1314, 
      930,  1698,   162,  1186,   674,  2034,   498,  1522,   882,  1650, 
      114,  1138,   626,  1906,   370,  1394,   978,  1746,   210,  1234, 
      722,  1938,   402,  1426,   786,  1554,    18,  1042,   530,  1810, 
      274,  1298,   914,  1682,   146,  1170,   658,  2002,   466,  1490, 
      850,  1618,    82,  1106,   594,  1874,   338,  1362,  1018,  1786, 
      250,  1274,   762,  1978,   442,  1466,   826,  1594,    58,  1082, 
      570,  1850,   314,  1338,   954,  1722,   186,  1210,   698,  2026, 
      490,  1514,   874,  1642,   106,  1130,   618,  1898,   362,  1386, 
      970,  1738,   202,  1226,   714,  1930,   394,  1418,   778,  1546, 
       10,  1034,   522,  1802,   266,  1290,   906,  1674,   138,  1162, 
      650,  1994,   458,  1482,   842,  1610,    74,  1098,   586,  1866, 
      330,  1354,  1002,  1770,   234,  1258,   746,  1962,   426,  1450, 
      810,  1578,    42,  1066,   554,  1834,   298,  1322,   938,  1706, 
      170,  1194,   682,  2047,   511,  1535,   895,  1663,   127,  1151, 
      639,  1919,   383,  1407,   991,  1759,   223,  1247,   735,  1951, 
      415,  1439,   799,  1567,    31,  1055,   543,  1823,   287,  1311, 
      927,  1695,   159,  1183,   671,  2015,   479,  1503,   863,  1631, 
       95,  1119,   607,  1887,   351,  1375,  1015,  1783,   247,  1271, 
      759,  1975,   439,  1463,   823,  1591,    55,  1079,   567,  1847, 
      311,  1335,   951,  1719,   183,  1207,   695,  2023,   487,  1511, 
      871,  1639,   103,  1127,   615,  1895,   359,  1383,   967,  1735, 
      199,  1223,   711,  1927,   391,  1415,   775,  1543,     7,  1031, 
      519,  1799,   263,  1287,   903,  1671,   135,  1159,   647,  1991,
      455,  1479,   839,  1607,    71,  1095,   583,  1863,   327,  1351, 
      999,  1767,   231,  1255,   743,  1959,   423,  1447,   807,  1575, 
       39,  1063,   551,  1831,   295,  1319,   935,  1703,   167,  1191, 
      679,  2039,   503,  1527,   887,  1655,   119,  1143,   631,  1911, 
      375,  1399,   983,  1751,   215,  1239,   727,  1943,   407,  1431, 
      791,  1559,    23,  1047,   535,  1815,   279,  1303,   919,  1687, 
      151,  1175,   663,  2007,   471,  1495,   855,  1623,    87,  1111, 
      599,  1879,   343,  1367,  1021,  1789,   253,  1277,   765,  1981, 
      445,  1469,   829,  1597,    61,  1085,   573,  1853,   317,  1341, 
      957,  1725,   189,  1213,   701,  2029,   493,  1517,   877,  1645, 
      109,  1133,   621,  1901,   365,  1389,   973,  1741,   205,  1229, 
      717,  1933,   397,  1421,   781,  1549,    13,  1037,   525,  1805, 
      269,  1293,   909,  1677,   141,  1165,   653,  1997,   461,  1485, 
      845,  1613,    77,  1101,   589,  1869,   333,  1357,  1005,  1773, 
      237,  1261,   749,  1965,   429,  1453,   813,  1581,    45,  1069, 
      557,  1837,   301,  1325,   941,  1709,   173,  1197,   685,  2041, 
      505,  1529,   889,  1657,   121,  1145,   633,  1913,   377,  1401, 
      985,  1753,   217,  1241,   729,  1945,   409,  1433,   793,  1561, 
       25,  1049,   537,  1817,   281,  1305,   921,  1689,   153,  1177, 
      665,  2009,   473,  1497,   857,  1625,    89,  1113,   601,  1881, 
      345,  1369,  1009,  1777,   241,  1265,   753,  1969,   433,  1457, 
      817,  1585,    49,  1073,   561,  1841,   305,  1329,   945,  1713, 
      177,  1201,   689,  2017,   481,  1505,   865,  1633,    97,  1121, 
      609,  1889,   353,  1377,   961,  1729,   193,  1217,   705,  1921, 
      385,  1409,   769,  1537,     1,  1025,   513,  1793,   257,  1281, 
      897,  1665,   129,  1153,   641,  1985,   449,  1473,   833,  1601, 
       65,  1089,   577,  1857,   321,  1345,   993,  1761,   225,  1249, 
      737,  1953,   417,  1441,   801,  1569,    33,  1057,   545,  1825, 
      289,  1313,   929,  1697,   161,  1185,   673,  2033,   497,  1521, 
      881,  1649,   113,  1137,   625,  1905,   369,  1393,   977,  1745, 
      209,  1233,   721,  1937,   401,  1425,   785,  1553,    17,  1041, 
      529,  1809,   273,  1297,   913,  1681,   145,  1169,   657,  2001, 
      465,  1489,   849,  1617,    81,  1105,   593,  1873,   337,  1361, 
     1017,  1785,   249,  1273,   761,  1977,   441,  1465,   825,  1593, 
       57,  1081,   569,  1849,   313,  1337,   953,  1721,   185,  1209, 
      697,  2025,   489,  1513,   873,  1641,   105,  1129,   617,  1897,
      361,  1385,   969,  1737,   201,  1225,   713,  1929,   393,  1417, 
      777,  1545,     9,  1033,   521,  1801,   265,  1289,   905,  1673, 
      137,  1161,   649,  1993,   457,  1481,   841,  1609,    73,  1097, 
      585,  1865,   329,  1353,  1001,  1769,   233,  1257,   745,  1961, 
      425,  1449,   809,  1577,    41,  1065,   553,  1833,   297,  1321, 
      937,  1705,   169,  1193,   681,  2045,   509,  1533,   893,  1661, 
      125,  1149,   637,  1917,   381,  1405,   989,  1757,   221,  1245, 
      733,  1949,   413,  1437,   797,  1565,    29,  1053,   541,  1821, 
      285,  1309,   925,  1693,   157,  1181,   669,  2013,   477,  1501, 
      861,  1629,    93,  1117,   605,  1885,   349,  1373,  1013,  1781, 
      245,  1269,   757,  1973,   437,  1461,   821,  1589,    53,  1077, 
      565,  1845,   309,  1333,   949,  1717,   181,  1205,   693,  2021, 
      485,  1509,   869,  1637,   101,  1125,   613,  1893,   357,  1381, 
      965,  1733,   197,  1221,   709,  1925,   389,  1413,   773,  1541, 
        5,  1029,   517,  1797,   261,  1285,   901,  1669,   133,  1157, 
      645,  1989,   453,  1477,   837,  1605,    69,  1093,   581,  1861, 
      325,  1349,   997,  1765,   229,  1253,   741,  1957,   421,  1445, 
      805,  1573,    37,  1061,   549,  1829,   293,  1317,   933,  1701, 
      165,  1189,   677,  2037,   501,  1525,   885,  1653,   117,  1141, 
      629,  1909,   373,  1397,   981,  1749,   213,  1237,   725,  1941, 
      405,  1429,   789,  1557,    21,  1045,   533,  1813,   277,  1301, 
      917,  1685,   149,  1173,   661,  2005,   469,  1493,   853,  1621, 
       85,  1109,   597,  1877,   341,  1365,  1023,  1791,   255,  1279, 
      767,  1983,   447,  1471,   831,  1599,    63,  1087,   575,  1855, 
      319,  1343,   959,  1727,   191,  1215,   703,  2031,   495,  1519, 
      879,  1647,   111,  1135,   623,  1903,   367,  1391,   975,  1743, 
      207,  1231,   719,  1935,   399,  1423,   783,  1551,    15,  1039, 
      527,  1807,   271,  1295,   911,  1679,   143,  1167,   655,  1999, 
      463,  1487,   847,  1615,    79,  1103,   591,  1871,   335,  1359, 
     1007,  1775,   239,  1263,   751,  1967,   431,  1455,   815,  1583, 
       47,  1071,   559,  1839,   303,  1327,   943,  1711,   175,  1199, 
      687,  2043,   507,  1531,   891,  1659,   123,  1147,   635,  1915, 
      379,  1403,   987,  1755,   219,  1243,   731,  1947,   411,  1435, 
      795,  1563,    27,  1051,   539,  1819,   283,  1307,   923,  1691, 
      155,  1179,   667,  2011,   475,  1499,   859,  1627,    91,  1115, 
      603,  1883,   347,  1371,  1011,  1779,   243,  1267,   755,  1971,
      435,  1459,   819,  1587,    51,  1075,   563,  1843,   307,  1331, 
      947,  1715,   179,  1203,   691,  2019,   483,  1507,   867,  1635, 
       99,  1123,   611,  1891,   355,  1379,   963,  1731,   195,  1219, 
      707,  1923,   387,  1411,   771,  1539,     3,  1027,   515,  1795, 
      259,  1283,   899,  1667,   131,  1155,   643,  1987,   451,  1475, 
      835,  1603,    67,  1091,   579,  1859,   323,  1347,   995,  1763, 
      227,  1251,   739,  1955,   419,  1443,   803,  1571,    35,  1059, 
      547,  1827,   291,  1315,   931,  1699,   163,  1187,   675,  2035, 
      499,  1523,   883,  1651,   115,  1139,   627,  1907,   371,  1395, 
      979,  1747,   211,  1235,   723,  1939,   403,  1427,   787,  1555, 
       19,  1043,   531,  1811,   275,  1299,   915,  1683,   147,  1171, 
      659,  2003,   467,  1491,   851,  1619,    83,  1107,   595,  1875, 
      339,  1363,  1019,  1787,   251,  1275,   763,  1979,   443,  1467, 
      827,  1595,    59,  1083,   571,  1851,   315,  1339,   955,  1723, 
      187,  1211,   699,  2027,   491,  1515,   875,  1643,   107,  1131, 
      619,  1899,   363,  1387,   971,  1739,   203,  1227,   715,  1931, 
      395,  1419,   779,  1547,    11,  1035,   523,  1803,   267,  1291, 
      907,  1675,   139,  1163,   651,  1995,   459,  1483,   843,  1611, 
       75,  1099,   587,  1867,   331,  1355,  1003,  1771,   235,  1259, 
      747,  1963,   427,  1451,   811,  1579,    43,  1067,   555,  1835, 
      299,  1323,   939,  1707,   171,  1195,   683,  2046,   510,  1534, 
      894,  1662,   126,  1150,   638,  1918,   382,  1406,   990,  1758, 
      222,  1246,   734,  1950,   414,  1438,   798,  1566,    30,  1054, 
      542,  1822,   286,  1310,   926,  1694,   158,  1182,   670,  2014, 
      478,  1502,   862,  1630,    94,  1118,   606,  1886,   350,  1374, 
     1014,  1782,   246,  1270,   758,  1974,   438,  1462,   822,  1590, 
       54,  1078,   566,  1846,   310,  1334,   950,  1718,   182,  1206, 
      694,  2022,   486,  1510,   870,  1638,   102,  1126,   614,  1894, 
      358,  1382,   966,  1734,   198,  1222,   710,  1926,   390,  1414, 
      774,  1542,     6,  1030,   518,  1798,   262,  1286,   902,  1670, 
      134,  1158,   646,  1990,   454,  1478,   838,  1606,    70,  1094, 
      582,  1862,   326,  1350,   998,  1766,   230,  1254,   742,  1958, 
      422,  1446,   806,  1574,    38,  1062,   550,  1830,   294,  1318, 
      934,  1702,   166,  1190,   678,  2038,   502,  1526,   886,  1654, 
      118,  1142,   630,  1910,   374,  1398,   982,  1750,   214,  1238, 
      726,  1942,   406,  1430,   790,  1558,    22,  1046,   534,  1814,
      278,  1302,   918,  1686,   150,  1174,   662,  2006,   470,  1494, 
      854,  1622,    86,  1110,   598,  1878,   342,  1366,  1020,  1788, 
      252,  1276,   764,  1980,   444,  1468,   828,  1596,    60,  1084, 
      572,  1852,   316,  1340,   956,  1724,   188,  1212,   700,  2028, 
      492,  1516,   876,  1644,   108,  1132,   620,  1900,   364,  1388, 
      972,  1740,   204,  1228,   716,  1932,   396,  1420,   780,  1548, 
       12,  1036,   524,  1804,   268,  1292,   908,  1676,   140,  1164, 
      652,  1996,   460,  1484,   844,  1612,    76,  1100,   588,  1868, 
      332,  1356,  1004,  1772,   236,  1260,   748,  1964,   428,  1452, 
      812,  1580,    44,  1068,   556,  1836,   300,  1324,   940,  1708, 
      172,  1196,   684,  2040,   504,  1528,   888,  1656,   120,  1144, 
      632,  1912,   376,  1400,   984,  1752,   216,  1240,   728,  1944, 
      408,  1432,   792,  1560,    24,  1048,   536,  1816,   280,  1304, 
      920,  1688,   152,  1176,   664,  2008,   472,  1496,   856,  1624, 
       88,  1112,   600,  1880,   344,  1368,  1008,  1776,   240,  1264, 
      752,  1968,   432,  1456,   816,  1584,    48,  1072,   560,  1840, 
      304,  1328,   944,  1712,   176,  1200,   688,  2016,   480,  1504, 
      864,  1632,    96,  1120,   608,  1888,   352,  1376,   960,  1728, 
      192,  1216,   704,  1920,   384,  1408,   768,  1536
  );
  RevBits4096: array[0..4095] of WORD = (
        0,  2048,  1024,  3584,   512,  2560,  1792,  3328,   256,  2304, 
     1280,  3968,   896,  2944,  1664,  3200,   128,  2176,  1152,  3712, 
      640,  2688,  1984,  3520,   448,  2496,  1472,  3904,   832,  2880, 
     1600,  3136,    64,  2112,  1088,  3648,   576,  2624,  1856,  3392, 
      320,  2368,  1344,  4064,   992,  3040,  1760,  3296,   224,  2272, 
     1248,  3808,   736,  2784,  1952,  3488,   416,  2464,  1440,  3872, 
      800,  2848,  1568,  3104,    32,  2080,  1056,  3616,   544,  2592, 
     1824,  3360,   288,  2336,  1312,  4000,   928,  2976,  1696,  3232, 
      160,  2208,  1184,  3744,   672,  2720,  2032,  3568,   496,  2544, 
     1520,  3952,   880,  2928,  1648,  3184,   112,  2160,  1136,  3696, 
      624,  2672,  1904,  3440,   368,  2416,  1392,  4048,   976,  3024, 
     1744,  3280,   208,  2256,  1232,  3792,   720,  2768,  1936,  3472, 
      400,  2448,  1424,  3856,   784,  2832,  1552,  3088,    16,  2064, 
     1040,  3600,   528,  2576,  1808,  3344,   272,  2320,  1296,  3984, 
      912,  2960,  1680,  3216,   144,  2192,  1168,  3728,   656,  2704,
     2000,  3536,   464,  2512,  1488,  3920,   848,  2896,  1616,  3152, 
       80,  2128,  1104,  3664,   592,  2640,  1872,  3408,   336,  2384, 
     1360,  4088,  1016,  3064,  1784,  3320,   248,  2296,  1272,  3832, 
      760,  2808,  1976,  3512,   440,  2488,  1464,  3896,   824,  2872, 
     1592,  3128,    56,  2104,  1080,  3640,   568,  2616,  1848,  3384, 
      312,  2360,  1336,  4024,   952,  3000,  1720,  3256,   184,  2232, 
     1208,  3768,   696,  2744,  2024,  3560,   488,  2536,  1512,  3944, 
      872,  2920,  1640,  3176,   104,  2152,  1128,  3688,   616,  2664, 
     1896,  3432,   360,  2408,  1384,  4040,   968,  3016,  1736,  3272, 
      200,  2248,  1224,  3784,   712,  2760,  1928,  3464,   392,  2440, 
     1416,  3848,   776,  2824,  1544,  3080,     8,  2056,  1032,  3592, 
      520,  2568,  1800,  3336,   264,  2312,  1288,  3976,   904,  2952, 
     1672,  3208,   136,  2184,  1160,  3720,   648,  2696,  1992,  3528, 
      456,  2504,  1480,  3912,   840,  2888,  1608,  3144,    72,  2120, 
     1096,  3656,   584,  2632,  1864,  3400,   328,  2376,  1352,  4072, 
     1000,  3048,  1768,  3304,   232,  2280,  1256,  3816,   744,  2792, 
     1960,  3496,   424,  2472,  1448,  3880,   808,  2856,  1576,  3112, 
       40,  2088,  1064,  3624,   552,  2600,  1832,  3368,   296,  2344, 
     1320,  4008,   936,  2984,  1704,  3240,   168,  2216,  1192,  3752, 
      680,  2728,  2044,  3580,   508,  2556,  1532,  3964,   892,  2940, 
     1660,  3196,   124,  2172,  1148,  3708,   636,  2684,  1916,  3452, 
      380,  2428,  1404,  4060,   988,  3036,  1756,  3292,   220,  2268, 
     1244,  3804,   732,  2780,  1948,  3484,   412,  2460,  1436,  3868, 
      796,  2844,  1564,  3100,    28,  2076,  1052,  3612,   540,  2588, 
     1820,  3356,   284,  2332,  1308,  3996,   924,  2972,  1692,  3228, 
      156,  2204,  1180,  3740,   668,  2716,  2012,  3548,   476,  2524, 
     1500,  3932,   860,  2908,  1628,  3164,    92,  2140,  1116,  3676, 
      604,  2652,  1884,  3420,   348,  2396,  1372,  4084,  1012,  3060, 
     1780,  3316,   244,  2292,  1268,  3828,   756,  2804,  1972,  3508, 
      436,  2484,  1460,  3892,   820,  2868,  1588,  3124,    52,  2100, 
     1076,  3636,   564,  2612,  1844,  3380,   308,  2356,  1332,  4020, 
      948,  2996,  1716,  3252,   180,  2228,  1204,  3764,   692,  2740, 
     2020,  3556,   484,  2532,  1508,  3940,   868,  2916,  1636,  3172, 
      100,  2148,  1124,  3684,   612,  2660,  1892,  3428,   356,  2404, 
     1380,  4036,   964,  3012,  1732,  3268,   196,  2244,  1220,  3780, 
      708,  2756,  1924,  3460,   388,  2436,  1412,  3844,   772,  2820, 
     1540,  3076,     4,  2052,  1028,  3588,   516,  2564,  1796,  3332, 
      260,  2308,  1284,  3972,   900,  2948,  1668,  3204,   132,  2180, 
     1156,  3716,   644,  2692,  1988,  3524,   452,  2500,  1476,  3908, 
      836,  2884,  1604,  3140,    68,  2116,  1092,  3652,   580,  2628, 
     1860,  3396,   324,  2372,  1348,  4068,   996,  3044,  1764,  3300, 
      228,  2276,  1252,  3812,   740,  2788,  1956,  3492,   420,  2468, 
     1444,  3876,   804,  2852,  1572,  3108,    36,  2084,  1060,  3620, 
      548,  2596,  1828,  3364,   292,  2340,  1316,  4004,   932,  2980, 
     1700,  3236,   164,  2212,  1188,  3748,   676,  2724,  2036,  3572, 
      500,  2548,  1524,  3956,   884,  2932,  1652,  3188,   116,  2164, 
     1140,  3700,   628,  2676,  1908,  3444,   372,  2420,  1396,  4052, 
      980,  3028,  1748,  3284,   212,  2260,  1236,  3796,   724,  2772, 
     1940,  3476,   404,  2452,  1428,  3860,   788,  2836,  1556,  3092, 
       20,  2068,  1044,  3604,   532,  2580,  1812,  3348,   276,  2324, 
     1300,  3988,   916,  2964,  1684,  3220,   148,  2196,  1172,  3732, 
      660,  2708,  2004,  3540,   468,  2516,  1492,  3924,   852,  2900, 
     1620,  3156,    84,  2132,  1108,  3668,   596,  2644,  1876,  3412, 
      340,  2388,  1364,  4094,  1022,  3070,  1790,  3326,   254,  2302, 
     1278,  3838,   766,  2814,  1982,  3518,   446,  2494,  1470,  3902, 
      830,  2878,  1598,  3134,    62,  2110,  1086,  3646,   574,  2622, 
     1854,  3390,   318,  2366,  1342,  4030,   958,  3006,  1726,  3262, 
      190,  2238,  1214,  3774,   702,  2750,  2030,  3566,   494,  2542, 
     1518,  3950,   878,  2926,  1646,  3182,   110,  2158,  1134,  3694, 
      622,  2670,  1902,  3438,   366,  2414,  1390,  4046,   974,  3022, 
     1742,  3278,   206,  2254,  1230,  3790,   718,  2766,  1934,  3470, 
      398,  2446,  1422,  3854,   782,  2830,  1550,  3086,    14,  2062, 
     1038,  3598,   526,  2574,  1806,  3342,   270,  2318,  1294,  3982, 
      910,  2958,  1678,  3214,   142,  2190,  1166,  3726,   654,  2702, 
     1998,  3534,   462,  2510,  1486,  3918,   846,  2894,  1614,  3150, 
       78,  2126,  1102,  3662,   590,  2638,  1870,  3406,   334,  2382, 
     1358,  4078,  1006,  3054,  1774,  3310,   238,  2286,  1262,  3822, 
      750,  2798,  1966,  3502,   430,  2478,  1454,  3886,   814,  2862, 
     1582,  3118,    46,  2094,  1070,  3630,   558,  2606,  1838,  3374, 
      302,  2350,  1326,  4014,   942,  2990,  1710,  3246,   174,  2222, 
     1198,  3758,   686,  2734,  2042,  3578,   506,  2554,  1530,  3962, 
      890,  2938,  1658,  3194,   122,  2170,  1146,  3706,   634,  2682, 
     1914,  3450,   378,  2426,  1402,  4058,   986,  3034,  1754,  3290, 
      218,  2266,  1242,  3802,   730,  2778,  1946,  3482,   410,  2458, 
     1434,  3866,   794,  2842,  1562,  3098,    26,  2074,  1050,  3610, 
      538,  2586,  1818,  3354,   282,  2330,  1306,  3994,   922,  2970, 
     1690,  3226,   154,  2202,  1178,  3738,   666,  2714,  2010,  3546, 
      474,  2522,  1498,  3930,   858,  2906,  1626,  3162,    90,  2138, 
     1114,  3674,   602,  2650,  1882,  3418,   346,  2394,  1370,  4082, 
     1010,  3058,  1778,  3314,   242,  2290,  1266,  3826,   754,  2802, 
     1970,  3506,   434,  2482,  1458,  3890,   818,  2866,  1586,  3122, 
       50,  2098,  1074,  3634,   562,  2610,  1842,  3378,   306,  2354, 
     1330,  4018,   946,  2994,  1714,  3250,   178,  2226,  1202,  3762, 
      690,  2738,  2018,  3554,   482,  2530,  1506,  3938,   866,  2914, 
     1634,  3170,    98,  2146,  1122,  3682,   610,  2658,  1890,  3426, 
      354,  2402,  1378,  4034,   962,  3010,  1730,  3266,   194,  2242, 
     1218,  3778,   706,  2754,  1922,  3458,   386,  2434,  1410,  3842, 
      770,  2818,  1538,  3074,     2,  2050,  1026,  3586,   514,  2562, 
     1794,  3330,   258,  2306,  1282,  3970,   898,  2946,  1666,  3202, 
      130,  2178,  1154,  3714,   642,  2690,  1986,  3522,   450,  2498, 
     1474,  3906,   834,  2882,  1602,  3138,    66,  2114,  1090,  3650, 
      578,  2626,  1858,  3394,   322,  2370,  1346,  4066,   994,  3042, 
     1762,  3298,   226,  2274,  1250,  3810,   738,  2786,  1954,  3490, 
      418,  2466,  1442,  3874,   802,  2850,  1570,  3106,    34,  2082, 
     1058,  3618,   546,  2594,  1826,  3362,   290,  2338,  1314,  4002, 
      930,  2978,  1698,  3234,   162,  2210,  1186,  3746,   674,  2722, 
     2034,  3570,   498,  2546,  1522,  3954,   882,  2930,  1650,  3186, 
      114,  2162,  1138,  3698,   626,  2674,  1906,  3442,   370,  2418, 
     1394,  4050,   978,  3026,  1746,  3282,   210,  2258,  1234,  3794, 
      722,  2770,  1938,  3474,   402,  2450,  1426,  3858,   786,  2834, 
     1554,  3090,    18,  2066,  1042,  3602,   530,  2578,  1810,  3346, 
      274,  2322,  1298,  3986,   914,  2962,  1682,  3218,   146,  2194, 
     1170,  3730,   658,  2706,  2002,  3538,   466,  2514,  1490,  3922, 
      850,  2898,  1618,  3154,    82,  2130,  1106,  3666,   594,  2642, 
     1874,  3410,   338,  2386,  1362,  4090,  1018,  3066,  1786,  3322, 
      250,  2298,  1274,  3834,   762,  2810,  1978,  3514,   442,  2490, 
     1466,  3898,   826,  2874,  1594,  3130,    58,  2106,  1082,  3642, 
      570,  2618,  1850,  3386,   314,  2362,  1338,  4026,   954,  3002, 
     1722,  3258,   186,  2234,  1210,  3770,   698,  2746,  2026,  3562, 
      490,  2538,  1514,  3946,   874,  2922,  1642,  3178,   106,  2154, 
     1130,  3690,   618,  2666,  1898,  3434,   362,  2410,  1386,  4042, 
      970,  3018,  1738,  3274,   202,  2250,  1226,  3786,   714,  2762, 
     1930,  3466,   394,  2442,  1418,  3850,   778,  2826,  1546,  3082, 
       10,  2058,  1034,  3594,   522,  2570,  1802,  3338,   266,  2314, 
     1290,  3978,   906,  2954,  1674,  3210,   138,  2186,  1162,  3722, 
      650,  2698,  1994,  3530,   458,  2506,  1482,  3914,   842,  2890, 
     1610,  3146,    74,  2122,  1098,  3658,   586,  2634,  1866,  3402, 
      330,  2378,  1354,  4074,  1002,  3050,  1770,  3306,   234,  2282, 
     1258,  3818,   746,  2794,  1962,  3498,   426,  2474,  1450,  3882, 
      810,  2858,  1578,  3114,    42,  2090,  1066,  3626,   554,  2602, 
     1834,  3370,   298,  2346,  1322,  4010,   938,  2986,  1706,  3242, 
      170,  2218,  1194,  3754,   682,  2730,  2047,  3583,   511,  2559, 
     1535,  3967,   895,  2943,  1663,  3199,   127,  2175,  1151,  3711, 
      639,  2687,  1919,  3455,   383,  2431,  1407,  4063,   991,  3039, 
     1759,  3295,   223,  2271,  1247,  3807,   735,  2783,  1951,  3487, 
      415,  2463,  1439,  3871,   799,  2847,  1567,  3103,    31,  2079, 
     1055,  3615,   543,  2591,  1823,  3359,   287,  2335,  1311,  3999, 
      927,  2975,  1695,  3231,   159,  2207,  1183,  3743,   671,  2719, 
     2015,  3551,   479,  2527,  1503,  3935,   863,  2911,  1631,  3167, 
       95,  2143,  1119,  3679,   607,  2655,  1887,  3423,   351,  2399, 
     1375,  4087,  1015,  3063,  1783,  3319,   247,  2295,  1271,  3831, 
      759,  2807,  1975,  3511,   439,  2487,  1463,  3895,   823,  2871, 
     1591,  3127,    55,  2103,  1079,  3639,   567,  2615,  1847,  3383, 
      311,  2359,  1335,  4023,   951,  2999,  1719,  3255,   183,  2231, 
     1207,  3767,   695,  2743,  2023,  3559,   487,  2535,  1511,  3943, 
      871,  2919,  1639,  3175,   103,  2151,  1127,  3687,   615,  2663, 
     1895,  3431,   359,  2407,  1383,  4039,   967,  3015,  1735,  3271, 
      199,  2247,  1223,  3783,   711,  2759,  1927,  3463,   391,  2439, 
     1415,  3847,   775,  2823,  1543,  3079,     7,  2055,  1031,  3591, 
      519,  2567,  1799,  3335,   263,  2311,  1287,  3975,   903,  2951, 
     1671,  3207,   135,  2183,  1159,  3719,   647,  2695,  1991,  3527, 
      455,  2503,  1479,  3911,   839,  2887,  1607,  3143,    71,  2119, 
     1095,  3655,   583,  2631,  1863,  3399,   327,  2375,  1351,  4071, 
      999,  3047,  1767,  3303,   231,  2279,  1255,  3815,   743,  2791, 
     1959,  3495,   423,  2471,  1447,  3879,   807,  2855,  1575,  3111, 
       39,  2087,  1063,  3623,   551,  2599,  1831,  3367,   295,  2343, 
     1319,  4007,   935,  2983,  1703,  3239,   167,  2215,  1191,  3751, 
      679,  2727,  2039,  3575,   503,  2551,  1527,  3959,   887,  2935, 
     1655,  3191,   119,  2167,  1143,  3703,   631,  2679,  1911,  3447, 
      375,  2423,  1399,  4055,   983,  3031,  1751,  3287,   215,  2263, 
     1239,  3799,   727,  2775,  1943,  3479,   407,  2455,  1431,  3863, 
      791,  2839,  1559,  3095,    23,  2071,  1047,  3607,   535,  2583, 
     1815,  3351,   279,  2327,  1303,  3991,   919,  2967,  1687,  3223, 
      151,  2199,  1175,  3735,   663,  2711,  2007,  3543,   471,  2519, 
     1495,  3927,   855,  2903,  1623,  3159,    87,  2135,  1111,  3671, 
      599,  2647,  1879,  3415,   343,  2391,  1367,  4093,  1021,  3069, 
     1789,  3325,   253,  2301,  1277,  3837,   765,  2813,  1981,  3517, 
      445,  2493,  1469,  3901,   829,  2877,  1597,  3133,    61,  2109, 
     1085,  3645,   573,  2621,  1853,  3389,   317,  2365,  1341,  4029, 
      957,  3005,  1725,  3261,   189,  2237,  1213,  3773,   701,  2749, 
     2029,  3565,   493,  2541,  1517,  3949,   877,  2925,  1645,  3181, 
      109,  2157,  1133,  3693,   621,  2669,  1901,  3437,   365,  2413, 
     1389,  4045,   973,  3021,  1741,  3277,   205,  2253,  1229,  3789, 
      717,  2765,  1933,  3469,   397,  2445,  1421,  3853,   781,  2829, 
     1549,  3085,    13,  2061,  1037,  3597,   525,  2573,  1805,  3341, 
      269,  2317,  1293,  3981,   909,  2957,  1677,  3213,   141,  2189, 
     1165,  3725,   653,  2701,  1997,  3533,   461,  2509,  1485,  3917, 
      845,  2893,  1613,  3149,    77,  2125,  1101,  3661,   589,  2637, 
     1869,  3405,   333,  2381,  1357,  4077,  1005,  3053,  1773,  3309, 
      237,  2285,  1261,  3821,   749,  2797,  1965,  3501,   429,  2477, 
     1453,  3885,   813,  2861,  1581,  3117,    45,  2093,  1069,  3629, 
      557,  2605,  1837,  3373,   301,  2349,  1325,  4013,   941,  2989, 
     1709,  3245,   173,  2221,  1197,  3757,   685,  2733,  2041,  3577, 
      505,  2553,  1529,  3961,   889,  2937,  1657,  3193,   121,  2169, 
     1145,  3705,   633,  2681,  1913,  3449,   377,  2425,  1401,  4057, 
      985,  3033,  1753,  3289,   217,  2265,  1241,  3801,   729,  2777, 
     1945,  3481,   409,  2457,  1433,  3865,   793,  2841,  1561,  3097, 
       25,  2073,  1049,  3609,   537,  2585,  1817,  3353,   281,  2329, 
     1305,  3993,   921,  2969,  1689,  3225,   153,  2201,  1177,  3737, 
      665,  2713,  2009,  3545,   473,  2521,  1497,  3929,   857,  2905, 
     1625,  3161,    89,  2137,  1113,  3673,   601,  2649,  1881,  3417, 
      345,  2393,  1369,  4081,  1009,  3057,  1777,  3313,   241,  2289, 
     1265,  3825,   753,  2801,  1969,  3505,   433,  2481,  1457,  3889, 
      817,  2865,  1585,  3121,    49,  2097,  1073,  3633,   561,  2609, 
     1841,  3377,   305,  2353,  1329,  4017,   945,  2993,  1713,  3249, 
      177,  2225,  1201,  3761,   689,  2737,  2017,  3553,   481,  2529, 
     1505,  3937,   865,  2913,  1633,  3169,    97,  2145,  1121,  3681, 
      609,  2657,  1889,  3425,   353,  2401,  1377,  4033,   961,  3009, 
     1729,  3265,   193,  2241,  1217,  3777,   705,  2753,  1921,  3457, 
      385,  2433,  1409,  3841,   769,  2817,  1537,  3073,     1,  2049, 
     1025,  3585,   513,  2561,  1793,  3329,   257,  2305,  1281,  3969, 
      897,  2945,  1665,  3201,   129,  2177,  1153,  3713,   641,  2689, 
     1985,  3521,   449,  2497,  1473,  3905,   833,  2881,  1601,  3137, 
       65,  2113,  1089,  3649,   577,  2625,  1857,  3393,   321,  2369, 
     1345,  4065,   993,  3041,  1761,  3297,   225,  2273,  1249,  3809, 
      737,  2785,  1953,  3489,   417,  2465,  1441,  3873,   801,  2849, 
     1569,  3105,    33,  2081,  1057,  3617,   545,  2593,  1825,  3361, 
      289,  2337,  1313,  4001,   929,  2977,  1697,  3233,   161,  2209, 
     1185,  3745,   673,  2721,  2033,  3569,   497,  2545,  1521,  3953, 
      881,  2929,  1649,  3185,   113,  2161,  1137,  3697,   625,  2673, 
     1905,  3441,   369,  2417,  1393,  4049,   977,  3025,  1745,  3281, 
      209,  2257,  1233,  3793,   721,  2769,  1937,  3473,   401,  2449, 
     1425,  3857,   785,  2833,  1553,  3089,    17,  2065,  1041,  3601, 
      529,  2577,  1809,  3345,   273,  2321,  1297,  3985,   913,  2961, 
     1681,  3217,   145,  2193,  1169,  3729,   657,  2705,  2001,  3537, 
      465,  2513,  1489,  3921,   849,  2897,  1617,  3153,    81,  2129, 
     1105,  3665,   593,  2641,  1873,  3409,   337,  2385,  1361,  4089, 
     1017,  3065,  1785,  3321,   249,  2297,  1273,  3833,   761,  2809, 
     1977,  3513,   441,  2489,  1465,  3897,   825,  2873,  1593,  3129, 
       57,  2105,  1081,  3641,   569,  2617,  1849,  3385,   313,  2361, 
     1337,  4025,   953,  3001,  1721,  3257,   185,  2233,  1209,  3769, 
      697,  2745,  2025,  3561,   489,  2537,  1513,  3945,   873,  2921, 
     1641,  3177,   105,  2153,  1129,  3689,   617,  2665,  1897,  3433, 
      361,  2409,  1385,  4041,   969,  3017,  1737,  3273,   201,  2249, 
     1225,  3785,   713,  2761,  1929,  3465,   393,  2441,  1417,  3849, 
      777,  2825,  1545,  3081,     9,  2057,  1033,  3593,   521,  2569, 
     1801,  3337,   265,  2313,  1289,  3977,   905,  2953,  1673,  3209, 
      137,  2185,  1161,  3721,   649,  2697,  1993,  3529,   457,  2505, 
     1481,  3913,   841,  2889,  1609,  3145,    73,  2121,  1097,  3657, 
      585,  2633,  1865,  3401,   329,  2377,  1353,  4073,  1001,  3049, 
     1769,  3305,   233,  2281,  1257,  3817,   745,  2793,  1961,  3497, 
      425,  2473,  1449,  3881,   809,  2857,  1577,  3113,    41,  2089, 
     1065,  3625,   553,  2601,  1833,  3369,   297,  2345,  1321,  4009, 
      937,  2985,  1705,  3241,   169,  2217,  1193,  3753,   681,  2729, 
     2045,  3581,   509,  2557,  1533,  3965,   893,  2941,  1661,  3197, 
      125,  2173,  1149,  3709,   637,  2685,  1917,  3453,   381,  2429, 
     1405,  4061,   989,  3037,  1757,  3293,   221,  2269,  1245,  3805, 
      733,  2781,  1949,  3485,   413,  2461,  1437,  3869,   797,  2845, 
     1565,  3101,    29,  2077,  1053,  3613,   541,  2589,  1821,  3357, 
      285,  2333,  1309,  3997,   925,  2973,  1693,  3229,   157,  2205, 
     1181,  3741,   669,  2717,  2013,  3549,   477,  2525,  1501,  3933, 
      861,  2909,  1629,  3165,    93,  2141,  1117,  3677,   605,  2653, 
     1885,  3421,   349,  2397,  1373,  4085,  1013,  3061,  1781,  3317, 
      245,  2293,  1269,  3829,   757,  2805,  1973,  3509,   437,  2485, 
     1461,  3893,   821,  2869,  1589,  3125,    53,  2101,  1077,  3637, 
      565,  2613,  1845,  3381,   309,  2357,  1333,  4021,   949,  2997, 
     1717,  3253,   181,  2229,  1205,  3765,   693,  2741,  2021,  3557, 
      485,  2533,  1509,  3941,   869,  2917,  1637,  3173,   101,  2149, 
     1125,  3685,   613,  2661,  1893,  3429,   357,  2405,  1381,  4037, 
      965,  3013,  1733,  3269,   197,  2245,  1221,  3781,   709,  2757, 
     1925,  3461,   389,  2437,  1413,  3845,   773,  2821,  1541,  3077, 
        5,  2053,  1029,  3589,   517,  2565,  1797,  3333,   261,  2309, 
     1285,  3973,   901,  2949,  1669,  3205,   133,  2181,  1157,  3717, 
      645,  2693,  1989,  3525,   453,  2501,  1477,  3909,   837,  2885, 
     1605,  3141,    69,  2117,  1093,  3653,   581,  2629,  1861,  3397, 
      325,  2373,  1349,  4069,   997,  3045,  1765,  3301,   229,  2277, 
     1253,  3813,   741,  2789,  1957,  3493,   421,  2469,  1445,  3877, 
      805,  2853,  1573,  3109,    37,  2085,  1061,  3621,   549,  2597, 
     1829,  3365,   293,  2341,  1317,  4005,   933,  2981,  1701,  3237, 
      165,  2213,  1189,  3749,   677,  2725,  2037,  3573,   501,  2549, 
     1525,  3957,   885,  2933,  1653,  3189,   117,  2165,  1141,  3701, 
      629,  2677,  1909,  3445,   373,  2421,  1397,  4053,   981,  3029, 
     1749,  3285,   213,  2261,  1237,  3797,   725,  2773,  1941,  3477, 
      405,  2453,  1429,  3861,   789,  2837,  1557,  3093,    21,  2069, 
     1045,  3605,   533,  2581,  1813,  3349,   277,  2325,  1301,  3989, 
      917,  2965,  1685,  3221,   149,  2197,  1173,  3733,   661,  2709, 
     2005,  3541,   469,  2517,  1493,  3925,   853,  2901,  1621,  3157, 
       85,  2133,  1109,  3669,   597,  2645,  1877,  3413,   341,  2389, 
     1365,  4095,  1023,  3071,  1791,  3327,   255,  2303,  1279,  3839, 
      767,  2815,  1983,  3519,   447,  2495,  1471,  3903,   831,  2879, 
     1599,  3135,    63,  2111,  1087,  3647,   575,  2623,  1855,  3391, 
      319,  2367,  1343,  4031,   959,  3007,  1727,  3263,   191,  2239, 
     1215,  3775,   703,  2751,  2031,  3567,   495,  2543,  1519,  3951, 
      879,  2927,  1647,  3183,   111,  2159,  1135,  3695,   623,  2671, 
     1903,  3439,   367,  2415,  1391,  4047,   975,  3023,  1743,  3279, 
      207,  2255,  1231,  3791,   719,  2767,  1935,  3471,   399,  2447, 
     1423,  3855,   783,  2831,  1551,  3087,    15,  2063,  1039,  3599, 
      527,  2575,  1807,  3343,   271,  2319,  1295,  3983,   911,  2959, 
     1679,  3215,   143,  2191,  1167,  3727,   655,  2703,  1999,  3535, 
      463,  2511,  1487,  3919,   847,  2895,  1615,  3151,    79,  2127, 
     1103,  3663,   591,  2639,  1871,  3407,   335,  2383,  1359,  4079, 
     1007,  3055,  1775,  3311,   239,  2287,  1263,  3823,   751,  2799, 
     1967,  3503,   431,  2479,  1455,  3887,   815,  2863,  1583,  3119, 
       47,  2095,  1071,  3631,   559,  2607,  1839,  3375,   303,  2351, 
     1327,  4015,   943,  2991,  1711,  3247,   175,  2223,  1199,  3759, 
      687,  2735,  2043,  3579,   507,  2555,  1531,  3963,   891,  2939, 
     1659,  3195,   123,  2171,  1147,  3707,   635,  2683,  1915,  3451, 
      379,  2427,  1403,  4059,   987,  3035,  1755,  3291,   219,  2267, 
     1243,  3803,   731,  2779,  1947,  3483,   411,  2459,  1435,  3867, 
      795,  2843,  1563,  3099,    27,  2075,  1051,  3611,   539,  2587, 
     1819,  3355,   283,  2331,  1307,  3995,   923,  2971,  1691,  3227, 
      155,  2203,  1179,  3739,   667,  2715,  2011,  3547,   475,  2523, 
     1499,  3931,   859,  2907,  1627,  3163,    91,  2139,  1115,  3675, 
      603,  2651,  1883,  3419,   347,  2395,  1371,  4083,  1011,  3059, 
     1779,  3315,   243,  2291,  1267,  3827,   755,  2803,  1971,  3507, 
      435,  2483,  1459,  3891,   819,  2867,  1587,  3123,    51,  2099, 
     1075,  3635,   563,  2611,  1843,  3379,   307,  2355,  1331,  4019, 
      947,  2995,  1715,  3251,   179,  2227,  1203,  3763,   691,  2739, 
     2019,  3555,   483,  2531,  1507,  3939,   867,  2915,  1635,  3171, 
       99,  2147,  1123,  3683,   611,  2659,  1891,  3427,   355,  2403, 
     1379,  4035,   963,  3011,  1731,  3267,   195,  2243,  1219,  3779, 
      707,  2755,  1923,  3459,   387,  2435,  1411,  3843,   771,  2819, 
     1539,  3075,     3,  2051,  1027,  3587,   515,  2563,  1795,  3331, 
      259,  2307,  1283,  3971,   899,  2947,  1667,  3203,   131,  2179, 
     1155,  3715,   643,  2691,  1987,  3523,   451,  2499,  1475,  3907, 
      835,  2883,  1603,  3139,    67,  2115,  1091,  3651,   579,  2627, 
     1859,  3395,   323,  2371,  1347,  4067,   995,  3043,  1763,  3299, 
      227,  2275,  1251,  3811,   739,  2787,  1955,  3491,   419,  2467, 
     1443,  3875,   803,  2851,  1571,  3107,    35,  2083,  1059,  3619, 
      547,  2595,  1827,  3363,   291,  2339,  1315,  4003,   931,  2979, 
     1699,  3235,   163,  2211,  1187,  3747,   675,  2723,  2035,  3571, 
      499,  2547,  1523,  3955,   883,  2931,  1651,  3187,   115,  2163, 
     1139,  3699,   627,  2675,  1907,  3443,   371,  2419,  1395,  4051, 
      979,  3027,  1747,  3283,   211,  2259,  1235,  3795,   723,  2771, 
     1939,  3475,   403,  2451,  1427,  3859,   787,  2835,  1555,  3091, 
       19,  2067,  1043,  3603,   531,  2579,  1811,  3347,   275,  2323, 
     1299,  3987,   915,  2963,  1683,  3219,   147,  2195,  1171,  3731, 
      659,  2707,  2003,  3539,   467,  2515,  1491,  3923,   851,  2899, 
     1619,  3155,    83,  2131,  1107,  3667,   595,  2643,  1875,  3411, 
      339,  2387,  1363,  4091,  1019,  3067,  1787,  3323,   251,  2299, 
     1275,  3835,   763,  2811,  1979,  3515,   443,  2491,  1467,  3899, 
      827,  2875,  1595,  3131,    59,  2107,  1083,  3643,   571,  2619, 
     1851,  3387,   315,  2363,  1339,  4027,   955,  3003,  1723,  3259, 
      187,  2235,  1211,  3771,   699,  2747,  2027,  3563,   491,  2539, 
     1515,  3947,   875,  2923,  1643,  3179,   107,  2155,  1131,  3691, 
      619,  2667,  1899,  3435,   363,  2411,  1387,  4043,   971,  3019, 
     1739,  3275,   203,  2251,  1227,  3787,   715,  2763,  1931,  3467, 
      395,  2443,  1419,  3851,   779,  2827,  1547,  3083,    11,  2059, 
     1035,  3595,   523,  2571,  1803,  3339,   267,  2315,  1291,  3979, 
      907,  2955,  1675,  3211,   139,  2187,  1163,  3723,   651,  2699, 
     1995,  3531,   459,  2507,  1483,  3915,   843,  2891,  1611,  3147, 
       75,  2123,  1099,  3659,   587,  2635,  1867,  3403,   331,  2379, 
     1355,  4075,  1003,  3051,  1771,  3307,   235,  2283,  1259,  3819, 
      747,  2795,  1963,  3499,   427,  2475,  1451,  3883,   811,  2859, 
     1579,  3115,    43,  2091,  1067,  3627,   555,  2603,  1835,  3371, 
      299,  2347,  1323,  4011,   939,  2987,  1707,  3243,   171,  2219, 
     1195,  3755,   683,  2731,  2046,  3582,   510,  2558,  1534,  3966, 
      894,  2942,  1662,  3198,   126,  2174,  1150,  3710,   638,  2686, 
     1918,  3454,   382,  2430,  1406,  4062,   990,  3038,  1758,  3294, 
      222,  2270,  1246,  3806,   734,  2782,  1950,  3486,   414,  2462, 
     1438,  3870,   798,  2846,  1566,  3102,    30,  2078,  1054,  3614, 
      542,  2590,  1822,  3358,   286,  2334,  1310,  3998,   926,  2974, 
     1694,  3230,   158,  2206,  1182,  3742,   670,  2718,  2014,  3550, 
      478,  2526,  1502,  3934,   862,  2910,  1630,  3166,    94,  2142, 
     1118,  3678,   606,  2654,  1886,  3422,   350,  2398,  1374,  4086, 
     1014,  3062,  1782,  3318,   246,  2294,  1270,  3830,   758,  2806, 
     1974,  3510,   438,  2486,  1462,  3894,   822,  2870,  1590,  3126, 
       54,  2102,  1078,  3638,   566,  2614,  1846,  3382,   310,  2358, 
     1334,  4022,   950,  2998,  1718,  3254,   182,  2230,  1206,  3766, 
      694,  2742,  2022,  3558,   486,  2534,  1510,  3942,   870,  2918, 
     1638,  3174,   102,  2150,  1126,  3686,   614,  2662,  1894,  3430, 
      358,  2406,  1382,  4038,   966,  3014,  1734,  3270,   198,  2246, 
     1222,  3782,   710,  2758,  1926,  3462,   390,  2438,  1414,  3846, 
      774,  2822,  1542,  3078,     6,  2054,  1030,  3590,   518,  2566, 
     1798,  3334,   262,  2310,  1286,  3974,   902,  2950,  1670,  3206, 
      134,  2182,  1158,  3718,   646,  2694,  1990,  3526,   454,  2502, 
     1478,  3910,   838,  2886,  1606,  3142,    70,  2118,  1094,  3654, 
      582,  2630,  1862,  3398,   326,  2374,  1350,  4070,   998,  3046, 
     1766,  3302,   230,  2278,  1254,  3814,   742,  2790,  1958,  3494, 
      422,  2470,  1446,  3878,   806,  2854,  1574,  3110,    38,  2086, 
     1062,  3622,   550,  2598,  1830,  3366,   294,  2342,  1318,  4006, 
      934,  2982,  1702,  3238,   166,  2214,  1190,  3750,   678,  2726, 
     2038,  3574,   502,  2550,  1526,  3958,   886,  2934,  1654,  3190, 
      118,  2166,  1142,  3702,   630,  2678,  1910,  3446,   374,  2422, 
     1398,  4054,   982,  3030,  1750,  3286,   214,  2262,  1238,  3798, 
      726,  2774,  1942,  3478,   406,  2454,  1430,  3862,   790,  2838, 
     1558,  3094,    22,  2070,  1046,  3606,   534,  2582,  1814,  3350, 
      278,  2326,  1302,  3990,   918,  2966,  1686,  3222,   150,  2198, 
     1174,  3734,   662,  2710,  2006,  3542,   470,  2518,  1494,  3926, 
      854,  2902,  1622,  3158,    86,  2134,  1110,  3670,   598,  2646, 
     1878,  3414,   342,  2390,  1366,  4092,  1020,  3068,  1788,  3324, 
      252,  2300,  1276,  3836,   764,  2812,  1980,  3516,   444,  2492, 
     1468,  3900,   828,  2876,  1596,  3132,    60,  2108,  1084,  3644, 
      572,  2620,  1852,  3388,   316,  2364,  1340,  4028,   956,  3004, 
     1724,  3260,   188,  2236,  1212,  3772,   700,  2748,  2028,  3564, 
      492,  2540,  1516,  3948,   876,  2924,  1644,  3180,   108,  2156, 
     1132,  3692,   620,  2668,  1900,  3436,   364,  2412,  1388,  4044, 
      972,  3020,  1740,  3276,   204,  2252,  1228,  3788,   716,  2764, 
     1932,  3468,   396,  2444,  1420,  3852,   780,  2828,  1548,  3084, 
       12,  2060,  1036,  3596,   524,  2572,  1804,  3340,   268,  2316, 
     1292,  3980,   908,  2956,  1676,  3212,   140,  2188,  1164,  3724, 
      652,  2700,  1996,  3532,   460,  2508,  1484,  3916,   844,  2892, 
     1612,  3148,    76,  2124,  1100,  3660,   588,  2636,  1868,  3404, 
      332,  2380,  1356,  4076,  1004,  3052,  1772,  3308,   236,  2284, 
     1260,  3820,   748,  2796,  1964,  3500,   428,  2476,  1452,  3884, 
      812,  2860,  1580,  3116,    44,  2092,  1068,  3628,   556,  2604, 
     1836,  3372,   300,  2348,  1324,  4012,   940,  2988,  1708,  3244, 
      172,  2220,  1196,  3756,   684,  2732,  2040,  3576,   504,  2552, 
     1528,  3960,   888,  2936,  1656,  3192,   120,  2168,  1144,  3704, 
      632,  2680,  1912,  3448,   376,  2424,  1400,  4056,   984,  3032, 
     1752,  3288,   216,  2264,  1240,  3800,   728,  2776,  1944,  3480, 
      408,  2456,  1432,  3864,   792,  2840,  1560,  3096,    24,  2072, 
     1048,  3608,   536,  2584,  1816,  3352,   280,  2328,  1304,  3992, 
      920,  2968,  1688,  3224,   152,  2200,  1176,  3736,   664,  2712, 
     2008,  3544,   472,  2520,  1496,  3928,   856,  2904,  1624,  3160, 
       88,  2136,  1112,  3672,   600,  2648,  1880,  3416,   344,  2392, 
     1368,  4080,  1008,  3056,  1776,  3312,   240,  2288,  1264,  3824, 
      752,  2800,  1968,  3504,   432,  2480,  1456,  3888,   816,  2864, 
     1584,  3120,    48,  2096,  1072,  3632,   560,  2608,  1840,  3376, 
      304,  2352,  1328,  4016,   944,  2992,  1712,  3248,   176,  2224, 
     1200,  3760,   688,  2736,  2016,  3552,   480,  2528,  1504,  3936, 
      864,  2912,  1632,  3168,    96,  2144,  1120,  3680,   608,  2656, 
     1888,  3424,   352,  2400,  1376,  4032,   960,  3008,  1728,  3264, 
      192,  2240,  1216,  3776,   704,  2752,  1920,  3456,   384,  2432, 
     1408,  3840,   768,  2816,  1536,  3072
  );
  RevBits8192: array[0..8191] of WORD = (
        0,  4096,  2048,  7168,  1024,  5120,  3584,  6656,   512,  4608, 
     2560,  7936,  1792,  5888,  3328,  6400,   256,  4352,  2304,  7424, 
     1280,  5376,  3968,  7040,   896,  4992,  2944,  7808,  1664,  5760, 
     3200,  6272,   128,  4224,  2176,  7296,  1152,  5248,  3712,  6784, 
      640,  4736,  2688,  8128,  1984,  6080,  3520,  6592,   448,  4544, 
     2496,  7616,  1472,  5568,  3904,  6976,   832,  4928,  2880,  7744, 
     1600,  5696,  3136,  6208,    64,  4160,  2112,  7232,  1088,  5184, 
     3648,  6720,   576,  4672,  2624,  8000,  1856,  5952,  3392,  6464, 
      320,  4416,  2368,  7488,  1344,  5440,  4064,  7136,   992,  5088, 
     3040,  7904,  1760,  5856,  3296,  6368,   224,  4320,  2272,  7392, 
     1248,  5344,  3808,  6880,   736,  4832,  2784,  8096,  1952,  6048, 
     3488,  6560,   416,  4512,  2464,  7584,  1440,  5536,  3872,  6944, 
      800,  4896,  2848,  7712,  1568,  5664,  3104,  6176,    32,  4128, 
     2080,  7200,  1056,  5152,  3616,  6688,   544,  4640,  2592,  7968, 
     1824,  5920,  3360,  6432,   288,  4384,  2336,  7456,  1312,  5408, 
     4000,  7072,   928,  5024,  2976,  7840,  1696,  5792,  3232,  6304, 
      160,  4256,  2208,  7328,  1184,  5280,  3744,  6816,   672,  4768, 
     2720,  8176,  2032,  6128,  3568,  6640,   496,  4592,  2544,  7664, 
     1520,  5616,  3952,  7024,   880,  4976,  2928,  7792,  1648,  5744, 
     3184,  6256,   112,  4208,  2160,  7280,  1136,  5232,  3696,  6768, 
      624,  4720,  2672,  8048,  1904,  6000,  3440,  6512,   368,  4464, 
     2416,  7536,  1392,  5488,  4048,  7120,   976,  5072,  3024,  7888, 
     1744,  5840,  3280,  6352,   208,  4304,  2256,  7376,  1232,  5328, 
     3792,  6864,   720,  4816,  2768,  8080,  1936,  6032,  3472,  6544, 
      400,  4496,  2448,  7568,  1424,  5520,  3856,  6928,   784,  4880, 
     2832,  7696,  1552,  5648,  3088,  6160,    16,  4112,  2064,  7184, 
     1040,  5136,  3600,  6672,   528,  4624,  2576,  7952,  1808,  5904, 
     3344,  6416,   272,  4368,  2320,  7440,  1296,  5392,  3984,  7056, 
      912,  5008,  2960,  7824,  1680,  5776,  3216,  6288,   144,  4240, 
     2192,  7312,  1168,  5264,  3728,  6800,   656,  4752,  2704,  8144, 
     2000,  6096,  3536,  6608,   464,  4560,  2512,  7632,  1488,  5584, 
     3920,  6992,   848,  4944,  2896,  7760,  1616,  5712,  3152,  6224, 
       80,  4176,  2128,  7248,  1104,  5200,  3664,  6736,   592,  4688, 
     2640,  8016,  1872,  5968,  3408,  6480,   336,  4432,  2384,  7504, 
     1360,  5456,  4088,  7160,  1016,  5112,  3064,  7928,  1784,  5880, 
     3320,  6392,   248,  4344,  2296,  7416,  1272,  5368,  3832,  6904, 
      760,  4856,  2808,  8120,  1976,  6072,  3512,  6584,   440,  4536, 
     2488,  7608,  1464,  5560,  3896,  6968,   824,  4920,  2872,  7736, 
     1592,  5688,  3128,  6200,    56,  4152,  2104,  7224,  1080,  5176, 
     3640,  6712,   568,  4664,  2616,  7992,  1848,  5944,  3384,  6456, 
      312,  4408,  2360,  7480,  1336,  5432,  4024,  7096,   952,  5048, 
     3000,  7864,  1720,  5816,  3256,  6328,   184,  4280,  2232,  7352, 
     1208,  5304,  3768,  6840,   696,  4792,  2744,  8168,  2024,  6120, 
     3560,  6632,   488,  4584,  2536,  7656,  1512,  5608,  3944,  7016, 
      872,  4968,  2920,  7784,  1640,  5736,  3176,  6248,   104,  4200, 
     2152,  7272,  1128,  5224,  3688,  6760,   616,  4712,  2664,  8040, 
     1896,  5992,  3432,  6504,   360,  4456,  2408,  7528,  1384,  5480, 
     4040,  7112,   968,  5064,  3016,  7880,  1736,  5832,  3272,  6344, 
      200,  4296,  2248,  7368,  1224,  5320,  3784,  6856,   712,  4808, 
     2760,  8072,  1928,  6024,  3464,  6536,   392,  4488,  2440,  7560, 
     1416,  5512,  3848,  6920,   776,  4872,  2824,  7688,  1544,  5640, 
     3080,  6152,     8,  4104,  2056,  7176,  1032,  5128,  3592,  6664, 
      520,  4616,  2568,  7944,  1800,  5896,  3336,  6408,   264,  4360, 
     2312,  7432,  1288,  5384,  3976,  7048,   904,  5000,  2952,  7816, 
     1672,  5768,  3208,  6280,   136,  4232,  2184,  7304,  1160,  5256, 
     3720,  6792,   648,  4744,  2696,  8136,  1992,  6088,  3528,  6600, 
      456,  4552,  2504,  7624,  1480,  5576,  3912,  6984,   840,  4936, 
     2888,  7752,  1608,  5704,  3144,  6216,    72,  4168,  2120,  7240, 
     1096,  5192,  3656,  6728,   584,  4680,  2632,  8008,  1864,  5960, 
     3400,  6472,   328,  4424,  2376,  7496,  1352,  5448,  4072,  7144, 
     1000,  5096,  3048,  7912,  1768,  5864,  3304,  6376,   232,  4328, 
     2280,  7400,  1256,  5352,  3816,  6888,   744,  4840,  2792,  8104, 
     1960,  6056,  3496,  6568,   424,  4520,  2472,  7592,  1448,  5544, 
     3880,  6952,   808,  4904,  2856,  7720,  1576,  5672,  3112,  6184, 
       40,  4136,  2088,  7208,  1064,  5160,  3624,  6696,   552,  4648, 
     2600,  7976,  1832,  5928,  3368,  6440,   296,  4392,  2344,  7464, 
     1320,  5416,  4008,  7080,   936,  5032,  2984,  7848,  1704,  5800, 
     3240,  6312,   168,  4264,  2216,  7336,  1192,  5288,  3752,  6824, 
      680,  4776,  2728,  8188,  2044,  6140,  3580,  6652,   508,  4604, 
     2556,  7676,  1532,  5628,  3964,  7036,   892,  4988,  2940,  7804, 
     1660,  5756,  3196,  6268,   124,  4220,  2172,  7292,  1148,  5244, 
     3708,  6780,   636,  4732,  2684,  8060,  1916,  6012,  3452,  6524, 
      380,  4476,  2428,  7548,  1404,  5500,  4060,  7132,   988,  5084, 
     3036,  7900,  1756,  5852,  3292,  6364,   220,  4316,  2268,  7388, 
     1244,  5340,  3804,  6876,   732,  4828,  2780,  8092,  1948,  6044, 
     3484,  6556,   412,  4508,  2460,  7580,  1436,  5532,  3868,  6940, 
      796,  4892,  2844,  7708,  1564,  5660,  3100,  6172,    28,  4124, 
     2076,  7196,  1052,  5148,  3612,  6684,   540,  4636,  2588,  7964, 
     1820,  5916,  3356,  6428,   284,  4380,  2332,  7452,  1308,  5404, 
     3996,  7068,   924,  5020,  2972,  7836,  1692,  5788,  3228,  6300, 
      156,  4252,  2204,  7324,  1180,  5276,  3740,  6812,   668,  4764, 
     2716,  8156,  2012,  6108,  3548,  6620,   476,  4572,  2524,  7644, 
     1500,  5596,  3932,  7004,   860,  4956,  2908,  7772,  1628,  5724, 
     3164,  6236,    92,  4188,  2140,  7260,  1116,  5212,  3676,  6748, 
      604,  4700,  2652,  8028,  1884,  5980,  3420,  6492,   348,  4444, 
     2396,  7516,  1372,  5468,  4084,  7156,  1012,  5108,  3060,  7924, 
     1780,  5876,  3316,  6388,   244,  4340,  2292,  7412,  1268,  5364, 
     3828,  6900,   756,  4852,  2804,  8116,  1972,  6068,  3508,  6580, 
      436,  4532,  2484,  7604,  1460,  5556,  3892,  6964,   820,  4916, 
     2868,  7732,  1588,  5684,  3124,  6196,    52,  4148,  2100,  7220, 
     1076,  5172,  3636,  6708,   564,  4660,  2612,  7988,  1844,  5940, 
     3380,  6452,   308,  4404,  2356,  7476,  1332,  5428,  4020,  7092, 
      948,  5044,  2996,  7860,  1716,  5812,  3252,  6324,   180,  4276, 
     2228,  7348,  1204,  5300,  3764,  6836,   692,  4788,  2740,  8164, 
     2020,  6116,  3556,  6628,   484,  4580,  2532,  7652,  1508,  5604, 
     3940,  7012,   868,  4964,  2916,  7780,  1636,  5732,  3172,  6244, 
      100,  4196,  2148,  7268,  1124,  5220,  3684,  6756,   612,  4708, 
     2660,  8036,  1892,  5988,  3428,  6500,   356,  4452,  2404,  7524, 
     1380,  5476,  4036,  7108,   964,  5060,  3012,  7876,  1732,  5828, 
     3268,  6340,   196,  4292,  2244,  7364,  1220,  5316,  3780,  6852, 
      708,  4804,  2756,  8068,  1924,  6020,  3460,  6532,   388,  4484, 
     2436,  7556,  1412,  5508,  3844,  6916,   772,  4868,  2820,  7684, 
     1540,  5636,  3076,  6148,     4,  4100,  2052,  7172,  1028,  5124, 
     3588,  6660,   516,  4612,  2564,  7940,  1796,  5892,  3332,  6404, 
      260,  4356,  2308,  7428,  1284,  5380,  3972,  7044,   900,  4996, 
     2948,  7812,  1668,  5764,  3204,  6276,   132,  4228,  2180,  7300, 
     1156,  5252,  3716,  6788,   644,  4740,  2692,  8132,  1988,  6084, 
     3524,  6596,   452,  4548,  2500,  7620,  1476,  5572,  3908,  6980, 
      836,  4932,  2884,  7748,  1604,  5700,  3140,  6212,    68,  4164, 
     2116,  7236,  1092,  5188,  3652,  6724,   580,  4676,  2628,  8004, 
     1860,  5956,  3396,  6468,   324,  4420,  2372,  7492,  1348,  5444, 
     4068,  7140,   996,  5092,  3044,  7908,  1764,  5860,  3300,  6372, 
      228,  4324,  2276,  7396,  1252,  5348,  3812,  6884,   740,  4836, 
     2788,  8100,  1956,  6052,  3492,  6564,   420,  4516,  2468,  7588, 
     1444,  5540,  3876,  6948,   804,  4900,  2852,  7716,  1572,  5668, 
     3108,  6180,    36,  4132,  2084,  7204,  1060,  5156,  3620,  6692, 
      548,  4644,  2596,  7972,  1828,  5924,  3364,  6436,   292,  4388, 
     2340,  7460,  1316,  5412,  4004,  7076,   932,  5028,  2980,  7844, 
     1700,  5796,  3236,  6308,   164,  4260,  2212,  7332,  1188,  5284, 
     3748,  6820,   676,  4772,  2724,  8180,  2036,  6132,  3572,  6644, 
      500,  4596,  2548,  7668,  1524,  5620,  3956,  7028,   884,  4980, 
     2932,  7796,  1652,  5748,  3188,  6260,   116,  4212,  2164,  7284, 
     1140,  5236,  3700,  6772,   628,  4724,  2676,  8052,  1908,  6004, 
     3444,  6516,   372,  4468,  2420,  7540,  1396,  5492,  4052,  7124, 
      980,  5076,  3028,  7892,  1748,  5844,  3284,  6356,   212,  4308, 
     2260,  7380,  1236,  5332,  3796,  6868,   724,  4820,  2772,  8084, 
     1940,  6036,  3476,  6548,   404,  4500,  2452,  7572,  1428,  5524, 
     3860,  6932,   788,  4884,  2836,  7700,  1556,  5652,  3092,  6164, 
       20,  4116,  2068,  7188,  1044,  5140,  3604,  6676,   532,  4628, 
     2580,  7956,  1812,  5908,  3348,  6420,   276,  4372,  2324,  7444, 
     1300,  5396,  3988,  7060,   916,  5012,  2964,  7828,  1684,  5780, 
     3220,  6292,   148,  4244,  2196,  7316,  1172,  5268,  3732,  6804, 
      660,  4756,  2708,  8148,  2004,  6100,  3540,  6612,   468,  4564, 
     2516,  7636,  1492,  5588,  3924,  6996,   852,  4948,  2900,  7764, 
     1620,  5716,  3156,  6228,    84,  4180,  2132,  7252,  1108,  5204, 
     3668,  6740,   596,  4692,  2644,  8020,  1876,  5972,  3412,  6484, 
      340,  4436,  2388,  7508,  1364,  5460,  4094,  7166,  1022,  5118, 
     3070,  7934,  1790,  5886,  3326,  6398,   254,  4350,  2302,  7422, 
     1278,  5374,  3838,  6910,   766,  4862,  2814,  8126,  1982,  6078, 
     3518,  6590,   446,  4542,  2494,  7614,  1470,  5566,  3902,  6974, 
      830,  4926,  2878,  7742,  1598,  5694,  3134,  6206,    62,  4158, 
     2110,  7230,  1086,  5182,  3646,  6718,   574,  4670,  2622,  7998, 
     1854,  5950,  3390,  6462,   318,  4414,  2366,  7486,  1342,  5438, 
     4030,  7102,   958,  5054,  3006,  7870,  1726,  5822,  3262,  6334, 
      190,  4286,  2238,  7358,  1214,  5310,  3774,  6846,   702,  4798, 
     2750,  8174,  2030,  6126,  3566,  6638,   494,  4590,  2542,  7662, 
     1518,  5614,  3950,  7022,   878,  4974,  2926,  7790,  1646,  5742, 
     3182,  6254,   110,  4206,  2158,  7278,  1134,  5230,  3694,  6766, 
      622,  4718,  2670,  8046,  1902,  5998,  3438,  6510,   366,  4462, 
     2414,  7534,  1390,  5486,  4046,  7118,   974,  5070,  3022,  7886, 
     1742,  5838,  3278,  6350,   206,  4302,  2254,  7374,  1230,  5326, 
     3790,  6862,   718,  4814,  2766,  8078,  1934,  6030,  3470,  6542, 
      398,  4494,  2446,  7566,  1422,  5518,  3854,  6926,   782,  4878, 
     2830,  7694,  1550,  5646,  3086,  6158,    14,  4110,  2062,  7182, 
     1038,  5134,  3598,  6670,   526,  4622,  2574,  7950,  1806,  5902, 
     3342,  6414,   270,  4366,  2318,  7438,  1294,  5390,  3982,  7054, 
      910,  5006,  2958,  7822,  1678,  5774,  3214,  6286,   142,  4238, 
     2190,  7310,  1166,  5262,  3726,  6798,   654,  4750,  2702,  8142, 
     1998,  6094,  3534,  6606,   462,  4558,  2510,  7630,  1486,  5582, 
     3918,  6990,   846,  4942,  2894,  7758,  1614,  5710,  3150,  6222, 
       78,  4174,  2126,  7246,  1102,  5198,  3662,  6734,   590,  4686, 
     2638,  8014,  1870,  5966,  3406,  6478,   334,  4430,  2382,  7502, 
     1358,  5454,  4078,  7150,  1006,  5102,  3054,  7918,  1774,  5870, 
     3310,  6382,   238,  4334,  2286,  7406,  1262,  5358,  3822,  6894, 
      750,  4846,  2798,  8110,  1966,  6062,  3502,  6574,   430,  4526, 
     2478,  7598,  1454,  5550,  3886,  6958,   814,  4910,  2862,  7726, 
     1582,  5678,  3118,  6190,    46,  4142,  2094,  7214,  1070,  5166, 
     3630,  6702,   558,  4654,  2606,  7982,  1838,  5934,  3374,  6446, 
      302,  4398,  2350,  7470,  1326,  5422,  4014,  7086,   942,  5038, 
     2990,  7854,  1710,  5806,  3246,  6318,   174,  4270,  2222,  7342, 
     1198,  5294,  3758,  6830,   686,  4782,  2734,  8186,  2042,  6138, 
     3578,  6650,   506,  4602,  2554,  7674,  1530,  5626,  3962,  7034, 
      890,  4986,  2938,  7802,  1658,  5754,  3194,  6266,   122,  4218, 
     2170,  7290,  1146,  5242,  3706,  6778,   634,  4730,  2682,  8058, 
     1914,  6010,  3450,  6522,   378,  4474,  2426,  7546,  1402,  5498, 
     4058,  7130,   986,  5082,  3034,  7898,  1754,  5850,  3290,  6362, 
      218,  4314,  2266,  7386,  1242,  5338,  3802,  6874,   730,  4826, 
     2778,  8090,  1946,  6042,  3482,  6554,   410,  4506,  2458,  7578, 
     1434,  5530,  3866,  6938,   794,  4890,  2842,  7706,  1562,  5658, 
     3098,  6170,    26,  4122,  2074,  7194,  1050,  5146,  3610,  6682, 
      538,  4634,  2586,  7962,  1818,  5914,  3354,  6426,   282,  4378, 
     2330,  7450,  1306,  5402,  3994,  7066,   922,  5018,  2970,  7834, 
     1690,  5786,  3226,  6298,   154,  4250,  2202,  7322,  1178,  5274, 
     3738,  6810,   666,  4762,  2714,  8154,  2010,  6106,  3546,  6618, 
      474,  4570,  2522,  7642,  1498,  5594,  3930,  7002,   858,  4954, 
     2906,  7770,  1626,  5722,  3162,  6234,    90,  4186,  2138,  7258, 
     1114,  5210,  3674,  6746,   602,  4698,  2650,  8026,  1882,  5978, 
     3418,  6490,   346,  4442,  2394,  7514,  1370,  5466,  4082,  7154, 
     1010,  5106,  3058,  7922,  1778,  5874,  3314,  6386,   242,  4338, 
     2290,  7410,  1266,  5362,  3826,  6898,   754,  4850,  2802,  8114, 
     1970,  6066,  3506,  6578,   434,  4530,  2482,  7602,  1458,  5554, 
     3890,  6962,   818,  4914,  2866,  7730,  1586,  5682,  3122,  6194, 
       50,  4146,  2098,  7218,  1074,  5170,  3634,  6706,   562,  4658, 
     2610,  7986,  1842,  5938,  3378,  6450,   306,  4402,  2354,  7474, 
     1330,  5426,  4018,  7090,   946,  5042,  2994,  7858,  1714,  5810, 
     3250,  6322,   178,  4274,  2226,  7346,  1202,  5298,  3762,  6834, 
      690,  4786,  2738,  8162,  2018,  6114,  3554,  6626,   482,  4578, 
     2530,  7650,  1506,  5602,  3938,  7010,   866,  4962,  2914,  7778, 
     1634,  5730,  3170,  6242,    98,  4194,  2146,  7266,  1122,  5218, 
     3682,  6754,   610,  4706,  2658,  8034,  1890,  5986,  3426,  6498, 
      354,  4450,  2402,  7522,  1378,  5474,  4034,  7106,   962,  5058, 
     3010,  7874,  1730,  5826,  3266,  6338,   194,  4290,  2242,  7362, 
     1218,  5314,  3778,  6850,   706,  4802,  2754,  8066,  1922,  6018, 
     3458,  6530,   386,  4482,  2434,  7554,  1410,  5506,  3842,  6914, 
      770,  4866,  2818,  7682,  1538,  5634,  3074,  6146,     2,  4098, 
     2050,  7170,  1026,  5122,  3586,  6658,   514,  4610,  2562,  7938, 
     1794,  5890,  3330,  6402,   258,  4354,  2306,  7426,  1282,  5378, 
     3970,  7042,   898,  4994,  2946,  7810,  1666,  5762,  3202,  6274, 
      130,  4226,  2178,  7298,  1154,  5250,  3714,  6786,   642,  4738, 
     2690,  8130,  1986,  6082,  3522,  6594,   450,  4546,  2498,  7618, 
     1474,  5570,  3906,  6978,   834,  4930,  2882,  7746,  1602,  5698, 
     3138,  6210,    66,  4162,  2114,  7234,  1090,  5186,  3650,  6722, 
      578,  4674,  2626,  8002,  1858,  5954,  3394,  6466,   322,  4418, 
     2370,  7490,  1346,  5442,  4066,  7138,   994,  5090,  3042,  7906, 
     1762,  5858,  3298,  6370,   226,  4322,  2274,  7394,  1250,  5346, 
     3810,  6882,   738,  4834,  2786,  8098,  1954,  6050,  3490,  6562, 
      418,  4514,  2466,  7586,  1442,  5538,  3874,  6946,   802,  4898, 
     2850,  7714,  1570,  5666,  3106,  6178,    34,  4130,  2082,  7202, 
     1058,  5154,  3618,  6690,   546,  4642,  2594,  7970,  1826,  5922, 
     3362,  6434,   290,  4386,  2338,  7458,  1314,  5410,  4002,  7074, 
      930,  5026,  2978,  7842,  1698,  5794,  3234,  6306,   162,  4258, 
     2210,  7330,  1186,  5282,  3746,  6818,   674,  4770,  2722,  8178, 
     2034,  6130,  3570,  6642,   498,  4594,  2546,  7666,  1522,  5618, 
     3954,  7026,   882,  4978,  2930,  7794,  1650,  5746,  3186,  6258, 
      114,  4210,  2162,  7282,  1138,  5234,  3698,  6770,   626,  4722, 
     2674,  8050,  1906,  6002,  3442,  6514,   370,  4466,  2418,  7538, 
     1394,  5490,  4050,  7122,   978,  5074,  3026,  7890,  1746,  5842, 
     3282,  6354,   210,  4306,  2258,  7378,  1234,  5330,  3794,  6866, 
      722,  4818,  2770,  8082,  1938,  6034,  3474,  6546,   402,  4498, 
     2450,  7570,  1426,  5522,  3858,  6930,   786,  4882,  2834,  7698, 
     1554,  5650,  3090,  6162,    18,  4114,  2066,  7186,  1042,  5138, 
     3602,  6674,   530,  4626,  2578,  7954,  1810,  5906,  3346,  6418, 
      274,  4370,  2322,  7442,  1298,  5394,  3986,  7058,   914,  5010, 
     2962,  7826,  1682,  5778,  3218,  6290,   146,  4242,  2194,  7314, 
     1170,  5266,  3730,  6802,   658,  4754,  2706,  8146,  2002,  6098, 
     3538,  6610,   466,  4562,  2514,  7634,  1490,  5586,  3922,  6994, 
      850,  4946,  2898,  7762,  1618,  5714,  3154,  6226,    82,  4178, 
     2130,  7250,  1106,  5202,  3666,  6738,   594,  4690,  2642,  8018, 
     1874,  5970,  3410,  6482,   338,  4434,  2386,  7506,  1362,  5458, 
     4090,  7162,  1018,  5114,  3066,  7930,  1786,  5882,  3322,  6394, 
      250,  4346,  2298,  7418,  1274,  5370,  3834,  6906,   762,  4858, 
     2810,  8122,  1978,  6074,  3514,  6586,   442,  4538,  2490,  7610, 
     1466,  5562,  3898,  6970,   826,  4922,  2874,  7738,  1594,  5690, 
     3130,  6202,    58,  4154,  2106,  7226,  1082,  5178,  3642,  6714, 
      570,  4666,  2618,  7994,  1850,  5946,  3386,  6458,   314,  4410, 
     2362,  7482,  1338,  5434,  4026,  7098,   954,  5050,  3002,  7866, 
     1722,  5818,  3258,  6330,   186,  4282,  2234,  7354,  1210,  5306, 
     3770,  6842,   698,  4794,  2746,  8170,  2026,  6122,  3562,  6634, 
      490,  4586,  2538,  7658,  1514,  5610,  3946,  7018,   874,  4970, 
     2922,  7786,  1642,  5738,  3178,  6250,   106,  4202,  2154,  7274, 
     1130,  5226,  3690,  6762,   618,  4714,  2666,  8042,  1898,  5994, 
     3434,  6506,   362,  4458,  2410,  7530,  1386,  5482,  4042,  7114, 
      970,  5066,  3018,  7882,  1738,  5834,  3274,  6346,   202,  4298, 
     2250,  7370,  1226,  5322,  3786,  6858,   714,  4810,  2762,  8074, 
     1930,  6026,  3466,  6538,   394,  4490,  2442,  7562,  1418,  5514, 
     3850,  6922,   778,  4874,  2826,  7690,  1546,  5642,  3082,  6154, 
       10,  4106,  2058,  7178,  1034,  5130,  3594,  6666,   522,  4618, 
     2570,  7946,  1802,  5898,  3338,  6410,   266,  4362,  2314,  7434, 
     1290,  5386,  3978,  7050,   906,  5002,  2954,  7818,  1674,  5770, 
     3210,  6282,   138,  4234,  2186,  7306,  1162,  5258,  3722,  6794, 
      650,  4746,  2698,  8138,  1994,  6090,  3530,  6602,   458,  4554, 
     2506,  7626,  1482,  5578,  3914,  6986,   842,  4938,  2890,  7754, 
     1610,  5706,  3146,  6218,    74,  4170,  2122,  7242,  1098,  5194, 
     3658,  6730,   586,  4682,  2634,  8010,  1866,  5962,  3402,  6474, 
      330,  4426,  2378,  7498,  1354,  5450,  4074,  7146,  1002,  5098, 
     3050,  7914,  1770,  5866,  3306,  6378,   234,  4330,  2282,  7402, 
     1258,  5354,  3818,  6890,   746,  4842,  2794,  8106,  1962,  6058, 
     3498,  6570,   426,  4522,  2474,  7594,  1450,  5546,  3882,  6954, 
      810,  4906,  2858,  7722,  1578,  5674,  3114,  6186,    42,  4138, 
     2090,  7210,  1066,  5162,  3626,  6698,   554,  4650,  2602,  7978, 
     1834,  5930,  3370,  6442,   298,  4394,  2346,  7466,  1322,  5418, 
     4010,  7082,   938,  5034,  2986,  7850,  1706,  5802,  3242,  6314, 
      170,  4266,  2218,  7338,  1194,  5290,  3754,  6826,   682,  4778, 
     2730,  8191,  2047,  6143,  3583,  6655,   511,  4607,  2559,  7679, 
     1535,  5631,  3967,  7039,   895,  4991,  2943,  7807,  1663,  5759, 
     3199,  6271,   127,  4223,  2175,  7295,  1151,  5247,  3711,  6783, 
      639,  4735,  2687,  8063,  1919,  6015,  3455,  6527,   383,  4479, 
     2431,  7551,  1407,  5503,  4063,  7135,   991,  5087,  3039,  7903, 
     1759,  5855,  3295,  6367,   223,  4319,  2271,  7391,  1247,  5343, 
     3807,  6879,   735,  4831,  2783,  8095,  1951,  6047,  3487,  6559, 
      415,  4511,  2463,  7583,  1439,  5535,  3871,  6943,   799,  4895, 
     2847,  7711,  1567,  5663,  3103,  6175,    31,  4127,  2079,  7199, 
     1055,  5151,  3615,  6687,   543,  4639,  2591,  7967,  1823,  5919, 
     3359,  6431,   287,  4383,  2335,  7455,  1311,  5407,  3999,  7071, 
      927,  5023,  2975,  7839,  1695,  5791,  3231,  6303,   159,  4255, 
     2207,  7327,  1183,  5279,  3743,  6815,   671,  4767,  2719,  8159, 
     2015,  6111,  3551,  6623,   479,  4575,  2527,  7647,  1503,  5599, 
     3935,  7007,   863,  4959,  2911,  7775,  1631,  5727,  3167,  6239, 
       95,  4191,  2143,  7263,  1119,  5215,  3679,  6751,   607,  4703, 
     2655,  8031,  1887,  5983,  3423,  6495,   351,  4447,  2399,  7519, 
     1375,  5471,  4087,  7159,  1015,  5111,  3063,  7927,  1783,  5879, 
     3319,  6391,   247,  4343,  2295,  7415,  1271,  5367,  3831,  6903, 
      759,  4855,  2807,  8119,  1975,  6071,  3511,  6583,   439,  4535, 
     2487,  7607,  1463,  5559,  3895,  6967,   823,  4919,  2871,  7735, 
     1591,  5687,  3127,  6199,    55,  4151,  2103,  7223,  1079,  5175, 
     3639,  6711,   567,  4663,  2615,  7991,  1847,  5943,  3383,  6455, 
      311,  4407,  2359,  7479,  1335,  5431,  4023,  7095,   951,  5047, 
     2999,  7863,  1719,  5815,  3255,  6327,   183,  4279,  2231,  7351, 
     1207,  5303,  3767,  6839,   695,  4791,  2743,  8167,  2023,  6119, 
     3559,  6631,   487,  4583,  2535,  7655,  1511,  5607,  3943,  7015, 
      871,  4967,  2919,  7783,  1639,  5735,  3175,  6247,   103,  4199, 
     2151,  7271,  1127,  5223,  3687,  6759,   615,  4711,  2663,  8039, 
     1895,  5991,  3431,  6503,   359,  4455,  2407,  7527,  1383,  5479, 
     4039,  7111,   967,  5063,  3015,  7879,  1735,  5831,  3271,  6343, 
      199,  4295,  2247,  7367,  1223,  5319,  3783,  6855,   711,  4807, 
     2759,  8071,  1927,  6023,  3463,  6535,   391,  4487,  2439,  7559, 
     1415,  5511,  3847,  6919,   775,  4871,  2823,  7687,  1543,  5639, 
     3079,  6151,     7,  4103,  2055,  7175,  1031,  5127,  3591,  6663, 
      519,  4615,  2567,  7943,  1799,  5895,  3335,  6407,   263,  4359, 
     2311,  7431,  1287,  5383,  3975,  7047,   903,  4999,  2951,  7815, 
     1671,  5767,  3207,  6279,   135,  4231,  2183,  7303,  1159,  5255, 
     3719,  6791,   647,  4743,  2695,  8135,  1991,  6087,  3527,  6599, 
      455,  4551,  2503,  7623,  1479,  5575,  3911,  6983,   839,  4935, 
     2887,  7751,  1607,  5703,  3143,  6215,    71,  4167,  2119,  7239, 
     1095,  5191,  3655,  6727,   583,  4679,  2631,  8007,  1863,  5959, 
     3399,  6471,   327,  4423,  2375,  7495,  1351,  5447,  4071,  7143, 
      999,  5095,  3047,  7911,  1767,  5863,  3303,  6375,   231,  4327, 
     2279,  7399,  1255,  5351,  3815,  6887,   743,  4839,  2791,  8103, 
     1959,  6055,  3495,  6567,   423,  4519,  2471,  7591,  1447,  5543, 
     3879,  6951,   807,  4903,  2855,  7719,  1575,  5671,  3111,  6183, 
       39,  4135,  2087,  7207,  1063,  5159,  3623,  6695,   551,  4647, 
     2599,  7975,  1831,  5927,  3367,  6439,   295,  4391,  2343,  7463, 
     1319,  5415,  4007,  7079,   935,  5031,  2983,  7847,  1703,  5799, 
     3239,  6311,   167,  4263,  2215,  7335,  1191,  5287,  3751,  6823, 
      679,  4775,  2727,  8183,  2039,  6135,  3575,  6647,   503,  4599, 
     2551,  7671,  1527,  5623,  3959,  7031,   887,  4983,  2935,  7799, 
     1655,  5751,  3191,  6263,   119,  4215,  2167,  7287,  1143,  5239, 
     3703,  6775,   631,  4727,  2679,  8055,  1911,  6007,  3447,  6519, 
      375,  4471,  2423,  7543,  1399,  5495,  4055,  7127,   983,  5079, 
     3031,  7895,  1751,  5847,  3287,  6359,   215,  4311,  2263,  7383, 
     1239,  5335,  3799,  6871,   727,  4823,  2775,  8087,  1943,  6039, 
     3479,  6551,   407,  4503,  2455,  7575,  1431,  5527,  3863,  6935, 
      791,  4887,  2839,  7703,  1559,  5655,  3095,  6167,    23,  4119, 
     2071,  7191,  1047,  5143,  3607,  6679,   535,  4631,  2583,  7959, 
     1815,  5911,  3351,  6423,   279,  4375,  2327,  7447,  1303,  5399, 
     3991,  7063,   919,  5015,  2967,  7831,  1687,  5783,  3223,  6295, 
      151,  4247,  2199,  7319,  1175,  5271,  3735,  6807,   663,  4759, 
     2711,  8151,  2007,  6103,  3543,  6615,   471,  4567,  2519,  7639, 
     1495,  5591,  3927,  6999,   855,  4951,  2903,  7767,  1623,  5719, 
     3159,  6231,    87,  4183,  2135,  7255,  1111,  5207,  3671,  6743, 
      599,  4695,  2647,  8023,  1879,  5975,  3415,  6487,   343,  4439, 
     2391,  7511,  1367,  5463,  4093,  7165,  1021,  5117,  3069,  7933, 
     1789,  5885,  3325,  6397,   253,  4349,  2301,  7421,  1277,  5373, 
     3837,  6909,   765,  4861,  2813,  8125,  1981,  6077,  3517,  6589, 
      445,  4541,  2493,  7613,  1469,  5565,  3901,  6973,   829,  4925, 
     2877,  7741,  1597,  5693,  3133,  6205,    61,  4157,  2109,  7229, 
     1085,  5181,  3645,  6717,   573,  4669,  2621,  7997,  1853,  5949, 
     3389,  6461,   317,  4413,  2365,  7485,  1341,  5437,  4029,  7101, 
      957,  5053,  3005,  7869,  1725,  5821,  3261,  6333,   189,  4285, 
     2237,  7357,  1213,  5309,  3773,  6845,   701,  4797,  2749,  8173, 
     2029,  6125,  3565,  6637,   493,  4589,  2541,  7661,  1517,  5613, 
     3949,  7021,   877,  4973,  2925,  7789,  1645,  5741,  3181,  6253, 
      109,  4205,  2157,  7277,  1133,  5229,  3693,  6765,   621,  4717, 
     2669,  8045,  1901,  5997,  3437,  6509,   365,  4461,  2413,  7533, 
     1389,  5485,  4045,  7117,   973,  5069,  3021,  7885,  1741,  5837, 
     3277,  6349,   205,  4301,  2253,  7373,  1229,  5325,  3789,  6861, 
      717,  4813,  2765,  8077,  1933,  6029,  3469,  6541,   397,  4493, 
     2445,  7565,  1421,  5517,  3853,  6925,   781,  4877,  2829,  7693, 
     1549,  5645,  3085,  6157,    13,  4109,  2061,  7181,  1037,  5133, 
     3597,  6669,   525,  4621,  2573,  7949,  1805,  5901,  3341,  6413, 
      269,  4365,  2317,  7437,  1293,  5389,  3981,  7053,   909,  5005, 
     2957,  7821,  1677,  5773,  3213,  6285,   141,  4237,  2189,  7309, 
     1165,  5261,  3725,  6797,   653,  4749,  2701,  8141,  1997,  6093, 
     3533,  6605,   461,  4557,  2509,  7629,  1485,  5581,  3917,  6989, 
      845,  4941,  2893,  7757,  1613,  5709,  3149,  6221,    77,  4173, 
     2125,  7245,  1101,  5197,  3661,  6733,   589,  4685,  2637,  8013, 
     1869,  5965,  3405,  6477,   333,  4429,  2381,  7501,  1357,  5453, 
     4077,  7149,  1005,  5101,  3053,  7917,  1773,  5869,  3309,  6381, 
      237,  4333,  2285,  7405,  1261,  5357,  3821,  6893,   749,  4845, 
     2797,  8109,  1965,  6061,  3501,  6573,   429,  4525,  2477,  7597, 
     1453,  5549,  3885,  6957,   813,  4909,  2861,  7725,  1581,  5677, 
     3117,  6189,    45,  4141,  2093,  7213,  1069,  5165,  3629,  6701, 
      557,  4653,  2605,  7981,  1837,  5933,  3373,  6445,   301,  4397, 
     2349,  7469,  1325,  5421,  4013,  7085,   941,  5037,  2989,  7853, 
     1709,  5805,  3245,  6317,   173,  4269,  2221,  7341,  1197,  5293, 
     3757,  6829,   685,  4781,  2733,  8185,  2041,  6137,  3577,  6649, 
      505,  4601,  2553,  7673,  1529,  5625,  3961,  7033,   889,  4985, 
     2937,  7801,  1657,  5753,  3193,  6265,   121,  4217,  2169,  7289, 
     1145,  5241,  3705,  6777,   633,  4729,  2681,  8057,  1913,  6009, 
     3449,  6521,   377,  4473,  2425,  7545,  1401,  5497,  4057,  7129, 
      985,  5081,  3033,  7897,  1753,  5849,  3289,  6361,   217,  4313, 
     2265,  7385,  1241,  5337,  3801,  6873,   729,  4825,  2777,  8089, 
     1945,  6041,  3481,  6553,   409,  4505,  2457,  7577,  1433,  5529, 
     3865,  6937,   793,  4889,  2841,  7705,  1561,  5657,  3097,  6169, 
       25,  4121,  2073,  7193,  1049,  5145,  3609,  6681,   537,  4633, 
     2585,  7961,  1817,  5913,  3353,  6425,   281,  4377,  2329,  7449, 
     1305,  5401,  3993,  7065,   921,  5017,  2969,  7833,  1689,  5785, 
     3225,  6297,   153,  4249,  2201,  7321,  1177,  5273,  3737,  6809, 
      665,  4761,  2713,  8153,  2009,  6105,  3545,  6617,   473,  4569, 
     2521,  7641,  1497,  5593,  3929,  7001,   857,  4953,  2905,  7769, 
     1625,  5721,  3161,  6233,    89,  4185,  2137,  7257,  1113,  5209, 
     3673,  6745,   601,  4697,  2649,  8025,  1881,  5977,  3417,  6489, 
      345,  4441,  2393,  7513,  1369,  5465,  4081,  7153,  1009,  5105, 
     3057,  7921,  1777,  5873,  3313,  6385,   241,  4337,  2289,  7409, 
     1265,  5361,  3825,  6897,   753,  4849,  2801,  8113,  1969,  6065, 
     3505,  6577,   433,  4529,  2481,  7601,  1457,  5553,  3889,  6961, 
      817,  4913,  2865,  7729,  1585,  5681,  3121,  6193,    49,  4145, 
     2097,  7217,  1073,  5169,  3633,  6705,   561,  4657,  2609,  7985, 
     1841,  5937,  3377,  6449,   305,  4401,  2353,  7473,  1329,  5425, 
     4017,  7089,   945,  5041,  2993,  7857,  1713,  5809,  3249,  6321, 
      177,  4273,  2225,  7345,  1201,  5297,  3761,  6833,   689,  4785, 
     2737,  8161,  2017,  6113,  3553,  6625,   481,  4577,  2529,  7649, 
     1505,  5601,  3937,  7009,   865,  4961,  2913,  7777,  1633,  5729, 
     3169,  6241,    97,  4193,  2145,  7265,  1121,  5217,  3681,  6753, 
      609,  4705,  2657,  8033,  1889,  5985,  3425,  6497,   353,  4449, 
     2401,  7521,  1377,  5473,  4033,  7105,   961,  5057,  3009,  7873, 
     1729,  5825,  3265,  6337,   193,  4289,  2241,  7361,  1217,  5313, 
     3777,  6849,   705,  4801,  2753,  8065,  1921,  6017,  3457,  6529, 
      385,  4481,  2433,  7553,  1409,  5505,  3841,  6913,   769,  4865, 
     2817,  7681,  1537,  5633,  3073,  6145,     1,  4097,  2049,  7169, 
     1025,  5121,  3585,  6657,   513,  4609,  2561,  7937,  1793,  5889, 
     3329,  6401,   257,  4353,  2305,  7425,  1281,  5377,  3969,  7041, 
      897,  4993,  2945,  7809,  1665,  5761,  3201,  6273,   129,  4225, 
     2177,  7297,  1153,  5249,  3713,  6785,   641,  4737,  2689,  8129, 
     1985,  6081,  3521,  6593,   449,  4545,  2497,  7617,  1473,  5569, 
     3905,  6977,   833,  4929,  2881,  7745,  1601,  5697,  3137,  6209, 
       65,  4161,  2113,  7233,  1089,  5185,  3649,  6721,   577,  4673, 
     2625,  8001,  1857,  5953,  3393,  6465,   321,  4417,  2369,  7489, 
     1345,  5441,  4065,  7137,   993,  5089,  3041,  7905,  1761,  5857, 
     3297,  6369,   225,  4321,  2273,  7393,  1249,  5345,  3809,  6881, 
      737,  4833,  2785,  8097,  1953,  6049,  3489,  6561,   417,  4513, 
     2465,  7585,  1441,  5537,  3873,  6945,   801,  4897,  2849,  7713, 
     1569,  5665,  3105,  6177,    33,  4129,  2081,  7201,  1057,  5153, 
     3617,  6689,   545,  4641,  2593,  7969,  1825,  5921,  3361,  6433, 
      289,  4385,  2337,  7457,  1313,  5409,  4001,  7073,   929,  5025, 
     2977,  7841,  1697,  5793,  3233,  6305,   161,  4257,  2209,  7329, 
     1185,  5281,  3745,  6817,   673,  4769,  2721,  8177,  2033,  6129, 
     3569,  6641,   497,  4593,  2545,  7665,  1521,  5617,  3953,  7025, 
      881,  4977,  2929,  7793,  1649,  5745,  3185,  6257,   113,  4209, 
     2161,  7281,  1137,  5233,  3697,  6769,   625,  4721,  2673,  8049, 
     1905,  6001,  3441,  6513,   369,  4465,  2417,  7537,  1393,  5489, 
     4049,  7121,   977,  5073,  3025,  7889,  1745,  5841,  3281,  6353, 
      209,  4305,  2257,  7377,  1233,  5329,  3793,  6865,   721,  4817, 
     2769,  8081,  1937,  6033,  3473,  6545,   401,  4497,  2449,  7569, 
     1425,  5521,  3857,  6929,   785,  4881,  2833,  7697,  1553,  5649, 
     3089,  6161,    17,  4113,  2065,  7185,  1041,  5137,  3601,  6673, 
      529,  4625,  2577,  7953,  1809,  5905,  3345,  6417,   273,  4369, 
     2321,  7441,  1297,  5393,  3985,  7057,   913,  5009,  2961,  7825, 
     1681,  5777,  3217,  6289,   145,  4241,  2193,  7313,  1169,  5265, 
     3729,  6801,   657,  4753,  2705,  8145,  2001,  6097,  3537,  6609, 
      465,  4561,  2513,  7633,  1489,  5585,  3921,  6993,   849,  4945, 
     2897,  7761,  1617,  5713,  3153,  6225,    81,  4177,  2129,  7249, 
     1105,  5201,  3665,  6737,   593,  4689,  2641,  8017,  1873,  5969, 
     3409,  6481,   337,  4433,  2385,  7505,  1361,  5457,  4089,  7161, 
     1017,  5113,  3065,  7929,  1785,  5881,  3321,  6393,   249,  4345, 
     2297,  7417,  1273,  5369,  3833,  6905,   761,  4857,  2809,  8121, 
     1977,  6073,  3513,  6585,   441,  4537,  2489,  7609,  1465,  5561, 
     3897,  6969,   825,  4921,  2873,  7737,  1593,  5689,  3129,  6201, 
       57,  4153,  2105,  7225,  1081,  5177,  3641,  6713,   569,  4665, 
     2617,  7993,  1849,  5945,  3385,  6457,   313,  4409,  2361,  7481, 
     1337,  5433,  4025,  7097,   953,  5049,  3001,  7865,  1721,  5817, 
     3257,  6329,   185,  4281,  2233,  7353,  1209,  5305,  3769,  6841, 
      697,  4793,  2745,  8169,  2025,  6121,  3561,  6633,   489,  4585, 
     2537,  7657,  1513,  5609,  3945,  7017,   873,  4969,  2921,  7785, 
     1641,  5737,  3177,  6249,   105,  4201,  2153,  7273,  1129,  5225, 
     3689,  6761,   617,  4713,  2665,  8041,  1897,  5993,  3433,  6505, 
      361,  4457,  2409,  7529,  1385,  5481,  4041,  7113,   969,  5065, 
     3017,  7881,  1737,  5833,  3273,  6345,   201,  4297,  2249,  7369, 
     1225,  5321,  3785,  6857,   713,  4809,  2761,  8073,  1929,  6025, 
     3465,  6537,   393,  4489,  2441,  7561,  1417,  5513,  3849,  6921, 
      777,  4873,  2825,  7689,  1545,  5641,  3081,  6153,     9,  4105, 
     2057,  7177,  1033,  5129,  3593,  6665,   521,  4617,  2569,  7945, 
     1801,  5897,  3337,  6409,   265,  4361,  2313,  7433,  1289,  5385, 
     3977,  7049,   905,  5001,  2953,  7817,  1673,  5769,  3209,  6281, 
      137,  4233,  2185,  7305,  1161,  5257,  3721,  6793,   649,  4745, 
     2697,  8137,  1993,  6089,  3529,  6601,   457,  4553,  2505,  7625, 
     1481,  5577,  3913,  6985,   841,  4937,  2889,  7753,  1609,  5705, 
     3145,  6217,    73,  4169,  2121,  7241,  1097,  5193,  3657,  6729, 
      585,  4681,  2633,  8009,  1865,  5961,  3401,  6473,   329,  4425, 
     2377,  7497,  1353,  5449,  4073,  7145,  1001,  5097,  3049,  7913, 
     1769,  5865,  3305,  6377,   233,  4329,  2281,  7401,  1257,  5353, 
     3817,  6889,   745,  4841,  2793,  8105,  1961,  6057,  3497,  6569, 
      425,  4521,  2473,  7593,  1449,  5545,  3881,  6953,   809,  4905, 
     2857,  7721,  1577,  5673,  3113,  6185,    41,  4137,  2089,  7209, 
     1065,  5161,  3625,  6697,   553,  4649,  2601,  7977,  1833,  5929, 
     3369,  6441,   297,  4393,  2345,  7465,  1321,  5417,  4009,  7081, 
      937,  5033,  2985,  7849,  1705,  5801,  3241,  6313,   169,  4265, 
     2217,  7337,  1193,  5289,  3753,  6825,   681,  4777,  2729,  8189, 
     2045,  6141,  3581,  6653,   509,  4605,  2557,  7677,  1533,  5629, 
     3965,  7037,   893,  4989,  2941,  7805,  1661,  5757,  3197,  6269, 
      125,  4221,  2173,  7293,  1149,  5245,  3709,  6781,   637,  4733, 
     2685,  8061,  1917,  6013,  3453,  6525,   381,  4477,  2429,  7549, 
     1405,  5501,  4061,  7133,   989,  5085,  3037,  7901,  1757,  5853, 
     3293,  6365,   221,  4317,  2269,  7389,  1245,  5341,  3805,  6877, 
      733,  4829,  2781,  8093,  1949,  6045,  3485,  6557,   413,  4509, 
     2461,  7581,  1437,  5533,  3869,  6941,   797,  4893,  2845,  7709, 
     1565,  5661,  3101,  6173,    29,  4125,  2077,  7197,  1053,  5149, 
     3613,  6685,   541,  4637,  2589,  7965,  1821,  5917,  3357,  6429, 
      285,  4381,  2333,  7453,  1309,  5405,  3997,  7069,   925,  5021, 
     2973,  7837,  1693,  5789,  3229,  6301,   157,  4253,  2205,  7325, 
     1181,  5277,  3741,  6813,   669,  4765,  2717,  8157,  2013,  6109, 
     3549,  6621,   477,  4573,  2525,  7645,  1501,  5597,  3933,  7005, 
      861,  4957,  2909,  7773,  1629,  5725,  3165,  6237,    93,  4189, 
     2141,  7261,  1117,  5213,  3677,  6749,   605,  4701,  2653,  8029, 
     1885,  5981,  3421,  6493,   349,  4445,  2397,  7517,  1373,  5469, 
     4085,  7157,  1013,  5109,  3061,  7925,  1781,  5877,  3317,  6389, 
      245,  4341,  2293,  7413,  1269,  5365,  3829,  6901,   757,  4853, 
     2805,  8117,  1973,  6069,  3509,  6581,   437,  4533,  2485,  7605, 
     1461,  5557,  3893,  6965,   821,  4917,  2869,  7733,  1589,  5685, 
     3125,  6197,    53,  4149,  2101,  7221,  1077,  5173,  3637,  6709, 
      565,  4661,  2613,  7989,  1845,  5941,  3381,  6453,   309,  4405, 
     2357,  7477,  1333,  5429,  4021,  7093,   949,  5045,  2997,  7861, 
     1717,  5813,  3253,  6325,   181,  4277,  2229,  7349,  1205,  5301, 
     3765,  6837,   693,  4789,  2741,  8165,  2021,  6117,  3557,  6629, 
      485,  4581,  2533,  7653,  1509,  5605,  3941,  7013,   869,  4965, 
     2917,  7781,  1637,  5733,  3173,  6245,   101,  4197,  2149,  7269, 
     1125,  5221,  3685,  6757,   613,  4709,  2661,  8037,  1893,  5989, 
     3429,  6501,   357,  4453,  2405,  7525,  1381,  5477,  4037,  7109, 
      965,  5061,  3013,  7877,  1733,  5829,  3269,  6341,   197,  4293, 
     2245,  7365,  1221,  5317,  3781,  6853,   709,  4805,  2757,  8069, 
     1925,  6021,  3461,  6533,   389,  4485,  2437,  7557,  1413,  5509, 
     3845,  6917,   773,  4869,  2821,  7685,  1541,  5637,  3077,  6149, 
        5,  4101,  2053,  7173,  1029,  5125,  3589,  6661,   517,  4613, 
     2565,  7941,  1797,  5893,  3333,  6405,   261,  4357,  2309,  7429, 
     1285,  5381,  3973,  7045,   901,  4997,  2949,  7813,  1669,  5765, 
     3205,  6277,   133,  4229,  2181,  7301,  1157,  5253,  3717,  6789, 
      645,  4741,  2693,  8133,  1989,  6085,  3525,  6597,   453,  4549, 
     2501,  7621,  1477,  5573,  3909,  6981,   837,  4933,  2885,  7749, 
     1605,  5701,  3141,  6213,    69,  4165,  2117,  7237,  1093,  5189, 
     3653,  6725,   581,  4677,  2629,  8005,  1861,  5957,  3397,  6469, 
      325,  4421,  2373,  7493,  1349,  5445,  4069,  7141,   997,  5093, 
     3045,  7909,  1765,  5861,  3301,  6373,   229,  4325,  2277,  7397, 
     1253,  5349,  3813,  6885,   741,  4837,  2789,  8101,  1957,  6053, 
     3493,  6565,   421,  4517,  2469,  7589,  1445,  5541,  3877,  6949, 
      805,  4901,  2853,  7717,  1573,  5669,  3109,  6181,    37,  4133, 
     2085,  7205,  1061,  5157,  3621,  6693,   549,  4645,  2597,  7973, 
     1829,  5925,  3365,  6437,   293,  4389,  2341,  7461,  1317,  5413, 
     4005,  7077,   933,  5029,  2981,  7845,  1701,  5797,  3237,  6309, 
      165,  4261,  2213,  7333,  1189,  5285,  3749,  6821,   677,  4773, 
     2725,  8181,  2037,  6133,  3573,  6645,   501,  4597,  2549,  7669, 
     1525,  5621,  3957,  7029,   885,  4981,  2933,  7797,  1653,  5749, 
     3189,  6261,   117,  4213,  2165,  7285,  1141,  5237,  3701,  6773, 
      629,  4725,  2677,  8053,  1909,  6005,  3445,  6517,   373,  4469, 
     2421,  7541,  1397,  5493,  4053,  7125,   981,  5077,  3029,  7893, 
     1749,  5845,  3285,  6357,   213,  4309,  2261,  7381,  1237,  5333, 
     3797,  6869,   725,  4821,  2773,  8085,  1941,  6037,  3477,  6549, 
      405,  4501,  2453,  7573,  1429,  5525,  3861,  6933,   789,  4885, 
     2837,  7701,  1557,  5653,  3093,  6165,    21,  4117,  2069,  7189, 
     1045,  5141,  3605,  6677,   533,  4629,  2581,  7957,  1813,  5909, 
     3349,  6421,   277,  4373,  2325,  7445,  1301,  5397,  3989,  7061, 
      917,  5013,  2965,  7829,  1685,  5781,  3221,  6293,   149,  4245, 
     2197,  7317,  1173,  5269,  3733,  6805,   661,  4757,  2709,  8149, 
     2005,  6101,  3541,  6613,   469,  4565,  2517,  7637,  1493,  5589, 
     3925,  6997,   853,  4949,  2901,  7765,  1621,  5717,  3157,  6229, 
       85,  4181,  2133,  7253,  1109,  5205,  3669,  6741,   597,  4693, 
     2645,  8021,  1877,  5973,  3413,  6485,   341,  4437,  2389,  7509, 
     1365,  5461,  4095,  7167,  1023,  5119,  3071,  7935,  1791,  5887, 
     3327,  6399,   255,  4351,  2303,  7423,  1279,  5375,  3839,  6911, 
      767,  4863,  2815,  8127,  1983,  6079,  3519,  6591,   447,  4543, 
     2495,  7615,  1471,  5567,  3903,  6975,   831,  4927,  2879,  7743, 
     1599,  5695,  3135,  6207,    63,  4159,  2111,  7231,  1087,  5183, 
     3647,  6719,   575,  4671,  2623,  7999,  1855,  5951,  3391,  6463, 
      319,  4415,  2367,  7487,  1343,  5439,  4031,  7103,   959,  5055, 
     3007,  7871,  1727,  5823,  3263,  6335,   191,  4287,  2239,  7359, 
     1215,  5311,  3775,  6847,   703,  4799,  2751,  8175,  2031,  6127, 
     3567,  6639,   495,  4591,  2543,  7663,  1519,  5615,  3951,  7023, 
      879,  4975,  2927,  7791,  1647,  5743,  3183,  6255,   111,  4207, 
     2159,  7279,  1135,  5231,  3695,  6767,   623,  4719,  2671,  8047, 
     1903,  5999,  3439,  6511,   367,  4463,  2415,  7535,  1391,  5487, 
     4047,  7119,   975,  5071,  3023,  7887,  1743,  5839,  3279,  6351, 
      207,  4303,  2255,  7375,  1231,  5327,  3791,  6863,   719,  4815, 
     2767,  8079,  1935,  6031,  3471,  6543,   399,  4495,  2447,  7567, 
     1423,  5519,  3855,  6927,   783,  4879,  2831,  7695,  1551,  5647, 
     3087,  6159,    15,  4111,  2063,  7183,  1039,  5135,  3599,  6671, 
      527,  4623,  2575,  7951,  1807,  5903,  3343,  6415,   271,  4367, 
     2319,  7439,  1295,  5391,  3983,  7055,   911,  5007,  2959,  7823, 
     1679,  5775,  3215,  6287,   143,  4239,  2191,  7311,  1167,  5263, 
     3727,  6799,   655,  4751,  2703,  8143,  1999,  6095,  3535,  6607, 
      463,  4559,  2511,  7631,  1487,  5583,  3919,  6991,   847,  4943, 
     2895,  7759,  1615,  5711,  3151,  6223,    79,  4175,  2127,  7247, 
     1103,  5199,  3663,  6735,   591,  4687,  2639,  8015,  1871,  5967, 
     3407,  6479,   335,  4431,  2383,  7503,  1359,  5455,  4079,  7151, 
     1007,  5103,  3055,  7919,  1775,  5871,  3311,  6383,   239,  4335, 
     2287,  7407,  1263,  5359,  3823,  6895,   751,  4847,  2799,  8111, 
     1967,  6063,  3503,  6575,   431,  4527,  2479,  7599,  1455,  5551, 
     3887,  6959,   815,  4911,  2863,  7727,  1583,  5679,  3119,  6191, 
       47,  4143,  2095,  7215,  1071,  5167,  3631,  6703,   559,  4655, 
     2607,  7983,  1839,  5935,  3375,  6447,   303,  4399,  2351,  7471, 
     1327,  5423,  4015,  7087,   943,  5039,  2991,  7855,  1711,  5807, 
     3247,  6319,   175,  4271,  2223,  7343,  1199,  5295,  3759,  6831, 
      687,  4783,  2735,  8187,  2043,  6139,  3579,  6651,   507,  4603, 
     2555,  7675,  1531,  5627,  3963,  7035,   891,  4987,  2939,  7803, 
     1659,  5755,  3195,  6267,   123,  4219,  2171,  7291,  1147,  5243, 
     3707,  6779,   635,  4731,  2683,  8059,  1915,  6011,  3451,  6523, 
      379,  4475,  2427,  7547,  1403,  5499,  4059,  7131,   987,  5083, 
     3035,  7899,  1755,  5851,  3291,  6363,   219,  4315,  2267,  7387, 
     1243,  5339,  3803,  6875,   731,  4827,  2779,  8091,  1947,  6043, 
     3483,  6555,   411,  4507,  2459,  7579,  1435,  5531,  3867,  6939, 
      795,  4891,  2843,  7707,  1563,  5659,  3099,  6171,    27,  4123, 
     2075,  7195,  1051,  5147,  3611,  6683,   539,  4635,  2587,  7963, 
     1819,  5915,  3355,  6427,   283,  4379,  2331,  7451,  1307,  5403, 
     3995,  7067,   923,  5019,  2971,  7835,  1691,  5787,  3227,  6299, 
      155,  4251,  2203,  7323,  1179,  5275,  3739,  6811,   667,  4763, 
     2715,  8155,  2011,  6107,  3547,  6619,   475,  4571,  2523,  7643, 
     1499,  5595,  3931,  7003,   859,  4955,  2907,  7771,  1627,  5723, 
     3163,  6235,    91,  4187,  2139,  7259,  1115,  5211,  3675,  6747, 
      603,  4699,  2651,  8027,  1883,  5979,  3419,  6491,   347,  4443, 
     2395,  7515,  1371,  5467,  4083,  7155,  1011,  5107,  3059,  7923, 
     1779,  5875,  3315,  6387,   243,  4339,  2291,  7411,  1267,  5363, 
     3827,  6899,   755,  4851,  2803,  8115,  1971,  6067,  3507,  6579, 
      435,  4531,  2483,  7603,  1459,  5555,  3891,  6963,   819,  4915, 
     2867,  7731,  1587,  5683,  3123,  6195,    51,  4147,  2099,  7219, 
     1075,  5171,  3635,  6707,   563,  4659,  2611,  7987,  1843,  5939, 
     3379,  6451,   307,  4403,  2355,  7475,  1331,  5427,  4019,  7091, 
      947,  5043,  2995,  7859,  1715,  5811,  3251,  6323,   179,  4275, 
     2227,  7347,  1203,  5299,  3763,  6835,   691,  4787,  2739,  8163, 
     2019,  6115,  3555,  6627,   483,  4579,  2531,  7651,  1507,  5603, 
     3939,  7011,   867,  4963,  2915,  7779,  1635,  5731,  3171,  6243, 
       99,  4195,  2147,  7267,  1123,  5219,  3683,  6755,   611,  4707, 
     2659,  8035,  1891,  5987,  3427,  6499,   355,  4451,  2403,  7523, 
     1379,  5475,  4035,  7107,   963,  5059,  3011,  7875,  1731,  5827, 
     3267,  6339,   195,  4291,  2243,  7363,  1219,  5315,  3779,  6851, 
      707,  4803,  2755,  8067,  1923,  6019,  3459,  6531,   387,  4483, 
     2435,  7555,  1411,  5507,  3843,  6915,   771,  4867,  2819,  7683, 
     1539,  5635,  3075,  6147,     3,  4099,  2051,  7171,  1027,  5123, 
     3587,  6659,   515,  4611,  2563,  7939,  1795,  5891,  3331,  6403, 
      259,  4355,  2307,  7427,  1283,  5379,  3971,  7043,   899,  4995, 
     2947,  7811,  1667,  5763,  3203,  6275,   131,  4227,  2179,  7299, 
     1155,  5251,  3715,  6787,   643,  4739,  2691,  8131,  1987,  6083, 
     3523,  6595,   451,  4547,  2499,  7619,  1475,  5571,  3907,  6979, 
      835,  4931,  2883,  7747,  1603,  5699,  3139,  6211,    67,  4163, 
     2115,  7235,  1091,  5187,  3651,  6723,   579,  4675,  2627,  8003, 
     1859,  5955,  3395,  6467,   323,  4419,  2371,  7491,  1347,  5443, 
     4067,  7139,   995,  5091,  3043,  7907,  1763,  5859,  3299,  6371, 
      227,  4323,  2275,  7395,  1251,  5347,  3811,  6883,   739,  4835, 
     2787,  8099,  1955,  6051,  3491,  6563,   419,  4515,  2467,  7587, 
     1443,  5539,  3875,  6947,   803,  4899,  2851,  7715,  1571,  5667, 
     3107,  6179,    35,  4131,  2083,  7203,  1059,  5155,  3619,  6691, 
      547,  4643,  2595,  7971,  1827,  5923,  3363,  6435,   291,  4387, 
     2339,  7459,  1315,  5411,  4003,  7075,   931,  5027,  2979,  7843, 
     1699,  5795,  3235,  6307,   163,  4259,  2211,  7331,  1187,  5283, 
     3747,  6819,   675,  4771,  2723,  8179,  2035,  6131,  3571,  6643, 
      499,  4595,  2547,  7667,  1523,  5619,  3955,  7027,   883,  4979, 
     2931,  7795,  1651,  5747,  3187,  6259,   115,  4211,  2163,  7283, 
     1139,  5235,  3699,  6771,   627,  4723,  2675,  8051,  1907,  6003, 
     3443,  6515,   371,  4467,  2419,  7539,  1395,  5491,  4051,  7123, 
      979,  5075,  3027,  7891,  1747,  5843,  3283,  6355,   211,  4307, 
     2259,  7379,  1235,  5331,  3795,  6867,   723,  4819,  2771,  8083, 
     1939,  6035,  3475,  6547,   403,  4499,  2451,  7571,  1427,  5523, 
     3859,  6931,   787,  4883,  2835,  7699,  1555,  5651,  3091,  6163, 
       19,  4115,  2067,  7187,  1043,  5139,  3603,  6675,   531,  4627, 
     2579,  7955,  1811,  5907,  3347,  6419,   275,  4371,  2323,  7443, 
     1299,  5395,  3987,  7059,   915,  5011,  2963,  7827,  1683,  5779, 
     3219,  6291,   147,  4243,  2195,  7315,  1171,  5267,  3731,  6803, 
      659,  4755,  2707,  8147,  2003,  6099,  3539,  6611,   467,  4563, 
     2515,  7635,  1491,  5587,  3923,  6995,   851,  4947,  2899,  7763, 
     1619,  5715,  3155,  6227,    83,  4179,  2131,  7251,  1107,  5203, 
     3667,  6739,   595,  4691,  2643,  8019,  1875,  5971,  3411,  6483, 
      339,  4435,  2387,  7507,  1363,  5459,  4091,  7163,  1019,  5115, 
     3067,  7931,  1787,  5883,  3323,  6395,   251,  4347,  2299,  7419, 
     1275,  5371,  3835,  6907,   763,  4859,  2811,  8123,  1979,  6075, 
     3515,  6587,   443,  4539,  2491,  7611,  1467,  5563,  3899,  6971, 
      827,  4923,  2875,  7739,  1595,  5691,  3131,  6203,    59,  4155, 
     2107,  7227,  1083,  5179,  3643,  6715,   571,  4667,  2619,  7995, 
     1851,  5947,  3387,  6459,   315,  4411,  2363,  7483,  1339,  5435, 
     4027,  7099,   955,  5051,  3003,  7867,  1723,  5819,  3259,  6331, 
      187,  4283,  2235,  7355,  1211,  5307,  3771,  6843,   699,  4795, 
     2747,  8171,  2027,  6123,  3563,  6635,   491,  4587,  2539,  7659, 
     1515,  5611,  3947,  7019,   875,  4971,  2923,  7787,  1643,  5739, 
     3179,  6251,   107,  4203,  2155,  7275,  1131,  5227,  3691,  6763, 
      619,  4715,  2667,  8043,  1899,  5995,  3435,  6507,   363,  4459, 
     2411,  7531,  1387,  5483,  4043,  7115,   971,  5067,  3019,  7883, 
     1739,  5835,  3275,  6347,   203,  4299,  2251,  7371,  1227,  5323, 
     3787,  6859,   715,  4811,  2763,  8075,  1931,  6027,  3467,  6539, 
      395,  4491,  2443,  7563,  1419,  5515,  3851,  6923,   779,  4875, 
     2827,  7691,  1547,  5643,  3083,  6155,    11,  4107,  2059,  7179, 
     1035,  5131,  3595,  6667,   523,  4619,  2571,  7947,  1803,  5899, 
     3339,  6411,   267,  4363,  2315,  7435,  1291,  5387,  3979,  7051, 
      907,  5003,  2955,  7819,  1675,  5771,  3211,  6283,   139,  4235, 
     2187,  7307,  1163,  5259,  3723,  6795,   651,  4747,  2699,  8139, 
     1995,  6091,  3531,  6603,   459,  4555,  2507,  7627,  1483,  5579, 
     3915,  6987,   843,  4939,  2891,  7755,  1611,  5707,  3147,  6219, 
       75,  4171,  2123,  7243,  1099,  5195,  3659,  6731,   587,  4683, 
     2635,  8011,  1867,  5963,  3403,  6475,   331,  4427,  2379,  7499, 
     1355,  5451,  4075,  7147,  1003,  5099,  3051,  7915,  1771,  5867, 
     3307,  6379,   235,  4331,  2283,  7403,  1259,  5355,  3819,  6891, 
      747,  4843,  2795,  8107,  1963,  6059,  3499,  6571,   427,  4523, 
     2475,  7595,  1451,  5547,  3883,  6955,   811,  4907,  2859,  7723, 
     1579,  5675,  3115,  6187,    43,  4139,  2091,  7211,  1067,  5163, 
     3627,  6699,   555,  4651,  2603,  7979,  1835,  5931,  3371,  6443, 
      299,  4395,  2347,  7467,  1323,  5419,  4011,  7083,   939,  5035, 
     2987,  7851,  1707,  5803,  3243,  6315,   171,  4267,  2219,  7339, 
     1195,  5291,  3755,  6827,   683,  4779,  2731,  8190,  2046,  6142, 
     3582,  6654,   510,  4606,  2558,  7678,  1534,  5630,  3966,  7038, 
      894,  4990,  2942,  7806,  1662,  5758,  3198,  6270,   126,  4222, 
     2174,  7294,  1150,  5246,  3710,  6782,   638,  4734,  2686,  8062, 
     1918,  6014,  3454,  6526,   382,  4478,  2430,  7550,  1406,  5502, 
     4062,  7134,   990,  5086,  3038,  7902,  1758,  5854,  3294,  6366, 
      222,  4318,  2270,  7390,  1246,  5342,  3806,  6878,   734,  4830, 
     2782,  8094,  1950,  6046,  3486,  6558,   414,  4510,  2462,  7582, 
     1438,  5534,  3870,  6942,   798,  4894,  2846,  7710,  1566,  5662, 
     3102,  6174,    30,  4126,  2078,  7198,  1054,  5150,  3614,  6686, 
      542,  4638,  2590,  7966,  1822,  5918,  3358,  6430,   286,  4382, 
     2334,  7454,  1310,  5406,  3998,  7070,   926,  5022,  2974,  7838, 
     1694,  5790,  3230,  6302,   158,  4254,  2206,  7326,  1182,  5278, 
     3742,  6814,   670,  4766,  2718,  8158,  2014,  6110,  3550,  6622, 
      478,  4574,  2526,  7646,  1502,  5598,  3934,  7006,   862,  4958, 
     2910,  7774,  1630,  5726,  3166,  6238,    94,  4190,  2142,  7262, 
     1118,  5214,  3678,  6750,   606,  4702,  2654,  8030,  1886,  5982, 
     3422,  6494,   350,  4446,  2398,  7518,  1374,  5470,  4086,  7158, 
     1014,  5110,  3062,  7926,  1782,  5878,  3318,  6390,   246,  4342, 
     2294,  7414,  1270,  5366,  3830,  6902,   758,  4854,  2806,  8118, 
     1974,  6070,  3510,  6582,   438,  4534,  2486,  7606,  1462,  5558, 
     3894,  6966,   822,  4918,  2870,  7734,  1590,  5686,  3126,  6198, 
       54,  4150,  2102,  7222,  1078,  5174,  3638,  6710,   566,  4662, 
     2614,  7990,  1846,  5942,  3382,  6454,   310,  4406,  2358,  7478, 
     1334,  5430,  4022,  7094,   950,  5046,  2998,  7862,  1718,  5814, 
     3254,  6326,   182,  4278,  2230,  7350,  1206,  5302,  3766,  6838, 
      694,  4790,  2742,  8166,  2022,  6118,  3558,  6630,   486,  4582, 
     2534,  7654,  1510,  5606,  3942,  7014,   870,  4966,  2918,  7782, 
     1638,  5734,  3174,  6246,   102,  4198,  2150,  7270,  1126,  5222, 
     3686,  6758,   614,  4710,  2662,  8038,  1894,  5990,  3430,  6502, 
      358,  4454,  2406,  7526,  1382,  5478,  4038,  7110,   966,  5062, 
     3014,  7878,  1734,  5830,  3270,  6342,   198,  4294,  2246,  7366, 
     1222,  5318,  3782,  6854,   710,  4806,  2758,  8070,  1926,  6022, 
     3462,  6534,   390,  4486,  2438,  7558,  1414,  5510,  3846,  6918, 
      774,  4870,  2822,  7686,  1542,  5638,  3078,  6150,     6,  4102, 
     2054,  7174,  1030,  5126,  3590,  6662,   518,  4614,  2566,  7942, 
     1798,  5894,  3334,  6406,   262,  4358,  2310,  7430,  1286,  5382, 
     3974,  7046,   902,  4998,  2950,  7814,  1670,  5766,  3206,  6278, 
      134,  4230,  2182,  7302,  1158,  5254,  3718,  6790,   646,  4742, 
     2694,  8134,  1990,  6086,  3526,  6598,   454,  4550,  2502,  7622, 
     1478,  5574,  3910,  6982,   838,  4934,  2886,  7750,  1606,  5702, 
     3142,  6214,    70,  4166,  2118,  7238,  1094,  5190,  3654,  6726, 
      582,  4678,  2630,  8006,  1862,  5958,  3398,  6470,   326,  4422, 
     2374,  7494,  1350,  5446,  4070,  7142,   998,  5094,  3046,  7910, 
     1766,  5862,  3302,  6374,   230,  4326,  2278,  7398,  1254,  5350, 
     3814,  6886,   742,  4838,  2790,  8102,  1958,  6054,  3494,  6566, 
      422,  4518,  2470,  7590,  1446,  5542,  3878,  6950,   806,  4902, 
     2854,  7718,  1574,  5670,  3110,  6182,    38,  4134,  2086,  7206, 
     1062,  5158,  3622,  6694,   550,  4646,  2598,  7974,  1830,  5926, 
     3366,  6438,   294,  4390,  2342,  7462,  1318,  5414,  4006,  7078, 
      934,  5030,  2982,  7846,  1702,  5798,  3238,  6310,   166,  4262, 
     2214,  7334,  1190,  5286,  3750,  6822,   678,  4774,  2726,  8182, 
     2038,  6134,  3574,  6646,   502,  4598,  2550,  7670,  1526,  5622, 
     3958,  7030,   886,  4982,  2934,  7798,  1654,  5750,  3190,  6262, 
      118,  4214,  2166,  7286,  1142,  5238,  3702,  6774,   630,  4726, 
     2678,  8054,  1910,  6006,  3446,  6518,   374,  4470,  2422,  7542, 
     1398,  5494,  4054,  7126,   982,  5078,  3030,  7894,  1750,  5846, 
     3286,  6358,   214,  4310,  2262,  7382,  1238,  5334,  3798,  6870, 
      726,  4822,  2774,  8086,  1942,  6038,  3478,  6550,   406,  4502, 
     2454,  7574,  1430,  5526,  3862,  6934,   790,  4886,  2838,  7702, 
     1558,  5654,  3094,  6166,    22,  4118,  2070,  7190,  1046,  5142, 
     3606,  6678,   534,  4630,  2582,  7958,  1814,  5910,  3350,  6422, 
      278,  4374,  2326,  7446,  1302,  5398,  3990,  7062,   918,  5014, 
     2966,  7830,  1686,  5782,  3222,  6294,   150,  4246,  2198,  7318, 
     1174,  5270,  3734,  6806,   662,  4758,  2710,  8150,  2006,  6102, 
     3542,  6614,   470,  4566,  2518,  7638,  1494,  5590,  3926,  6998, 
      854,  4950,  2902,  7766,  1622,  5718,  3158,  6230,    86,  4182, 
     2134,  7254,  1110,  5206,  3670,  6742,   598,  4694,  2646,  8022, 
     1878,  5974,  3414,  6486,   342,  4438,  2390,  7510,  1366,  5462, 
     4092,  7164,  1020,  5116,  3068,  7932,  1788,  5884,  3324,  6396, 
      252,  4348,  2300,  7420,  1276,  5372,  3836,  6908,   764,  4860, 
     2812,  8124,  1980,  6076,  3516,  6588,   444,  4540,  2492,  7612, 
     1468,  5564,  3900,  6972,   828,  4924,  2876,  7740,  1596,  5692, 
     3132,  6204,    60,  4156,  2108,  7228,  1084,  5180,  3644,  6716, 
      572,  4668,  2620,  7996,  1852,  5948,  3388,  6460,   316,  4412, 
     2364,  7484,  1340,  5436,  4028,  7100,   956,  5052,  3004,  7868, 
     1724,  5820,  3260,  6332,   188,  4284,  2236,  7356,  1212,  5308, 
     3772,  6844,   700,  4796,  2748,  8172,  2028,  6124,  3564,  6636, 
      492,  4588,  2540,  7660,  1516,  5612,  3948,  7020,   876,  4972, 
     2924,  7788,  1644,  5740,  3180,  6252,   108,  4204,  2156,  7276, 
     1132,  5228,  3692,  6764,   620,  4716,  2668,  8044,  1900,  5996, 
     3436,  6508,   364,  4460,  2412,  7532,  1388,  5484,  4044,  7116, 
      972,  5068,  3020,  7884,  1740,  5836,  3276,  6348,   204,  4300, 
     2252,  7372,  1228,  5324,  3788,  6860,   716,  4812,  2764,  8076, 
     1932,  6028,  3468,  6540,   396,  4492,  2444,  7564,  1420,  5516, 
     3852,  6924,   780,  4876,  2828,  7692,  1548,  5644,  3084,  6156, 
       12,  4108,  2060,  7180,  1036,  5132,  3596,  6668,   524,  4620, 
     2572,  7948,  1804,  5900,  3340,  6412,   268,  4364,  2316,  7436, 
     1292,  5388,  3980,  7052,   908,  5004,  2956,  7820,  1676,  5772, 
     3212,  6284,   140,  4236,  2188,  7308,  1164,  5260,  3724,  6796, 
      652,  4748,  2700,  8140,  1996,  6092,  3532,  6604,   460,  4556, 
     2508,  7628,  1484,  5580,  3916,  6988,   844,  4940,  2892,  7756, 
     1612,  5708,  3148,  6220,    76,  4172,  2124,  7244,  1100,  5196, 
     3660,  6732,   588,  4684,  2636,  8012,  1868,  5964,  3404,  6476, 
      332,  4428,  2380,  7500,  1356,  5452,  4076,  7148,  1004,  5100, 
     3052,  7916,  1772,  5868,  3308,  6380,   236,  4332,  2284,  7404, 
     1260,  5356,  3820,  6892,   748,  4844,  2796,  8108,  1964,  6060, 
     3500,  6572,   428,  4524,  2476,  7596,  1452,  5548,  3884,  6956, 
      812,  4908,  2860,  7724,  1580,  5676,  3116,  6188,    44,  4140, 
     2092,  7212,  1068,  5164,  3628,  6700,   556,  4652,  2604,  7980, 
     1836,  5932,  3372,  6444,   300,  4396,  2348,  7468,  1324,  5420, 
     4012,  7084,   940,  5036,  2988,  7852,  1708,  5804,  3244,  6316, 
      172,  4268,  2220,  7340,  1196,  5292,  3756,  6828,   684,  4780, 
     2732,  8184,  2040,  6136,  3576,  6648,   504,  4600,  2552,  7672, 
     1528,  5624,  3960,  7032,   888,  4984,  2936,  7800,  1656,  5752, 
     3192,  6264,   120,  4216,  2168,  7288,  1144,  5240,  3704,  6776, 
      632,  4728,  2680,  8056,  1912,  6008,  3448,  6520,   376,  4472, 
     2424,  7544,  1400,  5496,  4056,  7128,   984,  5080,  3032,  7896, 
     1752,  5848,  3288,  6360,   216,  4312,  2264,  7384,  1240,  5336, 
     3800,  6872,   728,  4824,  2776,  8088,  1944,  6040,  3480,  6552, 
      408,  4504,  2456,  7576,  1432,  5528,  3864,  6936,   792,  4888, 
     2840,  7704,  1560,  5656,  3096,  6168,    24,  4120,  2072,  7192, 
     1048,  5144,  3608,  6680,   536,  4632,  2584,  7960,  1816,  5912, 
     3352,  6424,   280,  4376,  2328,  7448,  1304,  5400,  3992,  7064, 
      920,  5016,  2968,  7832,  1688,  5784,  3224,  6296,   152,  4248, 
     2200,  7320,  1176,  5272,  3736,  6808,   664,  4760,  2712,  8152, 
     2008,  6104,  3544,  6616,   472,  4568,  2520,  7640,  1496,  5592, 
     3928,  7000,   856,  4952,  2904,  7768,  1624,  5720,  3160,  6232, 
       88,  4184,  2136,  7256,  1112,  5208,  3672,  6744,   600,  4696, 
     2648,  8024,  1880,  5976,  3416,  6488,   344,  4440,  2392,  7512, 
     1368,  5464,  4080,  7152,  1008,  5104,  3056,  7920,  1776,  5872, 
     3312,  6384,   240,  4336,  2288,  7408,  1264,  5360,  3824,  6896, 
      752,  4848,  2800,  8112,  1968,  6064,  3504,  6576,   432,  4528, 
     2480,  7600,  1456,  5552,  3888,  6960,   816,  4912,  2864,  7728, 
     1584,  5680,  3120,  6192,    48,  4144,  2096,  7216,  1072,  5168, 
     3632,  6704,   560,  4656,  2608,  7984,  1840,  5936,  3376,  6448, 
      304,  4400,  2352,  7472,  1328,  5424,  4016,  7088,   944,  5040, 
     2992,  7856,  1712,  5808,  3248,  6320,   176,  4272,  2224,  7344, 
     1200,  5296,  3760,  6832,   688,  4784,  2736,  8160,  2016,  6112, 
     3552,  6624,   480,  4576,  2528,  7648,  1504,  5600,  3936,  7008, 
      864,  4960,  2912,  7776,  1632,  5728,  3168,  6240,    96,  4192, 
     2144,  7264,  1120,  5216,  3680,  6752,   608,  4704,  2656,  8032, 
     1888,  5984,  3424,  6496,   352,  4448,  2400,  7520,  1376,  5472, 
     4032,  7104,   960,  5056,  3008,  7872,  1728,  5824,  3264,  6336, 
      192,  4288,  2240,  7360,  1216,  5312,  3776,  6848,   704,  4800, 
     2752,  8064,  1920,  6016,  3456,  6528,   384,  4480,  2432,  7552, 
     1408,  5504,  3840,  6912,   768,  4864,  2816,  7680,  1536,  5632, 
     3072,  6144
  );
  {$ENDIF}

  {$IFDEF CALC_SINCOS_TABLE}
var
  d16: array[0..2] of TComplex;
  d32: array[0..6] of TComplex;
  d64: array[0..14] of TComplex;
  d128: array[0..30] of TComplex;
  d256: array[0..62] of TComplex;
  d512: array[0..126] of TComplex;
  d1024: array[0..126] of TComplex;
  d2048: array[0..254] of TComplex;
  d4096: array[0..510] of TComplex;
  d8192: array[0..1022] of TComplex;
  {$ELSE}
const
  d16: array[0..2] of TComplex = (
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 7.07106781186547524E-1; im: 7.07106781186547524E-1),
    (re: 3.82683432365089772E-1; im: 9.23879532511286756E-1)
  );
  d32: array[0..6] of TComplex = (
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 7.07106781186547524E-1; im: 7.07106781186547524E-1),
    (re: 5.55570233019602225E-1; im: 8.31469612302545237E-1),
    (re: 3.82683432365089772E-1; im: 9.23879532511286756E-1),
    (re: 1.95090322016128268E-1; im: 9.80785280403230449E-1)
  );
  d64: array[0..14] of TComplex = (
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.07106781186547524E-1; im: 7.07106781186547524E-1),
    (re: 6.34393284163645498E-1; im: 7.73010453362736961E-1),
    (re: 5.55570233019602225E-1; im: 8.31469612302545237E-1),
    (re: 4.71396736825997649E-1; im: 8.81921264348355030E-1),
    (re: 3.82683432365089772E-1; im: 9.23879532511286756E-1),
    (re: 2.90284677254462368E-1; im: 9.56940335732208865E-1),
    (re: 1.95090322016128268E-1; im: 9.80785280403230449E-1),
    (re: 9.80171403295606019E-2; im: 9.95184726672196886E-1)
  );
  d128: array[0..30] of TComplex = (
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.07106781186547524E-1; im: 7.07106781186547524E-1),
    (re: 6.71558954847018401E-1; im: 7.40951125354959091E-1),
    (re: 6.34393284163645498E-1; im: 7.73010453362736961E-1),
    (re: 5.95699304492433343E-1; im: 8.03207531480644910E-1),
    (re: 5.55570233019602225E-1; im: 8.31469612302545237E-1),
    (re: 5.14102744193221727E-1; im: 8.57728610000272070E-1),
    (re: 4.71396736825997649E-1; im: 8.81921264348355030E-1),
    (re: 4.27555093430282094E-1; im: 9.03989293123443332E-1),
    (re: 3.82683432365089772E-1; im: 9.23879532511286756E-1),
    (re: 3.36889853392220051E-1; im: 9.41544065183020778E-1),
    (re: 2.90284677254462368E-1; im: 9.56940335732208865E-1),
    (re: 2.42980179903263890E-1; im: 9.70031253194543993E-1),
    (re: 1.95090322016128268E-1; im: 9.80785280403230449E-1),
    (re: 1.46730474455361752E-1; im: 9.89176509964780973E-1),
    (re: 9.80171403295606019E-2; im: 9.95184726672196886E-1),
    (re: 4.90676743274180143E-2; im: 9.98795456205172393E-1)
  );
  d256: array[0..62] of TComplex = (
    (re: 9.99698818696204220E-1; im: 2.45412285229122880E-2),
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.97290456678690216E-1; im: 7.35645635996674235E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.92479534598709998E-1; im: 1.22410675199216198E-1),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.85277642388941245E-1; im: 1.70961888760301226E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.75702130038528544E-1; im: 2.19101240156869797E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.63776065795439867E-1; im: 2.66712757474898386E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.49528180593036667E-1; im: 3.13681740398891477E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.32992798834738888E-1; im: 3.59895036534988149E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.14209755703530655E-1; im: 4.05241314004989871E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 8.93224301195515320E-1; im: 4.49611329654606600E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.70086991108711419E-1; im: 4.92898192229784037E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.44853565249707073E-1; im: 5.34997619887097211E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.17584813151583697E-1; im: 5.75808191417845301E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 7.88346427626606262E-1; im: 6.15231590580626846E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.57208846506484548E-1; im: 6.53172842953776764E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.24247082951466921E-1; im: 6.89540544737066925E-1),
    (re: 7.07106781186547524E-1; im: 7.07106781186547524E-1),
    (re: 6.89540544737066925E-1; im: 7.24247082951466921E-1),
    (re: 6.71558954847018401E-1; im: 7.40951125354959091E-1),
    (re: 6.53172842953776764E-1; im: 7.57208846506484548E-1),
    (re: 6.34393284163645498E-1; im: 7.73010453362736961E-1),
    (re: 6.15231590580626846E-1; im: 7.88346427626606262E-1),
    (re: 5.95699304492433343E-1; im: 8.03207531480644910E-1),
    (re: 5.75808191417845301E-1; im: 8.17584813151583697E-1),
    (re: 5.55570233019602225E-1; im: 8.31469612302545237E-1),
    (re: 5.34997619887097211E-1; im: 8.44853565249707073E-1),
    (re: 5.14102744193221727E-1; im: 8.57728610000272070E-1),
    (re: 4.92898192229784037E-1; im: 8.70086991108711419E-1),
    (re: 4.71396736825997649E-1; im: 8.81921264348355030E-1),
    (re: 4.49611329654606600E-1; im: 8.93224301195515320E-1),
    (re: 4.27555093430282094E-1; im: 9.03989293123443332E-1),
    (re: 4.05241314004989871E-1; im: 9.14209755703530655E-1),
    (re: 3.82683432365089772E-1; im: 9.23879532511286756E-1),
    (re: 3.59895036534988149E-1; im: 9.32992798834738888E-1),
    (re: 3.36889853392220051E-1; im: 9.41544065183020778E-1),
    (re: 3.13681740398891477E-1; im: 9.49528180593036667E-1),
    (re: 2.90284677254462368E-1; im: 9.56940335732208865E-1),
    (re: 2.66712757474898386E-1; im: 9.63776065795439867E-1),
    (re: 2.42980179903263890E-1; im: 9.70031253194543993E-1),
    (re: 2.19101240156869797E-1; im: 9.75702130038528544E-1),
    (re: 1.95090322016128268E-1; im: 9.80785280403230449E-1),
    (re: 1.70961888760301226E-1; im: 9.85277642388941245E-1),
    (re: 1.46730474455361752E-1; im: 9.89176509964780973E-1),
    (re: 1.22410675199216198E-1; im: 9.92479534598709998E-1),
    (re: 9.80171403295606019E-2; im: 9.95184726672196886E-1),
    (re: 7.35645635996674234E-2; im: 9.97290456678690216E-1),
    (re: 4.90676743274180143E-2; im: 9.98795456205172393E-1),
    (re: 2.45412285229122880E-2; im: 9.99698818696204220E-1)
  );
  d512: array[0..126] of TComplex = (
    (re: 9.99924701839144541E-1; im: 1.22715382857199261E-2),
    (re: 9.99698818696204220E-1; im: 2.45412285229122880E-2),
    (re: 9.99322384588349501E-1; im: 3.68072229413588323E-2),
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.98118112900149207E-1; im: 6.13207363022085778E-2),
    (re: 9.97290456678690216E-1; im: 7.35645635996674235E-2),
    (re: 9.96312612182778013E-1; im: 8.57973123444398905E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.93906970002356042E-1; im: 1.10222207293883059E-1),
    (re: 9.92479534598709998E-1; im: 1.22410675199216198E-1),
    (re: 9.90902635427780025E-1; im: 1.34580708507126186E-1),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.87301418157858382E-1; im: 1.58858143333861442E-1),
    (re: 9.85277642388941245E-1; im: 1.70961888760301226E-1),
    (re: 9.83105487431216327E-1; im: 1.83039887955140959E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.78317370719627633E-1; im: 2.07111376192218550E-1),
    (re: 9.75702130038528544E-1; im: 2.19101240156869797E-1),
    (re: 9.72939952205560145E-1; im: 2.31058108280671120E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.66976471044852109E-1; im: 2.54865659604514572E-1),
    (re: 9.63776065795439867E-1; im: 2.66712757474898386E-1),
    (re: 9.60430519415565811E-1; im: 2.78519689385053105E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.53306040354193837E-1; im: 3.02005949319228067E-1),
    (re: 9.49528180593036667E-1; im: 3.13681740398891477E-1),
    (re: 9.45607325380521326E-1; im: 3.25310292162262934E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.37339011912574923E-1; im: 3.48418680249434568E-1),
    (re: 9.32992798834738888E-1; im: 3.59895036534988149E-1),
    (re: 9.28506080473215566E-1; im: 3.71317193951837543E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.19113851690057744E-1; im: 3.93992040061048109E-1),
    (re: 9.14209755703530655E-1; im: 4.05241314004989871E-1),
    (re: 9.09167983090522377E-1; im: 4.16429560097637183E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 8.98674465693953843E-1; im: 4.38616238538527638E-1),
    (re: 8.93224301195515320E-1; im: 4.49611329654606600E-1),
    (re: 8.87639620402853948E-1; im: 4.60538710958240024E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.76070094195406607E-1; im: 4.82183772079122749E-1),
    (re: 8.70086991108711419E-1; im: 4.92898192229784037E-1),
    (re: 8.63972856121586738E-1; im: 5.03538383725717559E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.51355193105265142E-1; im: 5.24589682678468906E-1),
    (re: 8.44853565249707073E-1; im: 5.34997619887097211E-1),
    (re: 8.38224705554838043E-1; im: 5.45324988422046422E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.24589302785025264E-1; im: 5.65731810783613197E-1),
    (re: 8.17584813151583697E-1; im: 5.75808191417845301E-1),
    (re: 8.10457198252594792E-1; im: 5.85797857456438860E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 7.95836904608883536E-1; im: 6.05511041404325514E-1),
    (re: 7.88346427626606262E-1; im: 6.15231590580626846E-1),
    (re: 7.80737228572094478E-1; im: 6.24859488142386377E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.65167265622458926E-1; im: 6.43831542889791465E-1),
    (re: 7.57208846506484548E-1; im: 6.53172842953776764E-1),
    (re: 7.49136394523459326E-1; im: 6.62415777590171761E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.32654271672412835E-1; im: 6.80600997795453051E-1),
    (re: 7.24247082951466921E-1; im: 6.89540544737066925E-1),
    (re: 7.15730825283818654E-1; im: 6.98376249408972854E-1),
    (re: 7.07106781186547524E-1; im: 7.07106781186547524E-1),
    (re: 6.98376249408972854E-1; im: 7.15730825283818654E-1),
    (re: 6.89540544737066925E-1; im: 7.24247082951466921E-1),
    (re: 6.80600997795453051E-1; im: 7.32654271672412835E-1),
    (re: 6.71558954847018401E-1; im: 7.40951125354959091E-1),
    (re: 6.62415777590171761E-1; im: 7.49136394523459326E-1),
    (re: 6.53172842953776764E-1; im: 7.57208846506484548E-1),
    (re: 6.43831542889791465E-1; im: 7.65167265622458926E-1),
    (re: 6.34393284163645498E-1; im: 7.73010453362736961E-1),
    (re: 6.24859488142386377E-1; im: 7.80737228572094478E-1),
    (re: 6.15231590580626846E-1; im: 7.88346427626606262E-1),
    (re: 6.05511041404325514E-1; im: 7.95836904608883536E-1),
    (re: 5.95699304492433343E-1; im: 8.03207531480644910E-1),
    (re: 5.85797857456438860E-1; im: 8.10457198252594792E-1),
    (re: 5.75808191417845301E-1; im: 8.17584813151583697E-1),
    (re: 5.65731810783613197E-1; im: 8.24589302785025264E-1),
    (re: 5.55570233019602225E-1; im: 8.31469612302545237E-1),
    (re: 5.45324988422046422E-1; im: 8.38224705554838043E-1),
    (re: 5.34997619887097211E-1; im: 8.44853565249707073E-1),
    (re: 5.24589682678468906E-1; im: 8.51355193105265142E-1),
    (re: 5.14102744193221727E-1; im: 8.57728610000272070E-1),
    (re: 5.03538383725717559E-1; im: 8.63972856121586738E-1),
    (re: 4.92898192229784037E-1; im: 8.70086991108711419E-1),
    (re: 4.82183772079122748E-1; im: 8.76070094195406607E-1),
    (re: 4.71396736825997649E-1; im: 8.81921264348355030E-1),
    (re: 4.60538710958240024E-1; im: 8.87639620402853948E-1),
    (re: 4.49611329654606600E-1; im: 8.93224301195515320E-1),
    (re: 4.38616238538527638E-1; im: 8.98674465693953843E-1),
    (re: 4.27555093430282094E-1; im: 9.03989293123443332E-1),
    (re: 4.16429560097637182E-1; im: 9.09167983090522377E-1),
    (re: 4.05241314004989871E-1; im: 9.14209755703530655E-1),
    (re: 3.93992040061048109E-1; im: 9.19113851690057744E-1),
    (re: 3.82683432365089772E-1; im: 9.23879532511286756E-1),
    (re: 3.71317193951837543E-1; im: 9.28506080473215566E-1),
    (re: 3.59895036534988149E-1; im: 9.32992798834738888E-1),
    (re: 3.48418680249434568E-1; im: 9.37339011912574923E-1),
    (re: 3.36889853392220051E-1; im: 9.41544065183020778E-1),
    (re: 3.25310292162262934E-1; im: 9.45607325380521326E-1),
    (re: 3.13681740398891477E-1; im: 9.49528180593036667E-1),
    (re: 3.02005949319228067E-1; im: 9.53306040354193837E-1),
    (re: 2.90284677254462368E-1; im: 9.56940335732208865E-1),
    (re: 2.78519689385053105E-1; im: 9.60430519415565811E-1),
    (re: 2.66712757474898386E-1; im: 9.63776065795439867E-1),
    (re: 2.54865659604514572E-1; im: 9.66976471044852109E-1),
    (re: 2.42980179903263890E-1; im: 9.70031253194543993E-1),
    (re: 2.31058108280671120E-1; im: 9.72939952205560145E-1),
    (re: 2.19101240156869797E-1; im: 9.75702130038528544E-1),
    (re: 2.07111376192218550E-1; im: 9.78317370719627633E-1),
    (re: 1.95090322016128268E-1; im: 9.80785280403230449E-1),
    (re: 1.83039887955140958E-1; im: 9.83105487431216327E-1),
    (re: 1.70961888760301226E-1; im: 9.85277642388941245E-1),
    (re: 1.58858143333861442E-1; im: 9.87301418157858382E-1),
    (re: 1.46730474455361752E-1; im: 9.89176509964780973E-1),
    (re: 1.34580708507126186E-1; im: 9.90902635427780025E-1),
    (re: 1.22410675199216198E-1; im: 9.92479534598709998E-1),
    (re: 1.10222207293883059E-1; im: 9.93906970002356042E-1),
    (re: 9.80171403295606019E-2; im: 9.95184726672196886E-1),
    (re: 8.57973123444398904E-2; im: 9.96312612182778013E-1),
    (re: 7.35645635996674234E-2; im: 9.97290456678690216E-1),
    (re: 6.13207363022085778E-2; im: 9.98118112900149207E-1),
    (re: 4.90676743274180143E-2; im: 9.98795456205172393E-1),
    (re: 3.68072229413588323E-2; im: 9.99322384588349501E-1),
    (re: 2.45412285229122880E-2; im: 9.99698818696204220E-1),
    (re: 1.22715382857199260E-2; im: 9.99924701839144541E-1)
  );
  d1024: array[0..126] of TComplex = (
    (re: 9.99981175282601143E-1; im: 6.13588464915447536E-3),
    (re: 9.99924701839144541E-1; im: 1.22715382857199261E-2),
    (re: 9.99830581795823422E-1; im: 1.84067299058048209E-2),
    (re: 9.99698818696204220E-1; im: 2.45412285229122880E-2),
    (re: 9.99529417501093163E-1; im: 3.06748031766366259E-2),
    (re: 9.99322384588349501E-1; im: 3.68072229413588323E-2),
    (re: 9.99077727752645383E-1; im: 4.29382569349408231E-2),
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.98475580573294752E-1; im: 5.51952443496899398E-2),
    (re: 9.98118112900149207E-1; im: 6.13207363022085778E-2),
    (re: 9.97723066644191610E-1; im: 6.74439195636640579E-2),
    (re: 9.97290456678690216E-1; im: 7.35645635996674235E-2),
    (re: 9.96820299291165715E-1; im: 7.96824379714301212E-2),
    (re: 9.96312612182778013E-1; im: 8.57973123444398905E-2),
    (re: 9.95767414467659794E-1; im: 9.19089564971327286E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.94564570734255452E-1; im: 1.04121633872054579E-1),
    (re: 9.93906970002356042E-1; im: 1.10222207293883059E-1),
    (re: 9.93211949234794533E-1; im: 1.16318630911904767E-1),
    (re: 9.92479534598709998E-1; im: 1.22410675199216198E-1),
    (re: 9.91709753669099523E-1; im: 1.28498110793793173E-1),
    (re: 9.90902635427780025E-1; im: 1.34580708507126186E-1),
    (re: 9.90058210262297106E-1; im: 1.40658239332849231E-1),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.88257567730749491E-1; im: 1.52797185258443428E-1),
    (re: 9.87301418157858382E-1; im: 1.58858143333861442E-1),
    (re: 9.86308097244598648E-1; im: 1.64913120489969921E-1),
    (re: 9.85277642388941245E-1; im: 1.70961888760301226E-1),
    (re: 9.84210092386929073E-1; im: 1.77004220412148756E-1),
    (re: 9.83105487431216327E-1; im: 1.83039887955140959E-1),
    (re: 9.81963869109555264E-1; im: 1.89068664149806213E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.79569765685440534E-1; im: 2.01104634842091912E-1),
    (re: 9.78317370719627633E-1; im: 2.07111376192218550E-1),
    (re: 9.77028142657754352E-1; im: 2.13110319916091374E-1),
    (re: 9.75702130038528544E-1; im: 2.19101240156869797E-1),
    (re: 9.74339382785575861E-1; im: 2.25083911359792836E-1),
    (re: 9.72939952205560145E-1; im: 2.31058108280671120E-1),
    (re: 9.71503890986251776E-1; im: 2.37023605994367207E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.68522094274417316E-1; im: 2.48927605745720168E-1),
    (re: 9.66976471044852109E-1; im: 2.54865659604514572E-1),
    (re: 9.65394441697689375E-1; im: 2.60794117915275518E-1),
    (re: 9.63776065795439867E-1; im: 2.66712757474898386E-1),
    (re: 9.62121404269041595E-1; im: 2.72621355449948984E-1),
    (re: 9.60430519415565811E-1; im: 2.78519689385053105E-1),
    (re: 9.58703474895871555E-1; im: 2.84407537211271844E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.55141168305770722E-1; im: 2.96150888243623824E-1),
    (re: 9.53306040354193837E-1; im: 3.02005949319228067E-1),
    (re: 9.51435020969008370E-1; im: 3.07849640041534894E-1),
    (re: 9.49528180593036667E-1; im: 3.13681740398891477E-1),
    (re: 9.47585591017741135E-1; im: 3.19502030816015678E-1),
    (re: 9.45607325380521326E-1; im: 3.25310292162262934E-1),
    (re: 9.43593458161960361E-1; im: 3.31106305759876402E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.39459223602189912E-1; im: 3.42660717311994398E-1),
    (re: 9.37339011912574923E-1; im: 3.48418680249434568E-1),
    (re: 9.35183509938947578E-1; im: 3.54163525420490382E-1),
    (re: 9.32992798834738888E-1; im: 3.59895036534988149E-1),
    (re: 9.30766961078983732E-1; im: 3.65612997804773870E-1),
    (re: 9.28506080473215566E-1; im: 3.71317193951837543E-1),
    (re: 9.26210242138311342E-1; im: 3.77007410216418257E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.21514039342041943E-1; im: 3.88345046698826292E-1),
    (re: 9.19113851690057744E-1; im: 3.93992040061048109E-1),
    (re: 9.16679059921042663E-1; im: 3.99624199845646829E-1),
    (re: 9.14209755703530655E-1; im: 4.05241314004989871E-1),
    (re: 9.11706032005429851E-1; im: 4.10843171057903942E-1),
    (re: 9.09167983090522377E-1; im: 4.16429560097637183E-1),
    (re: 9.06595704514915365E-1; im: 4.22000270799799686E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 9.01348847046022015E-1; im: 4.33093818853151968E-1),
    (re: 8.98674465693953843E-1; im: 4.38616238538527638E-1),
    (re: 8.95966249756185156E-1; im: 4.44122144570429232E-1),
    (re: 8.93224301195515320E-1; im: 4.49611329654606600E-1),
    (re: 8.90448723244757890E-1; im: 4.55083587126343824E-1),
    (re: 8.87639620402853948E-1; im: 4.60538710958240024E-1),
    (re: 8.84797098430937780E-1; im: 4.65976495767966178E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.79012226428633478E-1; im: 4.76799230063322133E-1),
    (re: 8.76070094195406607E-1; im: 4.82183772079122749E-1),
    (re: 8.73094978418290099E-1; im: 4.87550160148435955E-1),
    (re: 8.70086991108711419E-1; im: 4.92898192229784037E-1),
    (re: 8.67046245515692652E-1; im: 4.98227666972781852E-1),
    (re: 8.63972856121586738E-1; im: 5.03538383725717559E-1),
    (re: 8.60866938637767279E-1; im: 5.08830142543107037E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.54557988365400521E-1; im: 5.19355990165589587E-1),
    (re: 8.51355193105265142E-1; im: 5.24589682678468906E-1),
    (re: 8.48120344803297251E-1; im: 5.29803624686294668E-1),
    (re: 8.44853565249707073E-1; im: 5.34997619887097211E-1),
    (re: 8.41554977436898410E-1; im: 5.40171472729892881E-1),
    (re: 8.38224705554838043E-1; im: 5.45324988422046422E-1),
    (re: 8.34862874986380056E-1; im: 5.50457972936604803E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.28045045257755752E-1; im: 5.60661576197336024E-1),
    (re: 8.24589302785025264E-1; im: 5.65731810783613197E-1),
    (re: 8.21102514991104679E-1; im: 5.70780745886967280E-1),
    (re: 8.17584813151583697E-1; im: 5.75808191417845301E-1),
    (re: 8.14036329705948362E-1; im: 5.80813958095764545E-1),
    (re: 8.10457198252594792E-1; im: 5.85797857456438860E-1),
    (re: 8.06847553543799272E-1; im: 5.90759701858874228E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 7.99537269107905034E-1; im: 6.00616479383868927E-1),
    (re: 7.95836904608883536E-1; im: 6.05511041404325514E-1),
    (re: 7.92106577300212352E-1; im: 6.10382806276309453E-1),
    (re: 7.88346427626606262E-1; im: 6.15231590580626846E-1),
    (re: 7.84556597155575233E-1; im: 6.20057211763289179E-1),
    (re: 7.80737228572094478E-1; im: 6.24859488142386377E-1),
    (re: 7.76888465673232450E-1; im: 6.29638238914927025E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.69103337645579639E-1; im: 6.39124444863775744E-1),
    (re: 7.65167265622458926E-1; im: 6.43831542889791465E-1),
    (re: 7.61202385484261814E-1; im: 6.48514401022112445E-1),
    (re: 7.57208846506484548E-1; im: 6.53172842953776764E-1),
    (re: 7.53186799043612482E-1; im: 6.57806693297078657E-1),
    (re: 7.49136394523459326E-1; im: 6.62415777590171761E-1),
    (re: 7.45057785441465962E-1; im: 6.66999922303637507E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.36816568877369875E-1; im: 6.76092703575315960E-1),
    (re: 7.32654271672412835E-1; im: 6.80600997795453051E-1),
    (re: 7.28464390448225196E-1; im: 6.85083667772700381E-1),
    (re: 7.24247082951466921E-1; im: 6.89540544737066925E-1),
    (re: 7.20002507961381629E-1; im: 6.93971460889654009E-1),
    (re: 7.15730825283818654E-1; im: 6.98376249408972854E-1),
    (re: 7.11432195745216442E-1; im: 7.02754744457225302E-1)
  )
;
  d2048: array[0..254] of TComplex = (
    (re: 9.99995293809576172E-1; im: 3.06795676296597627E-3),
    (re: 9.99981175282601143E-1; im: 6.13588464915447536E-3),
    (re: 9.99957644551963866E-1; im: 9.20375478205981932E-3),
    (re: 9.99924701839144541E-1; im: 1.22715382857199261E-2),
    (re: 9.99882347454212526E-1; im: 1.53392062849881010E-2),
    (re: 9.99830581795823422E-1; im: 1.84067299058048209E-2),
    (re: 9.99769405351215322E-1; im: 2.14740802754695074E-2),
    (re: 9.99698818696204220E-1; im: 2.45412285229122880E-2),
    (re: 9.99618822495178597E-1; im: 2.76081457789657416E-2),
    (re: 9.99529417501093163E-1; im: 3.06748031766366259E-2),
    (re: 9.99430604555461772E-1; im: 3.37411718513775848E-2),
    (re: 9.99322384588349501E-1; im: 3.68072229413588323E-2),
    (re: 9.99204758618363896E-1; im: 3.98729275877398111E-2),
    (re: 9.99077727752645383E-1; im: 4.29382569349408231E-2),
    (re: 9.98941293186856851E-1; im: 4.60031821309146288E-2),
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.98640218180265222E-1; im: 5.21317046802833212E-2),
    (re: 9.98475580573294752E-1; im: 5.51952443496899398E-2),
    (re: 9.98301544933892841E-1; im: 5.82582645004357596E-2),
    (re: 9.98118112900149207E-1; im: 6.13207363022085778E-2),
    (re: 9.97925286198596013E-1; im: 6.43826309298574608E-2),
    (re: 9.97723066644191610E-1; im: 6.74439195636640579E-2),
    (re: 9.97511456140303460E-1; im: 7.05045733896138630E-2),
    (re: 9.97290456678690216E-1; im: 7.35645635996674235E-2),
    (re: 9.97060070339482979E-1; im: 7.66238613920314923E-2),
    (re: 9.96820299291165715E-1; im: 7.96824379714301212E-2),
    (re: 9.96571145790554847E-1; im: 8.27402645493756931E-2),
    (re: 9.96312612182778013E-1; im: 8.57973123444398905E-2),
    (re: 9.96044700901251990E-1; im: 8.88535525825245966E-2),
    (re: 9.95767414467659794E-1; im: 9.19089564971327286E-2),
    (re: 9.95480755491926942E-1; im: 9.49634953296389989E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.94879330794805621E-1; im: 1.01069862754827825E-1),
    (re: 9.94564570734255452E-1; im: 1.04121633872054579E-1),
    (re: 9.94240449453187946E-1; im: 1.07172424956808849E-1),
    (re: 9.93906970002356042E-1; im: 1.10222207293883059E-1),
    (re: 9.93564135520595334E-1; im: 1.13270952177564349E-1),
    (re: 9.93211949234794533E-1; im: 1.16318630911904767E-1),
    (re: 9.92850414459865091E-1; im: 1.19365214810991365E-1),
    (re: 9.92479534598709998E-1; im: 1.22410675199216198E-1),
    (re: 9.92099313142191757E-1; im: 1.25454983411546239E-1),
    (re: 9.91709753669099523E-1; im: 1.28498110793793173E-1),
    (re: 9.91310859846115419E-1; im: 1.31540028702883111E-1),
    (re: 9.90902635427780025E-1; im: 1.34580708507126186E-1),
    (re: 9.90485084256457038E-1; im: 1.37620121586486045E-1),
    (re: 9.90058210262297106E-1; im: 1.40658239332849231E-1),
    (re: 9.89622017463200835E-1; im: 1.43695033150294455E-1),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.88721691960323768E-1; im: 1.49764534677321517E-1),
    (re: 9.88257567730749491E-1; im: 1.52797185258443428E-1),
    (re: 9.87784141644572154E-1; im: 1.55828397654265236E-1),
    (re: 9.87301418157858382E-1; im: 1.58858143333861442E-1),
    (re: 9.86809401814185477E-1; im: 1.61886393780111838E-1),
    (re: 9.86308097244598648E-1; im: 1.64913120489969921E-1),
    (re: 9.85797509167567425E-1; im: 1.67938294974731178E-1),
    (re: 9.85277642388941245E-1; im: 1.70961888760301226E-1),
    (re: 9.84748501801904219E-1; im: 1.73983873387463828E-1),
    (re: 9.84210092386929073E-1; im: 1.77004220412148756E-1),
    (re: 9.83662419211730274E-1; im: 1.80022901405699523E-1),
    (re: 9.83105487431216327E-1; im: 1.83039887955140959E-1),
    (re: 9.82539302287441256E-1; im: 1.86055151663446648E-1),
    (re: 9.81963869109555264E-1; im: 1.89068664149806213E-1),
    (re: 9.81379193313754574E-1; im: 1.92080397049892442E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.80182135968117393E-1; im: 1.98098410717953586E-1),
    (re: 9.79569765685440534E-1; im: 2.01104634842091912E-1),
    (re: 9.78948175319062195E-1; im: 2.04108966092816874E-1),
    (re: 9.78317370719627633E-1; im: 2.07111376192218550E-1),
    (re: 9.77677357824509980E-1; im: 2.10111836880469622E-1),
    (re: 9.77028142657754352E-1; im: 2.13110319916091374E-1),
    (re: 9.76369731330021149E-1; im: 2.16106797076219510E-1),
    (re: 9.75702130038528544E-1; im: 2.19101240156869797E-1),
    (re: 9.75025345066994147E-1; im: 2.22093620973203534E-1),
    (re: 9.74339382785575861E-1; im: 2.25083911359792836E-1),
    (re: 9.73644249650811925E-1; im: 2.28072083170885739E-1),
    (re: 9.72939952205560145E-1; im: 2.31058108280671120E-1),
    (re: 9.72226497078936306E-1; im: 2.34041958583543423E-1),
    (re: 9.71503890986251776E-1; im: 2.37023605994367207E-1),
    (re: 9.70772140728950302E-1; im: 2.40003022448741487E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.69281235356548486E-1; im: 2.45955050335794612E-1),
    (re: 9.68522094274417316E-1; im: 2.48927605745720168E-1),
    (re: 9.67753837093475465E-1; im: 2.51897818154216950E-1),
    (re: 9.66976471044852109E-1; im: 2.54865659604514572E-1),
    (re: 9.66190003445412555E-1; im: 2.57831102162159006E-1),
    (re: 9.65394441697689375E-1; im: 2.60794117915275518E-1),
    (re: 9.64589793289812724E-1; im: 2.63754678974831384E-1),
    (re: 9.63776065795439867E-1; im: 2.66712757474898386E-1),
    (re: 9.62953266873683886E-1; im: 2.69668325572915107E-1),
    (re: 9.62121404269041595E-1; im: 2.72621355449948984E-1),
    (re: 9.61280485811320642E-1; im: 2.75571819310958163E-1),
    (re: 9.60430519415565811E-1; im: 2.78519689385053105E-1),
    (re: 9.59571513081984528E-1; im: 2.81464937925757984E-1),
    (re: 9.58703474895871555E-1; im: 2.84407537211271844E-1),
    (re: 9.57826413027532890E-1; im: 2.87347459544729526E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.56045251349996443E-1; im: 2.93219162694258651E-1),
    (re: 9.55141168305770722E-1; im: 2.96150888243623824E-1),
    (re: 9.54228095109105630E-1; im: 2.99079826308040477E-1),
    (re: 9.53306040354193837E-1; im: 3.02005949319228067E-1),
    (re: 9.52375012719765858E-1; im: 3.04929229735402406E-1),
    (re: 9.51435020969008370E-1; im: 3.07849640041534894E-1),
    (re: 9.50486073949481722E-1; im: 3.10767152749611496E-1),
    (re: 9.49528180593036667E-1; im: 3.13681740398891477E-1),
    (re: 9.48561349915730288E-1; im: 3.16593375556165867E-1),
    (re: 9.47585591017741135E-1; im: 3.19502030816015678E-1),
    (re: 9.46600913083283570E-1; im: 3.22407678801069848E-1),
    (re: 9.45607325380521326E-1; im: 3.25310292162262934E-1),
    (re: 9.44604837261480266E-1; im: 3.28209843579092526E-1),
    (re: 9.43593458161960361E-1; im: 3.31106305759876402E-1),
    (re: 9.42573197601446879E-1; im: 3.33999651442009405E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.40506070593268324E-1; im: 3.39776884406826858E-1),
    (re: 9.39459223602189912E-1; im: 3.42660717311994398E-1),
    (re: 9.38403534063108112E-1; im: 3.45541324963989066E-1),
    (re: 9.37339011912574923E-1; im: 3.48418680249434568E-1),
    (re: 9.36265667170278247E-1; im: 3.51292756085567126E-1),
    (re: 9.35183509938947578E-1; im: 3.54163525420490382E-1),
    (re: 9.34092550404258915E-1; im: 3.57030961233430033E-1),
    (re: 9.32992798834738888E-1; im: 3.59895036534988149E-1),
    (re: 9.31884265581668107E-1; im: 3.62755724367397216E-1),
    (re: 9.30766961078983732E-1; im: 3.65612997804773870E-1),
    (re: 9.29640895843181265E-1; im: 3.68466829953372332E-1),
    (re: 9.28506080473215566E-1; im: 3.71317193951837543E-1),
    (re: 9.27362525650401087E-1; im: 3.74164062971457997E-1),
    (re: 9.26210242138311342E-1; im: 3.77007410216418257E-1),
    (re: 9.25049240782677590E-1; im: 3.79847208924051171E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.22701128333878570E-1; im: 3.85516053843918864E-1),
    (re: 9.21514039342041943E-1; im: 3.88345046698826292E-1),
    (re: 9.20318276709110566E-1; im: 3.91170384302253889E-1),
    (re: 9.19113851690057744E-1; im: 3.93992040061048109E-1),
    (re: 9.17900775621390458E-1; im: 3.96809987416710329E-1),
    (re: 9.16679059921042663E-1; im: 3.99624199845646829E-1),
    (re: 9.15448716088267820E-1; im: 4.02434650859418441E-1),
    (re: 9.14209755703530655E-1; im: 4.05241314004989871E-1),
    (re: 9.12962190428398165E-1; im: 4.08044162864978681E-1),
    (re: 9.11706032005429851E-1; im: 4.10843171057903942E-1),
    (re: 9.10441292258067197E-1; im: 4.13638312238434548E-1),
    (re: 9.09167983090522377E-1; im: 4.16429560097637183E-1),
    (re: 9.07886116487666212E-1; im: 4.19216888363223956E-1),
    (re: 9.06595704514915365E-1; im: 4.22000270799799686E-1),
    (re: 9.05296759318118774E-1; im: 4.24779681209108833E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 9.02673318237258807E-1; im: 4.30326481340082634E-1),
    (re: 9.01348847046022015E-1; im: 4.33093818853151968E-1),
    (re: 9.00015892016160229E-1; im: 4.35857079922255491E-1),
    (re: 8.98674465693953843E-1; im: 4.38616238538527638E-1),
    (re: 8.97324580705418281E-1; im: 4.41371268731716693E-1),
    (re: 8.95966249756185156E-1; im: 4.44122144570429232E-1),
    (re: 8.94599485631382678E-1; im: 4.46868840162374195E-1),
    (re: 8.93224301195515320E-1; im: 4.49611329654606600E-1),
    (re: 8.91840709392342728E-1; im: 4.52349587233770874E-1),
    (re: 8.90448723244757890E-1; im: 4.55083587126343824E-1),
    (re: 8.89048355854664563E-1; im: 4.57813303598877222E-1),
    (re: 8.87639620402853948E-1; im: 4.60538710958240024E-1),
    (re: 8.86222530148880632E-1; im: 4.63259783551860197E-1),
    (re: 8.84797098430937780E-1; im: 4.65976495767966178E-1),
    (re: 8.83363338665731595E-1; im: 4.68688822035827934E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.80470889052160771E-1; im: 4.74100214650550014E-1),
    (re: 8.79012226428633478E-1; im: 4.76799230063322133E-1),
    (re: 8.77545290207261292E-1; im: 4.79493757660153027E-1),
    (re: 8.76070094195406607E-1; im: 4.82183772079122749E-1),
    (re: 8.74586652278176113E-1; im: 4.84869248000791102E-1),
    (re: 8.73094978418290099E-1; im: 4.87550160148435955E-1),
    (re: 8.71595086655951035E-1; im: 4.90226483288291154E-1),
    (re: 8.70086991108711419E-1; im: 4.92898192229784037E-1),
    (re: 8.68570705971340895E-1; im: 4.95565261825772531E-1),
    (re: 8.67046245515692652E-1; im: 4.98227666972781852E-1),
    (re: 8.65513624090569083E-1; im: 5.00885382611240786E-1),
    (re: 8.63972856121586738E-1; im: 5.03538383725717559E-1),
    (re: 8.62423956111040539E-1; im: 5.06186645345155291E-1),
    (re: 8.60866938637767279E-1; im: 5.08830142543107037E-1),
    (re: 8.59301818357008405E-1; im: 5.11468850437970399E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.56147328375194481E-1; im: 5.16731799017649882E-1),
    (re: 8.54557988365400521E-1; im: 5.19355990165589587E-1),
    (re: 8.52960604930363658E-1; im: 5.21975292937154343E-1),
    (re: 8.51355193105265142E-1; im: 5.24589682678468906E-1),
    (re: 8.49741768000852490E-1; im: 5.27199134781901348E-1),
    (re: 8.48120344803297251E-1; im: 5.29803624686294668E-1),
    (re: 8.46490938774052078E-1; im: 5.32403127877197971E-1),
    (re: 8.44853565249707073E-1; im: 5.34997619887097211E-1),
    (re: 8.43208239641845437E-1; im: 5.37587076295645482E-1),
    (re: 8.41554977436898410E-1; im: 5.40171472729892881E-1),
    (re: 8.39893794195999505E-1; im: 5.42750784864515907E-1),
    (re: 8.38224705554838043E-1; im: 5.45324988422046422E-1),
    (re: 8.36547727223511984E-1; im: 5.47894059173100166E-1),
    (re: 8.34862874986380056E-1; im: 5.50457972936604803E-1),
    (re: 8.33170164701913186E-1; im: 5.53016705580027532E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.29761233794523042E-1; im: 5.58118531220556116E-1),
    (re: 8.28045045257755752E-1; im: 5.60661576197336024E-1),
    (re: 8.26321062845663480E-1; im: 5.63199344013834115E-1),
    (re: 8.24589302785025264E-1; im: 5.65731810783613197E-1),
    (re: 8.22849781375826332E-1; im: 5.68258952670131550E-1),
    (re: 8.21102514991104679E-1; im: 5.70780745886967280E-1),
    (re: 8.19347520076796961E-1; im: 5.73297166698042213E-1),
    (re: 8.17584813151583697E-1; im: 5.75808191417845301E-1),
    (re: 8.15814410806733789E-1; im: 5.78313796411655563E-1),
    (re: 8.14036329705948362E-1; im: 5.80813958095764545E-1),
    (re: 8.12250586585203913E-1; im: 5.83308652937698294E-1),
    (re: 8.10457198252594792E-1; im: 5.85797857456438860E-1),
    (re: 8.08656181588174992E-1; im: 5.88281548222645305E-1),
    (re: 8.06847553543799272E-1; im: 5.90759701858874228E-1),
    (re: 8.05031331142963598E-1; im: 5.93232295039799808E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 8.01376171723140219E-1; im: 5.98160706996342312E-1),
    (re: 7.99537269107905034E-1; im: 6.00616479383868927E-1),
    (re: 7.97690840943391108E-1; im: 6.03066598540348202E-1),
    (re: 7.95836904608883536E-1; im: 6.05511041404325514E-1),
    (re: 7.93975477554337165E-1; im: 6.07949784967773667E-1),
    (re: 7.92106577300212352E-1; im: 6.10382806276309453E-1),
    (re: 7.90230221437310055E-1; im: 6.12810082429409704E-1),
    (re: 7.88346427626606262E-1; im: 6.15231590580626846E-1),
    (re: 7.86455213599085758E-1; im: 6.17647307937803932E-1),
    (re: 7.84556597155575233E-1; im: 6.20057211763289179E-1),
    (re: 7.82650596166575738E-1; im: 6.22461279374149973E-1),
    (re: 7.80737228572094478E-1; im: 6.24859488142386377E-1),
    (re: 7.78816512381475953E-1; im: 6.27251815495144114E-1),
    (re: 7.76888465673232450E-1; im: 6.29638238914927025E-1),
    (re: 7.74953106594873878E-1; im: 6.32018735939809022E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.71060524261813773E-1; im: 6.36761861236284230E-1),
    (re: 7.69103337645579639E-1; im: 6.39124444863775744E-1),
    (re: 7.67138911935820381E-1; im: 6.41481012808583152E-1),
    (re: 7.65167265622458926E-1; im: 6.43831542889791465E-1),
    (re: 7.63188417263381272E-1; im: 6.46176012983316365E-1),
    (re: 7.61202385484261814E-1; im: 6.48514401022112445E-1),
    (re: 7.59209188978388033E-1; im: 6.50846684996380915E-1),
    (re: 7.57208846506484548E-1; im: 6.53172842953776764E-1),
    (re: 7.55201376896536528E-1; im: 6.55492852999615385E-1),
    (re: 7.53186799043612482E-1; im: 6.57806693297078657E-1),
    (re: 7.51165131909686411E-1; im: 6.60114342067420479E-1),
    (re: 7.49136394523459326E-1; im: 6.62415777590171761E-1),
    (re: 7.47100605980180144E-1; im: 6.64710978203344868E-1),
    (re: 7.45057785441465962E-1; im: 6.66999922303637507E-1),
    (re: 7.43007952135121694E-1; im: 6.69282588346636066E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.38887324460615148E-1; im: 6.73829000378756061E-1),
    (re: 7.36816568877369875E-1; im: 6.76092703575315960E-1),
    (re: 7.34738878095963465E-1; im: 6.78350043129861487E-1),
    (re: 7.32654271672412835E-1; im: 6.80600997795453051E-1),
    (re: 7.30562769227827561E-1; im: 6.82845546385248068E-1),
    (re: 7.28464390448225196E-1; im: 6.85083667772700381E-1),
    (re: 7.26359155084345977E-1; im: 6.87315340891759108E-1),
    (re: 7.24247082951466921E-1; im: 6.89540544737066925E-1),
    (re: 7.22128193929215321E-1; im: 6.91759258364157775E-1),
    (re: 7.20002507961381629E-1; im: 6.93971460889654009E-1),
    (re: 7.17870045055731736E-1; im: 6.96177131491462945E-1),
    (re: 7.15730825283818654E-1; im: 6.98376249408972854E-1),
    (re: 7.13584868780793593E-1; im: 7.00568793943248367E-1),
    (re: 7.11432195745216442E-1; im: 7.02754744457225302E-1),
    (re: 7.09272826438865651E-1; im: 7.04934080375904909E-1)
  );
  d4096: array[0..510] of TComplex = (
    (re: 9.99998823451701910E-1; im: 1.53398018628476561E-3),
    (re: 9.99995293809576172E-1; im: 3.06795676296597627E-3),
    (re: 9.99989411081928374E-1; im: 4.60192612044857076E-3),
    (re: 9.99981175282601143E-1; im: 6.13588464915447536E-3),
    (re: 9.99970586430974110E-1; im: 7.66982873953109748E-3),
    (re: 9.99957644551963866E-1; im: 9.20375478205981932E-3),
    (re: 9.99942349676023903E-1; im: 1.07376591672644914E-2),
    (re: 9.99924701839144541E-1; im: 1.22715382857199261E-2),
    (re: 9.99904701082852845E-1; im: 1.38053885280603907E-2),
    (re: 9.99882347454212526E-1; im: 1.53392062849881010E-2),
    (re: 9.99857641005823832E-1; im: 1.68729879472817141E-2),
    (re: 9.99830581795823422E-1; im: 1.84067299058048209E-2),
    (re: 9.99801169887884232E-1; im: 1.99404285515144396E-2),
    (re: 9.99769405351215322E-1; im: 2.14740802754695074E-2),
    (re: 9.99735288260561714E-1; im: 2.30076814688393729E-2),
    (re: 9.99698818696204220E-1; im: 2.45412285229122880E-2),
    (re: 9.99659996743959246E-1; im: 2.60747178291038998E-2),
    (re: 9.99618822495178597E-1; im: 2.76081457789657416E-2),
    (re: 9.99575296046749257E-1; im: 2.91415087641937241E-2),
    (re: 9.99529417501093163E-1; im: 3.06748031766366259E-2),
    (re: 9.99481186966166966E-1; im: 3.22080254083045844E-2),
    (re: 9.99430604555461772E-1; im: 3.37411718513775848E-2),
    (re: 9.99377670388002881E-1; im: 3.52742388982139507E-2),
    (re: 9.99322384588349501E-1; im: 3.68072229413588323E-2),
    (re: 9.99264747286594460E-1; im: 3.83401203735526958E-2),
    (re: 9.99204758618363896E-1; im: 3.98729275877398111E-2),
    (re: 9.99142418724816940E-1; im: 4.14056409770767400E-2),
    (re: 9.99077727752645383E-1; im: 4.29382569349408231E-2),
    (re: 9.99010685854073332E-1; im: 4.44707718549386666E-2),
    (re: 9.98941293186856851E-1; im: 4.60031821309146288E-2),
    (re: 9.98869549914283587E-1; im: 4.75354841569593053E-2),
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.98719012233872922E-1; im: 5.05997490368992809E-2),
    (re: 9.98640218180265222E-1; im: 5.21317046802833212E-2),
    (re: 9.98559074229759315E-1; im: 5.36635376527305253E-2),
    (re: 9.98475580573294752E-1; im: 5.51952443496899398E-2),
    (re: 9.98389737407340174E-1; im: 5.67268211669077497E-2),
    (re: 9.98301544933892841E-1; im: 5.82582645004357596E-2),
    (re: 9.98211003360478162E-1; im: 5.97895707466398742E-2),
    (re: 9.98118112900149207E-1; im: 6.13207363022085778E-2),
    (re: 9.98022873771486201E-1; im: 6.28517575641614134E-2),
    (re: 9.97925286198596013E-1; im: 6.43826309298574608E-2),
    (re: 9.97825350411111629E-1; im: 6.59133527970038141E-2),
    (re: 9.97723066644191610E-1; im: 6.74439195636640579E-2),
    (re: 9.97618435138519540E-1; im: 6.89743276282667434E-2),
    (re: 9.97511456140303460E-1; im: 7.05045733896138630E-2),
    (re: 9.97402129901275285E-1; im: 7.20346532468893244E-2),
    (re: 9.97290456678690216E-1; im: 7.35645635996674235E-2),
    (re: 9.97176436735326134E-1; im: 7.50943008479213168E-2),
    (re: 9.97060070339482979E-1; im: 7.66238613920314923E-2),
    (re: 9.96941357764982121E-1; im: 7.81532416327942400E-2),
    (re: 9.96820299291165715E-1; im: 7.96824379714301212E-2),
    (re: 9.96696895202896044E-1; im: 8.12114468095924364E-2),
    (re: 9.96571145790554847E-1; im: 8.27402645493756931E-2),
    (re: 9.96443051350042639E-1; im: 8.42688875933240717E-2),
    (re: 9.96312612182778013E-1; im: 8.57973123444398905E-2),
    (re: 9.96179828595696927E-1; im: 8.73255352061920702E-2),
    (re: 9.96044700901251990E-1; im: 8.88535525825245966E-2),
    (re: 9.95907229417411719E-1; im: 9.03813608778649825E-2),
    (re: 9.95767414467659794E-1; im: 9.19089564971327286E-2),
    (re: 9.95625256380994298E-1; im: 9.34363358457477829E-2),
    (re: 9.95480755491926942E-1; im: 9.49634953296389989E-2),
    (re: 9.95333912140482274E-1; im: 9.64904313552525935E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.95033199438118596E-1; im: 9.95436186600693337E-2),
    (re: 9.94879330794805621E-1; im: 1.01069862754827825E-1),
    (re: 9.94723121104325742E-1; im: 1.02595869022436292E-1),
    (re: 9.94564570734255452E-1; im: 1.04121633872054579E-1),
    (re: 9.94403680057679086E-1; im: 1.05647153713410614E-1),
    (re: 9.94240449453187946E-1; im: 1.07172424956808849E-1),
    (re: 9.94074879304879414E-1; im: 1.08697444013138714E-1),
    (re: 9.93906970002356042E-1; im: 1.10222207293883059E-1),
    (re: 9.93736721940724637E-1; im: 1.11746711211126596E-1),
    (re: 9.93564135520595334E-1; im: 1.13270952177564349E-1),
    (re: 9.93389211148080651E-1; im: 1.14794926606510086E-1),
    (re: 9.93211949234794533E-1; im: 1.16318630911904767E-1),
    (re: 9.93032350197851386E-1; im: 1.17842061508324977E-1),
    (re: 9.92850414459865091E-1; im: 1.19365214810991365E-1),
    (re: 9.92666142448948014E-1; im: 1.20888087235777078E-1),
    (re: 9.92479534598709998E-1; im: 1.22410675199216198E-1),
    (re: 9.92290591348257339E-1; im: 1.23932975118512171E-1),
    (re: 9.92099313142191757E-1; im: 1.25454983411546239E-1),
    (re: 9.91905700430609348E-1; im: 1.26976696496885866E-1),
    (re: 9.91709753669099523E-1; im: 1.28498110793793173E-1),
    (re: 9.91511473318743941E-1; im: 1.30019222722233355E-1),
    (re: 9.91310859846115419E-1; im: 1.31540028702883111E-1),
    (re: 9.91107913723276837E-1; im: 1.33060525157139065E-1),
    (re: 9.90902635427780025E-1; im: 1.34580708507126186E-1),
    (re: 9.90695025442664642E-1; im: 1.36100575175706208E-1),
    (re: 9.90485084256457038E-1; im: 1.37620121586486045E-1),
    (re: 9.90272812363169102E-1; im: 1.39139344163826211E-1),
    (re: 9.90058210262297106E-1; im: 1.40658239332849231E-1),
    (re: 9.89841278458820520E-1; im: 1.42176803519448051E-1),
    (re: 9.89622017463200835E-1; im: 1.43695033150294455E-1),
    (re: 9.89400427791380352E-1; im: 1.45212924652847464E-1),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.88950264510302976E-1; im: 1.48247678986896042E-1),
    (re: 9.88721691960323768E-1; im: 1.49764534677321517E-1),
    (re: 9.88490792852696638E-1; im: 1.51281037957330214E-1),
    (re: 9.88257567730749491E-1; im: 1.52797185258443428E-1),
    (re: 9.88022017143283568E-1; im: 1.54312973013020103E-1),
    (re: 9.87784141644572154E-1; im: 1.55828397654265236E-1),
    (re: 9.87543941794359276E-1; im: 1.57343455616238260E-1),
    (re: 9.87301418157858382E-1; im: 1.58858143333861442E-1),
    (re: 9.87056571305751018E-1; im: 1.60372457242928269E-1),
    (re: 9.86809401814185477E-1; im: 1.61886393780111838E-1),
    (re: 9.86559910264775448E-1; im: 1.63399949382973234E-1),
    (re: 9.86308097244598648E-1; im: 1.64913120489969921E-1),
    (re: 9.86053963346195436E-1; im: 1.66425903540464118E-1),
    (re: 9.85797509167567425E-1; im: 1.67938294974731178E-1),
    (re: 9.85538735312176068E-1; im: 1.69450291233967964E-1),
    (re: 9.85277642388941245E-1; im: 1.70961888760301226E-1),
    (re: 9.85014231012239824E-1; im: 1.72473083996795970E-1),
    (re: 9.84748501801904219E-1; im: 1.73983873387463828E-1),
    (re: 9.84480455383220930E-1; im: 1.75494253377271428E-1),
    (re: 9.84210092386929073E-1; im: 1.77004220412148756E-1),
    (re: 9.83937413449218895E-1; im: 1.78513770938997523E-1),
    (re: 9.83662419211730274E-1; im: 1.80022901405699523E-1),
    (re: 9.83385110321551217E-1; im: 1.81531608261124990E-1),
    (re: 9.83105487431216327E-1; im: 1.83039887955140959E-1),
    (re: 9.82823551198705277E-1; im: 1.84547736938619615E-1),
    (re: 9.82539302287441256E-1; im: 1.86055151663446648E-1),
    (re: 9.82252741366289409E-1; im: 1.87562128582529600E-1),
    (re: 9.81963869109555264E-1; im: 1.89068664149806213E-1),
    (re: 9.81672686196983146E-1; im: 1.90574754820252770E-1),
    (re: 9.81379193313754574E-1; im: 1.92080397049892442E-1),
    (re: 9.81083391150486654E-1; im: 1.93585587295803622E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.80484861773469344E-1; im: 1.96594597670080229E-1),
    (re: 9.80182135968117393E-1; im: 1.98098410717953586E-1),
    (re: 9.79877103699517659E-1; im: 1.99601757621130974E-1),
    (re: 9.79569765685440534E-1; im: 2.01104634842091912E-1),
    (re: 9.79260122649082055E-1; im: 2.02607038844421126E-1),
    (re: 9.78948175319062195E-1; im: 2.04108966092816874E-1),
    (re: 9.78633924429423155E-1; im: 2.05610413053099259E-1),
    (re: 9.78317370719627633E-1; im: 2.07111376192218550E-1),
    (re: 9.77998514934557087E-1; im: 2.08611851978263492E-1),
    (re: 9.77677357824509980E-1; im: 2.10111836880469622E-1),
    (re: 9.77353900145200013E-1; im: 2.11611327369227571E-1),
    (re: 9.77028142657754352E-1; im: 2.13110319916091374E-1),
    (re: 9.76700086128711830E-1; im: 2.14608810993786772E-1),
    (re: 9.76369731330021149E-1; im: 2.16106797076219510E-1),
    (re: 9.76037079039039063E-1; im: 2.17604274638483637E-1),
    (re: 9.75702130038528544E-1; im: 2.19101240156869797E-1),
    (re: 9.75364885116656946E-1; im: 2.20597690108873526E-1),
    (re: 9.75025345066994147E-1; im: 2.22093620973203534E-1),
    (re: 9.74683510688510681E-1; im: 2.23589029229789997E-1),
    (re: 9.74339382785575861E-1; im: 2.25083911359792836E-1),
    (re: 9.73992962167955883E-1; im: 2.26578263845609999E-1),
    (re: 9.73644249650811925E-1; im: 2.28072083170885739E-1),
    (re: 9.73293246054698224E-1; im: 2.29565365820518886E-1),
    (re: 9.72939952205560145E-1; im: 2.31058108280671120E-1),
    (re: 9.72584368934732245E-1; im: 2.32550307038775238E-1),
    (re: 9.72226497078936306E-1; im: 2.34041958583543423E-1),
    (re: 9.71866337480279374E-1; im: 2.35533059404975502E-1),
    (re: 9.71503890986251776E-1; im: 2.37023605994367207E-1),
    (re: 9.71139158449725121E-1; im: 2.38513594844318432E-1),
    (re: 9.70772140728950302E-1; im: 2.40003022448741487E-1),
    (re: 9.70402838687555467E-1; im: 2.41491885302869344E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.69657385124292438E-1; im: 2.44467902747824166E-1),
    (re: 9.69281235356548486E-1; im: 2.45955050335794612E-1),
    (re: 9.68902804776428876E-1; im: 2.47441619167773298E-1),
    (re: 9.68522094274417316E-1; im: 2.48927605745720168E-1),
    (re: 9.68139104746362395E-1; im: 2.50413006572965262E-1),
    (re: 9.67753837093475465E-1; im: 2.51897818154216950E-1),
    (re: 9.67366292222328531E-1; im: 2.53382036995570155E-1),
    (re: 9.66976471044852109E-1; im: 2.54865659604514572E-1),
    (re: 9.66584374478333085E-1; im: 2.56348682489942890E-1),
    (re: 9.66190003445412555E-1; im: 2.57831102162159006E-1),
    (re: 9.65793358874083655E-1; im: 2.59312915132886234E-1),
    (re: 9.65394441697689375E-1; im: 2.60794117915275518E-1),
    (re: 9.64993252854920364E-1; im: 2.62274707023913632E-1),
    (re: 9.64589793289812724E-1; im: 2.63754678974831384E-1),
    (re: 9.64184063951745783E-1; im: 2.65234030285511813E-1),
    (re: 9.63776065795439867E-1; im: 2.66712757474898386E-1),
    (re: 9.63365799780954047E-1; im: 2.68190857063403188E-1),
    (re: 9.62953266873683886E-1; im: 2.69668325572915107E-1),
    (re: 9.62538468044359165E-1; im: 2.71145159526808022E-1),
    (re: 9.62121404269041595E-1; im: 2.72621355449948984E-1),
    (re: 9.61702076529122529E-1; im: 2.74096909868706392E-1),
    (re: 9.61280485811320642E-1; im: 2.75571819310958163E-1),
    (re: 9.60856633107679618E-1; im: 2.77046080306099911E-1),
    (re: 9.60430519415565811E-1; im: 2.78519689385053105E-1),
    (re: 9.60002145737665900E-1; im: 2.79992643080273238E-1),
    (re: 9.59571513081984528E-1; im: 2.81464937925757984E-1),
    (re: 9.59138622461841932E-1; im: 2.82936570457055353E-1),
    (re: 9.58703474895871555E-1; im: 2.84407537211271844E-1),
    (re: 9.58266071408017655E-1; im: 2.85877834727080595E-1),
    (re: 9.57826413027532890E-1; im: 2.87347459544729526E-1),
    (re: 9.57384500788975899E-1; im: 2.88816408206049482E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.56493918902395072E-1; im: 2.91752263234989282E-1),
    (re: 9.56045251349996443E-1; im: 2.93219162694258651E-1),
    (re: 9.55594334130771068E-1; im: 2.94685372180514348E-1),
    (re: 9.55141168305770722E-1; im: 2.96150888243623824E-1),
    (re: 9.54685754941338363E-1; im: 2.97615707435086218E-1),
    (re: 9.54228095109105630E-1; im: 2.99079826308040477E-1),
    (re: 9.53768189885990316E-1; im: 3.00543241417273464E-1),
    (re: 9.53306040354193837E-1; im: 3.02005949319228067E-1),
    (re: 9.52841647601198682E-1; im: 3.03467946572011301E-1),
    (re: 9.52375012719765858E-1; im: 3.04929229735402406E-1),
    (re: 9.51906136807932317E-1; im: 3.06389795370860946E-1),
    (re: 9.51435020969008370E-1; im: 3.07849640041534894E-1),
    (re: 9.50961666311575093E-1; im: 3.09308760312268724E-1),
    (re: 9.50486073949481722E-1; im: 3.10767152749611496E-1),
    (re: 9.50008245001843023E-1; im: 3.12224813921824927E-1),
    (re: 9.49528180593036667E-1; im: 3.13681740398891477E-1),
    (re: 9.49045881852700581E-1; im: 3.15137928752522409E-1),
    (re: 9.48561349915730288E-1; im: 3.16593375556165867E-1),
    (re: 9.48074585922276241E-1; im: 3.18048077385014931E-1),
    (re: 9.47585591017741135E-1; im: 3.19502030816015678E-1),
    (re: 9.47094366352777215E-1; im: 3.20955232427875239E-1),
    (re: 9.46600913083283570E-1; im: 3.22407678801069848E-1),
    (re: 9.46105232370403407E-1; im: 3.23859366517852888E-1),
    (re: 9.45607325380521326E-1; im: 3.25310292162262934E-1),
    (re: 9.45107193285260568E-1; im: 3.26760452320131791E-1),
    (re: 9.44604837261480266E-1; im: 3.28209843579092526E-1),
    (re: 9.44100258491272668E-1; im: 3.29658462528587503E-1),
    (re: 9.43593458161960361E-1; im: 3.31106305759876402E-1),
    (re: 9.43084437466093476E-1; im: 3.32553369866044243E-1),
    (re: 9.42573197601446879E-1; im: 3.33999651442009405E-1),
    (re: 9.42059739771017356E-1; im: 3.35445147084531633E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.41026175050889265E-1; im: 3.38333766965541164E-1),
    (re: 9.40506070593268324E-1; im: 3.39776884406826858E-1),
    (re: 9.39983753034013982E-1; im: 3.41219202320282393E-1),
    (re: 9.39459223602189912E-1; im: 3.42660717311994398E-1),
    (re: 9.38932483532064533E-1; im: 3.44101425989938850E-1),
    (re: 9.38403534063108112E-1; im: 3.45541324963989066E-1),
    (re: 9.37872376439989844E-1; im: 3.46980410845923668E-1),
    (re: 9.37339011912574923E-1; im: 3.48418680249434568E-1),
    (re: 9.36803441735921604E-1; im: 3.49856129790134928E-1),
    (re: 9.36265667170278247E-1; im: 3.51292756085567126E-1),
    (re: 9.35725689481080350E-1; im: 3.52728555755210716E-1),
    (re: 9.35183509938947578E-1; im: 3.54163525420490382E-1),
    (re: 9.34639129819680764E-1; im: 3.55597661704783891E-1),
    (re: 9.34092550404258915E-1; im: 3.57030961233430033E-1),
    (re: 9.33543772978836192E-1; im: 3.58463420633736565E-1),
    (re: 9.32992798834738888E-1; im: 3.59895036534988149E-1),
    (re: 9.32439629268462385E-1; im: 3.61325805568454280E-1),
    (re: 9.31884265581668107E-1; im: 3.62755724367397216E-1),
    (re: 9.31326709081180455E-1; im: 3.64184789567079899E-1),
    (re: 9.30766961078983732E-1; im: 3.65612997804773870E-1),
    (re: 9.30205022892219057E-1; im: 3.67040345719767188E-1),
    (re: 9.29640895843181265E-1; im: 3.68466829953372332E-1),
    (re: 9.29074581259315795E-1; im: 3.69892447148934107E-1),
    (re: 9.28506080473215566E-1; im: 3.71317193951837543E-1),
    (re: 9.27935394822617843E-1; im: 3.72741067009515789E-1),
    (re: 9.27362525650401087E-1; im: 3.74164062971457997E-1),
    (re: 9.26787474304581799E-1; im: 3.75586178489217215E-1),
    (re: 9.26210242138311342E-1; im: 3.77007410216418257E-1),
    (re: 9.25630830509872762E-1; im: 3.78427754808765584E-1),
    (re: 9.25049240782677590E-1; im: 3.79847208924051171E-1),
    (re: 9.24465474325262634E-1; im: 3.81265769222162370E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.23291416719527646E-1; im: 3.84100195016935061E-1),
    (re: 9.22701128333878570E-1; im: 3.85516053843918864E-1),
    (re: 9.22108668743345121E-1; im: 3.86931005514388594E-1),
    (re: 9.21514039342041943E-1; im: 3.88345046698826292E-1),
    (re: 9.20917241529189458E-1; im: 3.89758174069856459E-1),
    (re: 9.20318276709110566E-1; im: 3.91170384302253889E-1),
    (re: 9.19717146291227348E-1; im: 3.92581674072951490E-1),
    (re: 9.19113851690057744E-1; im: 3.93992040061048109E-1),
    (re: 9.18508394325212226E-1; im: 3.95401478947816337E-1),
    (re: 9.17900775621390458E-1; im: 3.96809987416710329E-1),
    (re: 9.17290997008377944E-1; im: 3.98217562153373600E-1),
    (re: 9.16679059921042663E-1; im: 3.99624199845646829E-1),
    (re: 9.16064965799331692E-1; im: 4.01029897183575649E-1),
    (re: 9.15448716088267820E-1; im: 4.02434650859418441E-1),
    (re: 9.14830312237946142E-1; im: 4.03838457567654111E-1),
    (re: 9.14209755703530655E-1; im: 4.05241314004989871E-1),
    (re: 9.13587047945250827E-1; im: 4.06643216870369015E-1),
    (re: 9.12962190428398165E-1; im: 4.08044162864978681E-1),
    (re: 9.12335184623322764E-1; im: 4.09444148692257618E-1),
    (re: 9.11706032005429851E-1; im: 4.10843171057903942E-1),
    (re: 9.11074734055176310E-1; im: 4.12241226669882886E-1),
    (re: 9.10441292258067197E-1; im: 4.13638312238434548E-1),
    (re: 9.09805708104652250E-1; im: 4.15034424476081631E-1),
    (re: 9.09167983090522377E-1; im: 4.16429560097637183E-1),
    (re: 9.08528118716306137E-1; im: 4.17823715820212319E-1),
    (re: 9.07886116487666212E-1; im: 4.19216888363223956E-1),
    (re: 9.07241977915295861E-1; im: 4.20609074448402525E-1),
    (re: 9.06595704514915365E-1; im: 4.22000270799799686E-1),
    (re: 9.05947297807268464E-1; im: 4.23390474143796041E-1),
    (re: 9.05296759318118774E-1; im: 4.24779681209108833E-1),
    (re: 9.04644090578246200E-1; im: 4.26167888726799646E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 9.03332368494511831E-1; im: 4.28941292055329512E-1),
    (re: 9.02673318237258807E-1; im: 4.30326481340082634E-1),
    (re: 9.02012143902493176E-1; im: 4.31710658025057268E-1),
    (re: 9.01348847046022015E-1; im: 4.33093818853151968E-1),
    (re: 9.00683429228646898E-1; im: 4.34475960569655699E-1),
    (re: 9.00015892016160229E-1; im: 4.35857079922255491E-1),
    (re: 8.99346236979341548E-1; im: 4.37237173661044097E-1),
    (re: 8.98674465693953843E-1; im: 4.38616238538527638E-1),
    (re: 8.98000579740739840E-1; im: 4.39994271309633244E-1),
    (re: 8.97324580705418281E-1; im: 4.41371268731716693E-1),
    (re: 8.96646470178680196E-1; im: 4.42747227564570037E-1),
    (re: 8.95966249756185156E-1; im: 4.44122144570429232E-1),
    (re: 8.95283921038557522E-1; im: 4.45496016513981749E-1),
    (re: 8.94599485631382678E-1; im: 4.46868840162374195E-1),
    (re: 8.93912945145203251E-1; im: 4.48240612285219917E-1),
    (re: 8.93224301195515320E-1; im: 4.49611329654606600E-1),
    (re: 8.92533555402764622E-1; im: 4.50980989045103869E-1),
    (re: 8.91840709392342728E-1; im: 4.52349587233770874E-1),
    (re: 8.91145764794583228E-1; im: 4.53717121000163876E-1),
    (re: 8.90448723244757890E-1; im: 4.55083587126343824E-1),
    (re: 8.89749586383072812E-1; im: 4.56448982396883927E-1),
    (re: 8.89048355854664563E-1; im: 4.57813303598877222E-1),
    (re: 8.88345033309596312E-1; im: 4.59176547521944133E-1),
    (re: 8.87639620402853948E-1; im: 4.60538710958240024E-1),
    (re: 8.86932118794342179E-1; im: 4.61899790702462750E-1),
    (re: 8.86222530148880632E-1; im: 4.63259783551860197E-1),
    (re: 8.85510856136199933E-1; im: 4.64618686306237822E-1),
    (re: 8.84797098430937780E-1; im: 4.65976495767966178E-1),
    (re: 8.84081258712634999E-1; im: 4.67333208741988442E-1),
    (re: 8.83363338665731595E-1; im: 4.68688822035827934E-1),
    (re: 8.82643339979562786E-1; im: 4.70043332459595625E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.81197113471222037E-1; im: 4.72749031950342796E-1),
    (re: 8.80470889052160771E-1; im: 4.74100214650550014E-1),
    (re: 8.79742592800047441E-1; im: 4.75450281747155890E-1),
    (re: 8.79012226428633478E-1; im: 4.76799230063322133E-1),
    (re: 8.78279791656541505E-1; im: 4.78147056424843053E-1),
    (re: 8.77545290207261292E-1; im: 4.79493757660153027E-1),
    (re: 8.76808723809145698E-1; im: 4.80839330600333960E-1),
    (re: 8.76070094195406607E-1; im: 4.82183772079122749E-1),
    (re: 8.75329403104110850E-1; im: 4.83527078932918724E-1),
    (re: 8.74586652278176113E-1; im: 4.84869248000791102E-1),
    (re: 8.73841843465366835E-1; im: 4.86210276124486416E-1),
    (re: 8.73094978418290099E-1; im: 4.87550160148435955E-1),
    (re: 8.72346058894391505E-1; im: 4.88888896919763180E-1),
    (re: 8.71595086655951035E-1; im: 4.90226483288291154E-1),
    (re: 8.70842063470078908E-1; im: 4.91562916106549945E-1),
    (re: 8.70086991108711419E-1; im: 4.92898192229784037E-1),
    (re: 8.69329871348606771E-1; im: 4.94232308515959730E-1),
    (re: 8.68570705971340895E-1; im: 4.95565261825772531E-1),
    (re: 8.67809496763303257E-1; im: 4.96897049022654545E-1),
    (re: 8.67046245515692652E-1; im: 4.98227666972781852E-1),
    (re: 8.66280954024512993E-1; im: 4.99557112545081883E-1),
    (re: 8.65513624090569083E-1; im: 5.00885382611240786E-1),
    (re: 8.64744257519462378E-1; im: 5.02212474045710791E-1),
    (re: 8.63972856121586738E-1; im: 5.03538383725717559E-1),
    (re: 8.63199421712124166E-1; im: 5.04863108531267536E-1),
    (re: 8.62423956111040539E-1; im: 5.06186645345155291E-1),
    (re: 8.61646461143081322E-1; im: 5.07508991052970853E-1),
    (re: 8.60866938637767279E-1; im: 5.08830142543107037E-1),
    (re: 8.60085390429390164E-1; im: 5.10150096706766769E-1),
    (re: 8.59301818357008405E-1; im: 5.11468850437970399E-1),
    (re: 8.58516224264442778E-1; im: 5.12786400633563012E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.56938977417828723E-1; im: 5.15417878019462993E-1),
    (re: 8.56147328375194481E-1; im: 5.16731799017649882E-1),
    (re: 8.55353664735196010E-1; im: 5.18044504095999364E-1),
    (re: 8.54557988365400521E-1; im: 5.19355990165589587E-1),
    (re: 8.53760301138111370E-1; im: 5.20666254140367147E-1),
    (re: 8.52960604930363658E-1; im: 5.21975292937154343E-1),
    (re: 8.52158901623919808E-1; im: 5.23283103475656438E-1),
    (re: 8.51355193105265142E-1; im: 5.24589682678468906E-1),
    (re: 8.50549481265603440E-1; im: 5.25895027471084672E-1),
    (re: 8.49741768000852490E-1; im: 5.27199134781901348E-1),
    (re: 8.48932055211639624E-1; im: 5.28502001542228460E-1),
    (re: 8.48120344803297251E-1; im: 5.29803624686294668E-1),
    (re: 8.47306638685858371E-1; im: 5.31104001151254983E-1),
    (re: 8.46490938774052078E-1; im: 5.32403127877197971E-1),
    (re: 8.45673246987299059E-1; im: 5.33701001807152956E-1),
    (re: 8.44853565249707073E-1; im: 5.34997619887097211E-1),
    (re: 8.44031895490066428E-1; im: 5.36292979065963144E-1),
    (re: 8.43208239641845437E-1; im: 5.37587076295645482E-1),
    (re: 8.42382599643185874E-1; im: 5.38879908531008439E-1),
    (re: 8.41554977436898410E-1; im: 5.40171472729892881E-1),
    (re: 8.40725374970458040E-1; im: 5.41461765853123489E-1),
    (re: 8.39893794195999505E-1; im: 5.42750784864515907E-1),
    (re: 8.39060237070312694E-1; im: 5.44038526730883885E-1),
    (re: 8.38224705554838043E-1; im: 5.45324988422046422E-1),
    (re: 8.37387201615661917E-1; im: 5.46610166910834892E-1),
    (re: 8.36547727223511984E-1; im: 5.47894059173100166E-1),
    (re: 8.35706284353752580E-1; im: 5.49176662187719732E-1),
    (re: 8.34862874986380056E-1; im: 5.50457972936604803E-1),
    (re: 8.34017501106018125E-1; im: 5.51737988404707417E-1),
    (re: 8.33170164701913186E-1; im: 5.53016705580027532E-1),
    (re: 8.32320867767929649E-1; im: 5.54294121453620116E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.30616400308846289E-1; im: 5.56845037275160076E-1),
    (re: 8.29761233794523042E-1; im: 5.58118531220556116E-1),
    (re: 8.28904114771864912E-1; im: 5.59390711859136075E-1),
    (re: 8.28045045257755752E-1; im: 5.60661576197336024E-1),
    (re: 8.27184027273669112E-1; im: 5.61931121244689414E-1),
    (re: 8.26321062845663480E-1; im: 5.63199344013834115E-1),
    (re: 8.25456154004377514E-1; im: 5.64466241520519446E-1),
    (re: 8.24589302785025264E-1; im: 5.65731810783613197E-1),
    (re: 8.23720511227391385E-1; im: 5.66996048825108643E-1),
    (re: 8.22849781375826332E-1; im: 5.68258952670131550E-1),
    (re: 8.21977115279241556E-1; im: 5.69520519346947180E-1),
    (re: 8.21102514991104679E-1; im: 5.70780745886967280E-1),
    (re: 8.20225982569434661E-1; im: 5.72039629324757069E-1),
    (re: 8.19347520076796961E-1; im: 5.73297166698042213E-1),
    (re: 8.18467129580298679E-1; im: 5.74553355047715800E-1),
    (re: 8.17584813151583697E-1; im: 5.75808191417845301E-1),
    (re: 8.16700572866827798E-1; im: 5.77061672855679523E-1),
    (re: 8.15814410806733789E-1; im: 5.78313796411655563E-1),
    (re: 8.14926329056526596E-1; im: 5.79564559139405743E-1),
    (re: 8.14036329705948362E-1; im: 5.80813958095764545E-1),
    (re: 8.13144414849253530E-1; im: 5.82061990340775538E-1),
    (re: 8.12250586585203913E-1; im: 5.83308652937698294E-1),
    (re: 8.11354847017063757E-1; im: 5.84553942953015301E-1),
    (re: 8.10457198252594792E-1; im: 5.85797857456438860E-1),
    (re: 8.09557642404051268E-1; im: 5.87040393520917990E-1),
    (re: 8.08656181588174992E-1; im: 5.88281548222645305E-1),
    (re: 8.07752817926190341E-1; im: 5.89521318641063902E-1),
    (re: 8.06847553543799272E-1; im: 5.90759701858874228E-1),
    (re: 8.05940390571176324E-1; im: 5.91996694962040951E-1),
    (re: 8.05031331142963598E-1; im: 5.93232295039799808E-1),
    (re: 8.04120377398265741E-1; im: 5.94466499184664463E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 8.02292795538115725E-1; im: 5.96930708062196476E-1),
    (re: 8.01376171723140219E-1; im: 5.98160706996342312E-1),
    (re: 8.00457662192622772E-1; im: 5.99389298400564546E-1),
    (re: 7.99537269107905034E-1; im: 6.00616479383868927E-1),
    (re: 7.98614994634760838E-1; im: 6.01842247058580060E-1),
    (re: 7.97690840943391108E-1; im: 6.03066598540348202E-1),
    (re: 7.96764810208418751E-1; im: 6.04289530948156049E-1),
    (re: 7.95836904608883536E-1; im: 6.05511041404325514E-1),
    (re: 7.94907126328236972E-1; im: 6.06731127034524501E-1),
    (re: 7.93975477554337165E-1; im: 6.07949784967773667E-1),
    (re: 7.93041960479443674E-1; im: 6.09167012336453177E-1),
    (re: 7.92106577300212352E-1; im: 6.10382806276309453E-1),
    (re: 7.91169330217690172E-1; im: 6.11597163926461913E-1),
    (re: 7.90230221437310055E-1; im: 6.12810082429409704E-1),
    (re: 7.89289253168885675E-1; im: 6.14021558931038426E-1),
    (re: 7.88346427626606262E-1; im: 6.15231590580626846E-1),
    (re: 7.87401747029031390E-1; im: 6.16440174530853608E-1),
    (re: 7.86455213599085758E-1; im: 6.17647307937803932E-1),
    (re: 7.85506829564053957E-1; im: 6.18852987960976309E-1),
    (re: 7.84556597155575233E-1; im: 6.20057211763289179E-1),
    (re: 7.83604518609638232E-1; im: 6.21259976511087611E-1),
    (re: 7.82650596166575738E-1; im: 6.22461279374149973E-1),
    (re: 7.81694832071059407E-1; im: 6.23661117525694585E-1),
    (re: 7.80737228572094478E-1; im: 6.24859488142386377E-1),
    (re: 7.79777787923014485E-1; im: 6.26056388404343531E-1),
    (re: 7.78816512381475953E-1; im: 6.27251815495144114E-1),
    (re: 7.77853404209453088E-1; im: 6.28445766601832707E-1),
    (re: 7.76888465673232450E-1; im: 6.29638238914927025E-1),
    (re: 7.75921699043407625E-1; im: 6.30829229628424528E-1),
    (re: 7.74953106594873878E-1; im: 6.32018735939809022E-1),
    (re: 7.73982690606822804E-1; im: 6.33206755050057253E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.72036397150384498E-1; im: 6.35578320488556138E-1),
    (re: 7.71060524261813773E-1; im: 6.36761861236284230E-1),
    (re: 7.70082836993347959E-1; im: 6.37943903621844070E-1),
    (re: 7.69103337645579639E-1; im: 6.39124444863775744E-1),
    (re: 7.68122028523365395E-1; im: 6.40303482184151673E-1),
    (re: 7.67138911935820381E-1; im: 6.41481012808583152E-1),
    (re: 7.66153990196312894E-1; im: 6.42657033966226877E-1),
    (re: 7.65167265622458926E-1; im: 6.43831542889791465E-1),
    (re: 7.64178740536116713E-1; im: 6.45004536815543966E-1),
    (re: 7.63188417263381272E-1; im: 6.46176012983316365E-1),
    (re: 7.62196298134578924E-1; im: 6.47345968636512080E-1),
    (re: 7.61202385484261814E-1; im: 6.48514401022112445E-1),
    (re: 7.60206681651202417E-1; im: 6.49681307390683192E-1),
    (re: 7.59209188978388033E-1; im: 6.50846684996380915E-1),
    (re: 7.58209909813015276E-1; im: 6.52010531096959538E-1),
    (re: 7.57208846506484548E-1; im: 6.53172842953776764E-1),
    (re: 7.56206001414394507E-1; im: 6.54333617831800518E-1),
    (re: 7.55201376896536528E-1; im: 6.55492852999615385E-1),
    (re: 7.54194975316889142E-1; im: 6.56650545729429039E-1),
    (re: 7.53186799043612482E-1; im: 6.57806693297078657E-1),
    (re: 7.52176850449042705E-1; im: 6.58961292982037333E-1),
    (re: 7.51165131909686411E-1; im: 6.60114342067420479E-1),
    (re: 7.50151645806215051E-1; im: 6.61265837839992216E-1),
    (re: 7.49136394523459326E-1; im: 6.62415777590171761E-1),
    (re: 7.48119380450403572E-1; im: 6.63564158612039803E-1),
    (re: 7.47100605980180144E-1; im: 6.64710978203344868E-1),
    (re: 7.46080073510063780E-1; im: 6.65856233665509679E-1),
    (re: 7.45057785441465962E-1; im: 6.66999922303637507E-1),
    (re: 7.44033744179929264E-1; im: 6.68142041426518509E-1),
    (re: 7.43007952135121694E-1; im: 6.69282588346636066E-1),
    (re: 7.41980411720831019E-1; im: 6.70421560380173101E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.39920095459516155E-1; im: 6.72694769070772915E-1),
    (re: 7.38887324460615148E-1; im: 6.73829000378756061E-1),
    (re: 7.37852814788465992E-1; im: 6.74961646102012008E-1),
    (re: 7.36816568877369875E-1; im: 6.76092703575315960E-1),
    (re: 7.35778589165713524E-1; im: 6.77222170137180427E-1),
    (re: 7.34738878095963465E-1; im: 6.78350043129861487E-1),
    (re: 7.33697438114660276E-1; im: 6.79476319899365039E-1),
    (re: 7.32654271672412835E-1; im: 6.80600997795453051E-1),
    (re: 7.31609381223892544E-1; im: 6.81724074171649793E-1),
    (re: 7.30562769227827561E-1; im: 6.82845546385248068E-1),
    (re: 7.29514438146997013E-1; im: 6.83965411797315427E-1),
    (re: 7.28464390448225196E-1; im: 6.85083667772700381E-1),
    (re: 7.27412628602375778E-1; im: 6.86200311680038601E-1),
    (re: 7.26359155084345977E-1; im: 6.87315340891759108E-1),
    (re: 7.25303972373060742E-1; im: 6.88428752784090461E-1),
    (re: 7.24247082951466921E-1; im: 6.89540544737066925E-1),
    (re: 7.23188489306527413E-1; im: 6.90650714134534639E-1),
    (re: 7.22128193929215321E-1; im: 6.91759258364157775E-1),
    (re: 7.21066199314508089E-1; im: 6.92866174817424678E-1),
    (re: 7.20002507961381629E-1; im: 6.93971460889654009E-1),
    (re: 7.18937122372804444E-1; im: 6.95075113980000875E-1),
    (re: 7.17870045055731736E-1; im: 6.96177131491462945E-1),
    (re: 7.16801278521099508E-1; im: 6.97277510830886564E-1),
    (re: 7.15730825283818654E-1; im: 6.98376249408972854E-1),
    (re: 7.14658687862769044E-1; im: 6.99473344640283806E-1),
    (re: 7.13584868780793593E-1; im: 7.00568793943248367E-1),
    (re: 7.12509370564692328E-1; im: 7.01662594740168510E-1),
    (re: 7.11432195745216442E-1; im: 7.02754744457225302E-1),
    (re: 7.10353346857062334E-1; im: 7.03845240524484964E-1),
    (re: 7.09272826438865651E-1; im: 7.04934080375904909E-1),
    (re: 7.08190637033195313E-1; im: 7.06021261449339790E-1)
  );
  d8192: array[0..1022] of TComplex = (
    (re: 9.99999705862882219E-1; im: 7.66990318742704527E-4),
    (re: 9.99998823451701910E-1; im: 1.53398018628476561E-3),
    (re: 9.99997352766978172E-1; im: 2.30096915142580524E-3),
    (re: 9.99995293809576172E-1; im: 3.06795676296597627E-3),
    (re: 9.99992646580707140E-1; im: 3.83494256970622783E-3),
    (re: 9.99989411081928374E-1; im: 4.60192612044857076E-3),
    (re: 9.99985587315143233E-1; im: 5.36890696399634309E-3),
    (re: 9.99981175282601143E-1; im: 6.13588464915447536E-3),
    (re: 9.99976174986897586E-1; im: 6.90285872472975616E-3),
    (re: 9.99970586430974110E-1; im: 7.66982873953109748E-3),
    (re: 9.99964409618118317E-1; im: 8.43679424236980016E-3),
    (re: 9.99957644551963866E-1; im: 9.20375478205981932E-3),
    (re: 9.99950291236490473E-1; im: 9.97070990741802976E-3),
    (re: 9.99942349676023903E-1; im: 1.07376591672644914E-2),
    (re: 9.99933819875235972E-1; im: 1.15046021104227147E-2),
    (re: 9.99924701839144541E-1; im: 1.22715382857199261E-2),
    (re: 9.99914995573113516E-1; im: 1.30384672419873332E-2),
    (re: 9.99904701082852845E-1; im: 1.38053885280603907E-2),
    (re: 9.99893818374418509E-1; im: 1.45723016927790652E-2),
    (re: 9.99882347454212526E-1; im: 1.53392062849881010E-2),
    (re: 9.99870288328982942E-1; im: 1.61061018535372854E-2),
    (re: 9.99857641005823832E-1; im: 1.68729879472817141E-2),
    (re: 9.99844405492175288E-1; im: 1.76398641150820563E-2),
    (re: 9.99830581795823422E-1; im: 1.84067299058048209E-2),
    (re: 9.99816169924900359E-1; im: 1.91735848683226210E-2),
    (re: 9.99801169887884232E-1; im: 1.99404285515144396E-2),
    (re: 9.99785581693599175E-1; im: 2.07072605042658954E-2),
    (re: 9.99769405351215322E-1; im: 2.14740802754695074E-2),
    (re: 9.99752640870248797E-1; im: 2.22408874140249610E-2),
    (re: 9.99735288260561714E-1; im: 2.30076814688393729E-2),
    (re: 9.99717347532362166E-1; im: 2.37744619888275566E-2),
    (re: 9.99698818696204220E-1; im: 2.45412285229122880E-2),
    (re: 9.99679701762987914E-1; im: 2.53079806200245704E-2),
    (re: 9.99659996743959246E-1; im: 2.60747178291038998E-2),
    (re: 9.99639703650710173E-1; im: 2.68414396990985309E-2),
    (re: 9.99618822495178597E-1; im: 2.76081457789657416E-2),
    (re: 9.99597353289648365E-1; im: 2.83748356176720989E-2),
    (re: 9.99575296046749257E-1; im: 2.91415087641937241E-2),
    (re: 9.99552650779456980E-1; im: 2.99081647675165578E-2),
    (re: 9.99529417501093163E-1; im: 3.06748031766366259E-2),
    (re: 9.99505596225325344E-1; im: 3.14414235405603043E-2),
    (re: 9.99481186966166966E-1; im: 3.22080254083045844E-2),
    (re: 9.99456189737977367E-1; im: 3.29746083288973384E-2),
    (re: 9.99430604555461772E-1; im: 3.37411718513775848E-2),
    (re: 9.99404431433671286E-1; im: 3.45077155247957534E-2),
    (re: 9.99377670388002881E-1; im: 3.52742388982139507E-2),
    (re: 9.99350321434199391E-1; im: 3.60407415207062251E-2),
    (re: 9.99322384588349501E-1; im: 3.68072229413588323E-2),
    (re: 9.99293859866887738E-1; im: 3.75736827092705006E-2),
    (re: 9.99264747286594460E-1; im: 3.83401203735526958E-2),
    (re: 9.99235046864595848E-1; im: 3.91065354833298869E-2),
    (re: 9.99204758618363896E-1; im: 3.98729275877398111E-2),
    (re: 9.99173882565716397E-1; im: 4.06392962359337390E-2),
    (re: 9.99142418724816940E-1; im: 4.14056409770767400E-2),
    (re: 9.99110367114174889E-1; im: 4.21719613603479472E-2),
    (re: 9.99077727752645383E-1; im: 4.29382569349408231E-2),
    (re: 9.99044500659429316E-1; im: 4.37045272500634242E-2),
    (re: 9.99010685854073332E-1; im: 4.44707718549386666E-2),
    (re: 9.98976283356469809E-1; im: 4.52369902988045913E-2),
    (re: 9.98941293186856851E-1; im: 4.60031821309146288E-2),
    (re: 9.98905715365818272E-1; im: 4.67693469005378649E-2),
    (re: 9.98869549914283587E-1; im: 4.75354841569593053E-2),
    (re: 9.98832796853528002E-1; im: 4.83015934494801412E-2),
    (re: 9.98795456205172393E-1; im: 4.90676743274180143E-2),
    (re: 9.98757527991183302E-1; im: 4.98337263401072815E-2),
    (re: 9.98719012233872922E-1; im: 5.05997490368992809E-2),
    (re: 9.98679908955899078E-1; im: 5.13657419671625960E-2),
    (re: 9.98640218180265222E-1; im: 5.21317046802833212E-2),
    (re: 9.98599939930320416E-1; im: 5.28976367256653272E-2),
    (re: 9.98559074229759315E-1; im: 5.36635376527305253E-2),
    (re: 9.98517621102622158E-1; im: 5.44294070109191333E-2),
    (re: 9.98475580573294752E-1; im: 5.51952443496899398E-2),
    (re: 9.98432952666508458E-1; im: 5.59610492185205699E-2),
    (re: 9.98389737407340174E-1; im: 5.67268211669077497E-2),
    (re: 9.98345934821212324E-1; im: 5.74925597443675717E-2),
    (re: 9.98301544933892841E-1; im: 5.82582645004357596E-2),
    (re: 9.98256567771495152E-1; im: 5.90239349846679334E-2),
    (re: 9.98211003360478162E-1; im: 5.97895707466398742E-2),
    (re: 9.98164851727646242E-1; im: 6.05551713359477895E-2),
    (re: 9.98118112900149207E-1; im: 6.13207363022085778E-2),
    (re: 9.98070786905482306E-1; im: 6.20862651950600938E-2),
    (re: 9.98022873771486201E-1; im: 6.28517575641614134E-2),
    (re: 9.97974373526346955E-1; im: 6.36172129591930982E-2),
    (re: 9.97925286198596013E-1; im: 6.43826309298574608E-2),
    (re: 9.97875611817110184E-1; im: 6.51480110258788298E-2),
    (re: 9.97825350411111629E-1; im: 6.59133527970038141E-2),
    (re: 9.97774502010167836E-1; im: 6.66786557930015684E-2),
    (re: 9.97723066644191610E-1; im: 6.74439195636640579E-2),
    (re: 9.97671044343441052E-1; im: 6.82091436588063228E-2),
    (re: 9.97618435138519540E-1; im: 6.89743276282667434E-2),
    (re: 9.97565239060375716E-1; im: 6.97394710219073052E-2),
    (re: 9.97511456140303460E-1; im: 7.05045733896138630E-2),
    (re: 9.97457086409941879E-1; im: 7.12696342812964065E-2),
    (re: 9.97402129901275285E-1; im: 7.20346532468893244E-2),
    (re: 9.97346586646633175E-1; im: 7.27996298363516695E-2),
    (re: 9.97290456678690216E-1; im: 7.35645635996674235E-2),
    (re: 9.97233740030466221E-1; im: 7.43294540868457615E-2),
    (re: 9.97176436735326134E-1; im: 7.50943008479213168E-2),
    (re: 9.97118546826980006E-1; im: 7.58591034329544457E-2),
    (re: 9.97060070339482979E-1; im: 7.66238613920314923E-2),
    (re: 9.97001007307235264E-1; im: 7.73885742752650526E-2),
    (re: 9.96941357764982121E-1; im: 7.81532416327942400E-2),
    (re: 9.96881121747813839E-1; im: 7.89178630147849492E-2),
    (re: 9.96820299291165715E-1; im: 7.96824379714301212E-2),
    (re: 9.96758890430818033E-1; im: 8.04469660529500078E-2),
    (re: 9.96696895202896044E-1; im: 8.12114468095924364E-2),
    (re: 9.96634313643869942E-1; im: 8.19758797916330742E-2),
    (re: 9.96571145790554847E-1; im: 8.27402645493756931E-2),
    (re: 9.96507391680110779E-1; im: 8.35046006331524341E-2),
    (re: 9.96443051350042639E-1; im: 8.42688875933240717E-2),
    (re: 9.96378124838200186E-1; im: 8.50331249802802787E-2),
    (re: 9.96312612182778013E-1; im: 8.57973123444398905E-2),
    (re: 9.96246513422315527E-1; im: 8.65614492362511696E-2),
    (re: 9.96179828595696927E-1; im: 8.73255352061920702E-2),
    (re: 9.96112557742151178E-1; im: 8.80895698047705023E-2),
    (re: 9.96044700901251990E-1; im: 8.88535525825245966E-2),
    (re: 9.95976258112917794E-1; im: 8.96174830900229684E-2),
    (re: 9.95907229417411719E-1; im: 9.03813608778649825E-2),
    (re: 9.95837614855341568E-1; im: 9.11451854966810172E-2),
    (re: 9.95767414467659794E-1; im: 9.19089564971327286E-2),
    (re: 9.95696628295663477E-1; im: 9.26726734299133155E-2),
    (re: 9.95625256380994298E-1; im: 9.34363358457477829E-2),
    (re: 9.95553298765638516E-1; im: 9.41999432953932069E-2),
    (re: 9.95480755491926942E-1; im: 9.49634953296389989E-2),
    (re: 9.95407626602534914E-1; im: 9.57269914993071696E-2),
    (re: 9.95333912140482274E-1; im: 9.64904313552525935E-2),
    (re: 9.95259612149133342E-1; im: 9.72538144483632728E-2),
    (re: 9.95184726672196886E-1; im: 9.80171403295606020E-2),
    (re: 9.95109255753726105E-1; im: 9.87804085497996319E-2),
    (re: 9.95033199438118596E-1; im: 9.95436186600693337E-2),
    (re: 9.94956557770116328E-1; im: 1.00306770211392863E-1),
    (re: 9.94879330794805621E-1; im: 1.01069862754827825E-1),
    (re: 9.94801518557617114E-1; im: 1.01832895841466536E-1),
    (re: 9.94723121104325742E-1; im: 1.02595869022436292E-1),
    (re: 9.94644138481050708E-1; im: 1.03358781848899626E-1),
    (re: 9.94564570734255452E-1; im: 1.04121633872054579E-1),
    (re: 9.94484417910747631E-1; im: 1.04884424643134961E-1),
    (re: 9.94403680057679086E-1; im: 1.05647153713410614E-1),
    (re: 9.94322357222545814E-1; im: 1.06409820634187676E-1),
    (re: 9.94240449453187946E-1; im: 1.07172424956808849E-1),
    (re: 9.94157956797789712E-1; im: 1.07934966232653657E-1),
    (re: 9.94074879304879414E-1; im: 1.08697444013138714E-1),
    (re: 9.93991217023329403E-1; im: 1.09459857849717987E-1),
    (re: 9.93906970002356042E-1; im: 1.10222207293883059E-1),
    (re: 9.93822138291519683E-1; im: 1.10984491897163393E-1),
    (re: 9.93736721940724637E-1; im: 1.11746711211126596E-1),
    (re: 9.93650721000219141E-1; im: 1.12508864787378686E-1),
    (re: 9.93564135520595334E-1; im: 1.13270952177564349E-1),
    (re: 9.93476965552789222E-1; im: 1.14032972933367208E-1),
    (re: 9.93389211148080651E-1; im: 1.14794926606510086E-1),
    (re: 9.93300872358093277E-1; im: 1.15556812748755269E-1),
    (re: 9.93211949234794533E-1; im: 1.16318630911904767E-1),
    (re: 9.93122441830495603E-1; im: 1.17080380647800584E-1),
    (re: 9.93032350197851386E-1; im: 1.17842061508324977E-1),
    (re: 9.92941674389860468E-1; im: 1.18603673045400719E-1),
    (re: 9.92850414459865091E-1; im: 1.19365214810991365E-1),
    (re: 9.92758570461551120E-1; im: 1.20126686357101515E-1),
    (re: 9.92666142448948014E-1; im: 1.20888087235777078E-1),
    (re: 9.92573130476428791E-1; im: 1.21649416999105534E-1),
    (re: 9.92479534598709998E-1; im: 1.22410675199216198E-1),
    (re: 9.92385354870851678E-1; im: 1.23171861388280485E-1),
    (re: 9.92290591348257339E-1; im: 1.23932975118512171E-1),
    (re: 9.92195244086673920E-1; im: 1.24694015942167659E-1),
    (re: 9.92099313142191757E-1; im: 1.25454983411546239E-1),
    (re: 9.92002798571244555E-1; im: 1.26215877078990355E-1),
    (re: 9.91905700430609348E-1; im: 1.26976696496885866E-1),
    (re: 9.91808018777406470E-1; im: 1.27737441217662312E-1),
    (re: 9.91709753669099523E-1; im: 1.28498110793793173E-1),
    (re: 9.91610905163495337E-1; im: 1.29258704777796135E-1),
    (re: 9.91511473318743941E-1; im: 1.30019222722233355E-1),
    (re: 9.91411458193338528E-1; im: 1.30779664179711719E-1),
    (re: 9.91310859846115419E-1; im: 1.31540028702883111E-1),
    (re: 9.91209678336254030E-1; im: 1.32300315844444672E-1),
    (re: 9.91107913723276837E-1; im: 1.33060525157139065E-1),
    (re: 9.91005566067049339E-1; im: 1.33820656193754738E-1),
    (re: 9.90902635427780025E-1; im: 1.34580708507126186E-1),
    (re: 9.90799121866020339E-1; im: 1.35340681650134216E-1),
    (re: 9.90695025442664642E-1; im: 1.36100575175706208E-1),
    (re: 9.90590346218950179E-1; im: 1.36860388636816378E-1),
    (re: 9.90485084256457038E-1; im: 1.37620121586486045E-1),
    (re: 9.90379239617108121E-1; im: 1.38379773577783887E-1),
    (re: 9.90272812363169102E-1; im: 1.39139344163826211E-1),
    (re: 9.90165802557248393E-1; im: 1.39898832897777210E-1),
    (re: 9.90058210262297106E-1; im: 1.40658239332849231E-1),
    (re: 9.89950035541609014E-1; im: 1.41417563022303032E-1),
    (re: 9.89841278458820520E-1; im: 1.42176803519448051E-1),
    (re: 9.89731939077910613E-1; im: 1.42935960377642666E-1),
    (re: 9.89622017463200835E-1; im: 1.43695033150294455E-1),
    (re: 9.89511513679355238E-1; im: 1.44454021390860463E-1),
    (re: 9.89400427791380352E-1; im: 1.45212924652847464E-1),
    (re: 9.89288759864625142E-1; im: 1.45971742489812221E-1),
    (re: 9.89176509964780973E-1; im: 1.46730474455361752E-1),
    (re: 9.89063678157881570E-1; im: 1.47489120103153588E-1),
    (re: 9.88950264510302976E-1; im: 1.48247678986896042E-1),
    (re: 9.88836269088763519E-1; im: 1.49006150660348467E-1),
    (re: 9.88721691960323768E-1; im: 1.49764534677321517E-1),
    (re: 9.88606533192386495E-1; im: 1.50522830591677416E-1),
    (re: 9.88490792852696638E-1; im: 1.51281037957330214E-1),
    (re: 9.88374471009341256E-1; im: 1.52039156328246053E-1),
    (re: 9.88257567730749491E-1; im: 1.52797185258443428E-1),
    (re: 9.88140083085692532E-1; im: 1.53555124301993448E-1),
    (re: 9.88022017143283568E-1; im: 1.54312973013020103E-1),
    (re: 9.87903369972977751E-1; im: 1.55070730945700522E-1),
    (re: 9.87784141644572154E-1; im: 1.55828397654265236E-1),
    (re: 9.87664332228205731E-1; im: 1.56585972692998440E-1),
    (re: 9.87543941794359276E-1; im: 1.57343455616238260E-1),
    (re: 9.87422970413855377E-1; im: 1.58100845978377005E-1),
    (re: 9.87301418157858382E-1; im: 1.58858143333861442E-1),
    (re: 9.87179285097874352E-1; im: 1.59615347237193045E-1),
    (re: 9.87056571305751018E-1; im: 1.60372457242928269E-1),
    (re: 9.86933276853677743E-1; im: 1.61129472905678804E-1),
    (re: 9.86809401814185477E-1; im: 1.61886393780111838E-1),
    (re: 9.86684946260146713E-1; im: 1.62643219420950323E-1),
    (re: 9.86559910264775448E-1; im: 1.63399949382973234E-1),
    (re: 9.86434293901627136E-1; im: 1.64156583221015831E-1),
    (re: 9.86308097244598648E-1; im: 1.64913120489969921E-1),
    (re: 9.86181320367928224E-1; im: 1.65669560744784121E-1),
    (re: 9.86053963346195436E-1; im: 1.66425903540464118E-1),
    (re: 9.85926026254321138E-1; im: 1.67182148432072932E-1),
    (re: 9.85797509167567425E-1; im: 1.67938294974731178E-1),
    (re: 9.85668412161537587E-1; im: 1.68694342723617326E-1),
    (re: 9.85538735312176068E-1; im: 1.69450291233967964E-1),
    (re: 9.85408478695768417E-1; im: 1.70206140061078062E-1),
    (re: 9.85277642388941245E-1; im: 1.70961888760301226E-1),
    (re: 9.85146226468662180E-1; im: 1.71717536887049971E-1),
    (re: 9.85014231012239824E-1; im: 1.72473083996795970E-1),
    (re: 9.84881656097323701E-1; im: 1.73228529645070326E-1),
    (re: 9.84748501801904219E-1; im: 1.73983873387463828E-1),
    (re: 9.84614768204312618E-1; im: 1.74739114779627213E-1),
    (re: 9.84480455383220930E-1; im: 1.75494253377271428E-1),
    (re: 9.84345563417641926E-1; im: 1.76249288736167892E-1),
    (re: 9.84210092386929073E-1; im: 1.77004220412148756E-1),
    (re: 9.84074042370776490E-1; im: 1.77759047961107167E-1),
    (re: 9.83937413449218895E-1; im: 1.78513770938997523E-1),
    (re: 9.83800205702631562E-1; im: 1.79268388901835744E-1),
    (re: 9.83662419211730274E-1; im: 1.80022901405699523E-1),
    (re: 9.83524054057571274E-1; im: 1.80777308006728594E-1),
    (re: 9.83385110321551217E-1; im: 1.81531608261124990E-1),
    (re: 9.83245588085407122E-1; im: 1.82285801725153306E-1),
    (re: 9.83105487431216327E-1; im: 1.83039887955140959E-1),
    (re: 9.82964808441396437E-1; im: 1.83793866507478447E-1),
    (re: 9.82823551198705277E-1; im: 1.84547736938619615E-1),
    (re: 9.82681715786240844E-1; im: 1.85301498805081910E-1),
    (re: 9.82539302287441256E-1; im: 1.86055151663446648E-1),
    (re: 9.82396310786084706E-1; im: 1.86808695070359269E-1),
    (re: 9.82252741366289409E-1; im: 1.87562128582529600E-1),
    (re: 9.82108594112513556E-1; im: 1.88315451756732120E-1),
    (re: 9.81963869109555264E-1; im: 1.89068664149806213E-1),
    (re: 9.81818566442552522E-1; im: 1.89821765318656434E-1),
    (re: 9.81672686196983146E-1; im: 1.90574754820252770E-1),
    (re: 9.81526228458664725E-1; im: 1.91327632211630896E-1),
    (re: 9.81379193313754574E-1; im: 1.92080397049892442E-1),
    (re: 9.81231580848749681E-1; im: 1.92833048892205246E-1),
    (re: 9.81083391150486654E-1; im: 1.93585587295803622E-1),
    (re: 9.80934624306141677E-1; im: 1.94338011817988617E-1),
    (re: 9.80785280403230449E-1; im: 1.95090322016128268E-1),
    (re: 9.80635359529608142E-1; im: 1.95842517447657870E-1),
    (re: 9.80484861773469344E-1; im: 1.96594597670080229E-1),
    (re: 9.80333787223348005E-1; im: 1.97346562240965929E-1),
    (re: 9.80182135968117393E-1; im: 1.98098410717953586E-1),
    (re: 9.80029908096990032E-1; im: 1.98850142658750112E-1),
    (re: 9.79877103699517659E-1; im: 1.99601757621130974E-1),
    (re: 9.79723722865591162E-1; im: 2.00353255162940454E-1),
    (re: 9.79569765685440534E-1; im: 2.01104634842091912E-1),
    (re: 9.79415232249634819E-1; im: 2.01855896216568039E-1),
    (re: 9.79260122649082055E-1; im: 2.02607038844421126E-1),
    (re: 9.79104436975029223E-1; im: 2.03358062283773318E-1),
    (re: 9.78948175319062195E-1; im: 2.04108966092816874E-1),
    (re: 9.78791337773105676E-1; im: 2.04859749829814431E-1),
    (re: 9.78633924429423155E-1; im: 2.05610413053099259E-1),
    (re: 9.78475935380616845E-1; im: 2.06360955321075525E-1),
    (re: 9.78317370719627633E-1; im: 2.07111376192218550E-1),
    (re: 9.78158230539735025E-1; im: 2.07861675225075069E-1),
    (re: 9.77998514934557087E-1; im: 2.08611851978263492E-1),
    (re: 9.77838223998050396E-1; im: 2.09361906010474164E-1),
    (re: 9.77677357824509980E-1; im: 2.10111836880469622E-1),
    (re: 9.77515916508569263E-1; im: 2.10861644147084856E-1),
    (re: 9.77353900145200013E-1; im: 2.11611327369227571E-1),
    (re: 9.77191308829712282E-1; im: 2.12360886105878441E-1),
    (re: 9.77028142657754352E-1; im: 2.13110319916091374E-1),
    (re: 9.76864401725312677E-1; im: 2.13859628358993768E-1),
    (re: 9.76700086128711830E-1; im: 2.14608810993786772E-1),
    (re: 9.76535195964614442E-1; im: 2.15357867379745543E-1),
    (re: 9.76369731330021149E-1; im: 2.16106797076219510E-1),
    (re: 9.76203692322270533E-1; im: 2.16855599642632627E-1),
    (re: 9.76037079039039063E-1; im: 2.17604274638483637E-1),
    (re: 9.75869891578341042E-1; im: 2.18352821623346329E-1),
    (re: 9.75702130038528544E-1; im: 2.19101240156869797E-1),
    (re: 9.75533794518291363E-1; im: 2.19849529798778702E-1),
    (re: 9.75364885116656946E-1; im: 2.20597690108873526E-1),
    (re: 9.75195401932990344E-1; im: 2.21345720647030834E-1),
    (re: 9.75025345066994147E-1; im: 2.22093620973203534E-1),
    (re: 9.74854714618708427E-1; im: 2.22841390647421133E-1),
    (re: 9.74683510688510681E-1; im: 2.23589029229789997E-1),
    (re: 9.74511733377115770E-1; im: 2.24336536280493611E-1),
    (re: 9.74339382785575861E-1; im: 2.25083911359792836E-1),
    (re: 9.74166459015280365E-1; im: 2.25831154028026169E-1),
    (re: 9.73992962167955883E-1; im: 2.26578263845609999E-1),
    (re: 9.73818892345666139E-1; im: 2.27325240373038871E-1),
    (re: 9.73644249650811925E-1; im: 2.28072083170885739E-1),
    (re: 9.73469034186131039E-1; im: 2.28818791799802227E-1),
    (re: 9.73293246054698224E-1; im: 2.29565365820518886E-1),
    (re: 9.73116885359925108E-1; im: 2.30311804793845456E-1),
    (re: 9.72939952205560145E-1; im: 2.31058108280671120E-1),
    (re: 9.72762446695688552E-1; im: 2.31804275841964764E-1),
    (re: 9.72584368934732245E-1; im: 2.32550307038775238E-1),
    (re: 9.72405719027449784E-1; im: 2.33296201432231609E-1),
    (re: 9.72226497078936306E-1; im: 2.34041958583543423E-1),
    (re: 9.72046703194623466E-1; im: 2.34787578054000962E-1),
    (re: 9.71866337480279374E-1; im: 2.35533059404975502E-1),
    (re: 9.71685400042008533E-1; im: 2.36278402197919571E-1),
    (re: 9.71503890986251776E-1; im: 2.37023605994367207E-1),
    (re: 9.71321810419786203E-1; im: 2.37768670355934217E-1),
    (re: 9.71139158449725121E-1; im: 2.38513594844318432E-1),
    (re: 9.70955935183517979E-1; im: 2.39258379021299970E-1),
    (re: 9.70772140728950302E-1; im: 2.40003022448741487E-1),
    (re: 9.70587775194143634E-1; im: 2.40747524688588440E-1),
    (re: 9.70402838687555467E-1; im: 2.41491885302869344E-1),
    (re: 9.70217331317979185E-1; im: 2.42236103853696027E-1),
    (re: 9.70031253194543993E-1; im: 2.42980179903263890E-1),
    (re: 9.69844604426714857E-1; im: 2.43724113013852164E-1),
    (re: 9.69657385124292438E-1; im: 2.44467902747824166E-1),
    (re: 9.69469595397413028E-1; im: 2.45211548667627561E-1),
    (re: 9.69281235356548486E-1; im: 2.45955050335794612E-1),
    (re: 9.69092305112506170E-1; im: 2.46698407314942444E-1),
    (re: 9.68902804776428876E-1; im: 2.47441619167773298E-1),
    (re: 9.68712734459794768E-1; im: 2.48184685457074791E-1),
    (re: 9.68522094274417316E-1; im: 2.48927605745720168E-1),
    (re: 9.68330884332445231E-1; im: 2.49670379596668565E-1),
    (re: 9.68139104746362395E-1; im: 2.50413006572965262E-1),
    (re: 9.67946755628987796E-1; im: 2.51155486237741943E-1),
    (re: 9.67753837093475465E-1; im: 2.51897818154216950E-1),
    (re: 9.67560349253314407E-1; im: 2.52640001885695543E-1),
    (re: 9.67366292222328531E-1; im: 2.53382036995570155E-1),
    (re: 9.67171666114676590E-1; im: 2.54123923047320647E-1),
    (re: 9.66976471044852109E-1; im: 2.54865659604514572E-1),
    (re: 9.66780707127683318E-1; im: 2.55607246230807421E-1),
    (re: 9.66584374478333085E-1; im: 2.56348682489942890E-1),
    (re: 9.66387473212298850E-1; im: 2.57089967945753130E-1),
    (re: 9.66190003445412555E-1; im: 2.57831102162159006E-1),
    (re: 9.65991965293840576E-1; im: 2.58572084703170353E-1),
    (re: 9.65793358874083655E-1; im: 2.59312915132886234E-1),
    (re: 9.65594184302976832E-1; im: 2.60053593015495194E-1),
    (re: 9.65394441697689375E-1; im: 2.60794117915275518E-1),
    (re: 9.65194131175724712E-1; im: 2.61534489396595487E-1),
    (re: 9.64993252854920364E-1; im: 2.62274707023913632E-1),
    (re: 9.64791806853447870E-1; im: 2.63014770361778996E-1),
    (re: 9.64589793289812724E-1; im: 2.63754678974831384E-1),
    (re: 9.64387212282854299E-1; im: 2.64494432427801622E-1),
    (re: 9.64184063951745783E-1; im: 2.65234030285511813E-1),
    (re: 9.63980348415994105E-1; im: 2.65973472112875593E-1),
    (re: 9.63776065795439867E-1; im: 2.66712757474898386E-1),
    (re: 9.63571216210257270E-1; im: 2.67451885936677661E-1),
    (re: 9.63365799780954047E-1; im: 2.68190857063403188E-1),
    (re: 9.63159816628371392E-1; im: 2.68929670420357290E-1),
    (re: 9.62953266873683886E-1; im: 2.69668325572915107E-1),
    (re: 9.62746150638399429E-1; im: 2.70406822086544841E-1),
    (re: 9.62538468044359165E-1; im: 2.71145159526808022E-1),
    (re: 9.62330219213737413E-1; im: 2.71883337459359756E-1),
    (re: 9.62121404269041595E-1; im: 2.72621355449948984E-1),
    (re: 9.61912023333112164E-1; im: 2.73359213064418738E-1),
    (re: 9.61702076529122529E-1; im: 2.74096909868706392E-1),
    (re: 9.61491563980578985E-1; im: 2.74834445428843923E-1),
    (re: 9.61280485811320642E-1; im: 2.75571819310958163E-1),
    (re: 9.61068842145519347E-1; im: 2.76309031081271056E-1),
    (re: 9.60856633107679618E-1; im: 2.77046080306099911E-1),
    (re: 9.60643858822638562E-1; im: 2.77782966551857658E-1),
    (re: 9.60430519415565811E-1; im: 2.78519689385053105E-1),
    (re: 9.60216615011963441E-1; im: 2.79256248372291190E-1),
    (re: 9.60002145737665900E-1; im: 2.79992643080273238E-1),
    (re: 9.59787111718839938E-1; im: 2.80728873075797216E-1),
    (re: 9.59571513081984528E-1; im: 2.81464937925757984E-1),
    (re: 9.59355349953930793E-1; im: 2.82200837197147557E-1),
    (re: 9.59138622461841932E-1; im: 2.82936570457055353E-1),
    (re: 9.58921330733213144E-1; im: 2.83672137272668450E-1),
    (re: 9.58703474895871555E-1; im: 2.84407537211271844E-1),
    (re: 9.58485055077976142E-1; im: 2.85142769840248696E-1),
    (re: 9.58266071408017655E-1; im: 2.85877834727080595E-1),
    (re: 9.58046524014818547E-1; im: 2.86612731439347806E-1),
    (re: 9.57826413027532890E-1; im: 2.87347459544729526E-1),
    (re: 9.57605738575646310E-1; im: 2.88082018611004143E-1),
    (re: 9.57384500788975899E-1; im: 2.88816408206049482E-1),
    (re: 9.57162699797670148E-1; im: 2.89550627897843067E-1),
    (re: 9.56940335732208865E-1; im: 2.90284677254462368E-1),
    (re: 9.56717408723403101E-1; im: 2.91018555844085062E-1),
    (re: 9.56493918902395072E-1; im: 2.91752263234989282E-1),
    (re: 9.56269866400658082E-1; im: 2.92485798995553875E-1),
    (re: 9.56045251349996443E-1; im: 2.93219162694258651E-1),
    (re: 9.55820073882545405E-1; im: 2.93952353899684640E-1),
    (re: 9.55594334130771068E-1; im: 2.94685372180514348E-1),
    (re: 9.55368032227470314E-1; im: 2.95418217105532006E-1),
    (re: 9.55141168305770722E-1; im: 2.96150888243623824E-1),
    (re: 9.54913742499130490E-1; im: 2.96883385163778250E-1),
    (re: 9.54685754941338363E-1; im: 2.97615707435086218E-1),
    (re: 9.54457205766513546E-1; im: 2.98347854626741403E-1),
    (re: 9.54228095109105630E-1; im: 2.99079826308040477E-1),
    (re: 9.53998423103894512E-1; im: 2.99811622048383357E-1),
    (re: 9.53768189885990316E-1; im: 3.00543241417273464E-1),
    (re: 9.53537395590833312E-1; im: 3.01274683984317973E-1),
    (re: 9.53306040354193837E-1; im: 3.02005949319228067E-1),
    (re: 9.53074124312172216E-1; im: 3.02737036991819190E-1),
    (re: 9.52841647601198682E-1; im: 3.03467946572011301E-1),
    (re: 9.52608610358033294E-1; im: 3.04198677629829125E-1),
    (re: 9.52375012719765858E-1; im: 3.04929229735402406E-1),
    (re: 9.52140854823815847E-1; im: 3.05659602458966166E-1),
    (re: 9.51906136807932317E-1; im: 3.06389795370860946E-1),
    (re: 9.51670858810193830E-1; im: 3.07119808041533070E-1),
    (re: 9.51435020969008370E-1; im: 3.07849640041534894E-1),
    (re: 9.51198623423113262E-1; im: 3.08579290941525054E-1),
    (re: 9.50961666311575093E-1; im: 3.09308760312268724E-1),
    (re: 9.50724149773789627E-1; im: 3.10038047724637870E-1),
    (re: 9.50486073949481722E-1; im: 3.10767152749611496E-1),
    (re: 9.50247438978705252E-1; im: 3.11496074958275900E-1),
    (re: 9.50008245001843023E-1; im: 3.12224813921824927E-1),
    (re: 9.49768492159606688E-1; im: 3.12953369211560222E-1),
    (re: 9.49528180593036667E-1; im: 3.13681740398891477E-1),
    (re: 9.49287310443502064E-1; im: 3.14409927055336689E-1),
    (re: 9.49045881852700581E-1; im: 3.15137928752522409E-1),
    (re: 9.48803894962658438E-1; im: 3.15865745062183997E-1),
    (re: 9.48561349915730288E-1; im: 3.16593375556165867E-1),
    (re: 9.48318246854599133E-1; im: 3.17320819806421749E-1),
    (re: 9.48074585922276241E-1; im: 3.18048077385014931E-1),
    (re: 9.47830367262101059E-1; im: 3.18775147864118517E-1),
    (re: 9.47585591017741135E-1; im: 3.19502030816015678E-1),
    (re: 9.47340257333192025E-1; im: 3.20228725813099900E-1),
    (re: 9.47094366352777215E-1; im: 3.20955232427875239E-1),
    (re: 9.46847918221148035E-1; im: 3.21681550232956573E-1),
    (re: 9.46600913083283570E-1; im: 3.22407678801069848E-1),
    (re: 9.46353351084490579E-1; im: 3.23133617705052338E-1),
    (re: 9.46105232370403407E-1; im: 3.23859366517852888E-1),
    (re: 9.45856557086983902E-1; im: 3.24584924812532171E-1),
    (re: 9.45607325380521326E-1; im: 3.25310292162262934E-1),
    (re: 9.45357537397632269E-1; im: 3.26035468140330255E-1),
    (re: 9.45107193285260568E-1; im: 3.26760452320131791E-1),
    (re: 9.44856293190677213E-1; im: 3.27485244275178025E-1),
    (re: 9.44604837261480266E-1; im: 3.28209843579092526E-1),
    (re: 9.44352825645594770E-1; im: 3.28934249805612192E-1),
    (re: 9.44100258491272668E-1; im: 3.29658462528587503E-1),
    (re: 9.43847135947092708E-1; im: 3.30382481321982774E-1),
    (re: 9.43593458161960361E-1; im: 3.31106305759876402E-1),
    (re: 9.43339225285107734E-1; im: 3.31829935416461119E-1),
    (re: 9.43084437466093476E-1; im: 3.32553369866044243E-1),
    (re: 9.42829094854802698E-1; im: 3.33276608683047926E-1),
    (re: 9.42573197601446879E-1; im: 3.33999651442009405E-1),
    (re: 9.42316745856563780E-1; im: 3.34722497717581254E-1),
    (re: 9.42059739771017356E-1; im: 3.35445147084531633E-1),
    (re: 9.41802179495997664E-1; im: 3.36167599117744537E-1),
    (re: 9.41544065183020778E-1; im: 3.36889853392220051E-1),
    (re: 9.41285396983928700E-1; im: 3.37611909483074591E-1),
    (re: 9.41026175050889265E-1; im: 3.38333766965541164E-1),
    (re: 9.40766399536396059E-1; im: 3.39055425414969610E-1),
    (re: 9.40506070593268324E-1; im: 3.39776884406826858E-1),
    (re: 9.40245188374650869E-1; im: 3.40498143516697169E-1),
    (re: 9.39983753034013982E-1; im: 3.41219202320282393E-1),
    (re: 9.39721764725153339E-1; im: 3.41940060393402213E-1),
    (re: 9.39459223602189912E-1; im: 3.42660717311994398E-1),
    (re: 9.39196129819569879E-1; im: 3.43381172652115048E-1),
    (re: 9.38932483532064533E-1; im: 3.44101425989938850E-1),
    (re: 9.38668284894770194E-1; im: 3.44821476901759323E-1),
    (re: 9.38403534063108112E-1; im: 3.45541324963989066E-1),
    (re: 9.38138231192824381E-1; im: 3.46260969753160010E-1),
    (re: 9.37872376439989844E-1; im: 3.46980410845923668E-1),
    (re: 9.37605969961000002E-1; im: 3.47699647819051381E-1),
    (re: 9.37339011912574923E-1; im: 3.48418680249434568E-1),
    (re: 9.37071502451759149E-1; im: 3.49137507714084976E-1),
    (re: 9.36803441735921604E-1; im: 3.49856129790134928E-1),
    (re: 9.36534829922755500E-1; im: 3.50574546054837571E-1),
    (re: 9.36265667170278247E-1; im: 3.51292756085567126E-1),
    (re: 9.35995953636831356E-1; im: 3.52010759459819136E-1),
    (re: 9.35725689481080350E-1; im: 3.52728555755210716E-1),
    (re: 9.35454874862014670E-1; im: 3.53446144549480798E-1),
    (re: 9.35183509938947578E-1; im: 3.54163525420490382E-1),
    (re: 9.34911594871516066E-1; im: 3.54880697946222787E-1),
    (re: 9.34639129819680764E-1; im: 3.55597661704783891E-1),
    (re: 9.34366114943725841E-1; im: 3.56314416274402389E-1),
    (re: 9.34092550404258915E-1; im: 3.57030961233430033E-1),
    (re: 9.33818436362210956E-1; im: 3.57747296160341885E-1),
    (re: 9.33543772978836192E-1; im: 3.58463420633736565E-1),
    (re: 9.33268560415712016E-1; im: 3.59179334232336494E-1),
    (re: 9.32992798834738888E-1; im: 3.59895036534988149E-1),
    (re: 9.32716488398140240E-1; im: 3.60610527120662303E-1),
    (re: 9.32439629268462385E-1; im: 3.61325805568454280E-1),
    (re: 9.32162221608574414E-1; im: 3.62040871457584198E-1),
    (re: 9.31884265581668107E-1; im: 3.62755724367397216E-1),
    (re: 9.31605761351257833E-1; im: 3.63470363877363787E-1),
    (re: 9.31326709081180455E-1; im: 3.64184789567079899E-1),
    (re: 9.31047108935595234E-1; im: 3.64899001016267324E-1),
    (re: 9.30766961078983732E-1; im: 3.65612997804773870E-1),
    (re: 9.30486265676149715E-1; im: 3.66326779512573621E-1),
    (re: 9.30205022892219057E-1; im: 3.67040345719767188E-1),
    (re: 9.29923232892639642E-1; im: 3.67753696006581956E-1),
    (re: 9.29640895843181265E-1; im: 3.68466829953372332E-1),
    (re: 9.29358011909935540E-1; im: 3.69179747140619986E-1),
    (re: 9.29074581259315795E-1; im: 3.69892447148934107E-1),
    (re: 9.28790604058056980E-1; im: 3.70604929559051641E-1),
    (re: 9.28506080473215566E-1; im: 3.71317193951837543E-1),
    (re: 9.28221010672169447E-1; im: 3.72029239908285023E-1),
    (re: 9.27935394822617843E-1; im: 3.72741067009515789E-1),
    (re: 9.27649233092581198E-1; im: 3.73452674836780297E-1),
    (re: 9.27362525650401087E-1; im: 3.74164062971457997E-1),
    (re: 9.27075272664740111E-1; im: 3.74875230995057578E-1),
    (re: 9.26787474304581799E-1; im: 3.75586178489217215E-1),
    (re: 9.26499130739230512E-1; im: 3.76296905035704813E-1),
    (re: 9.26210242138311342E-1; im: 3.77007410216418257E-1),
    (re: 9.25920808671770008E-1; im: 3.77717693613385655E-1),
    (re: 9.25630830509872762E-1; im: 3.78427754808765584E-1),
    (re: 9.25340307823206286E-1; im: 3.79137593384847338E-1),
    (re: 9.25049240782677590E-1; im: 3.79847208924051171E-1),
    (re: 9.24757629559513916E-1; im: 3.80556601008928543E-1),
    (re: 9.24465474325262634E-1; im: 3.81265769222162370E-1),
    (re: 9.24172775251791139E-1; im: 3.81974713146567261E-1),
    (re: 9.23879532511286756E-1; im: 3.82683432365089772E-1),
    (re: 9.23585746276256634E-1; im: 3.83391926460808646E-1),
    (re: 9.23291416719527646E-1; im: 3.84100195016935061E-1),
    (re: 9.22996544014246286E-1; im: 3.84808237616812874E-1),
    (re: 9.22701128333878570E-1; im: 3.85516053843918864E-1),
    (re: 9.22405169852209932E-1; im: 3.86223643281862983E-1),
    (re: 9.22108668743345121E-1; im: 3.86931005514388594E-1),
    (re: 9.21811625181708100E-1; im: 3.87638140125372721E-1),
    (re: 9.21514039342041943E-1; im: 3.88345046698826292E-1),
    (re: 9.21215911399408734E-1; im: 3.89051724818894381E-1),
    (re: 9.20917241529189458E-1; im: 3.89758174069856459E-1),
    (re: 9.20618029907083906E-1; im: 3.90464394036126632E-1),
    (re: 9.20318276709110566E-1; im: 3.91170384302253889E-1),
    (re: 9.20017982111606522E-1; im: 3.91876144452922346E-1),
    (re: 9.19717146291227348E-1; im: 3.92581674072951490E-1),
    (re: 9.19415769424947007E-1; im: 3.93286972747296424E-1),
    (re: 9.19113851690057744E-1; im: 3.93992040061048109E-1),
    (re: 9.18811393264169984E-1; im: 3.94696875599433609E-1),
    (re: 9.18508394325212226E-1; im: 3.95401478947816337E-1),
    (re: 9.18204855051430939E-1; im: 3.96105849691696297E-1),
    (re: 9.17900775621390458E-1; im: 3.96809987416710329E-1),
    (re: 9.17596156213972876E-1; im: 3.97513891708632349E-1),
    (re: 9.17290997008377944E-1; im: 3.98217562153373600E-1),
    (re: 9.16985298184122959E-1; im: 3.98920998336982887E-1),
    (re: 9.16679059921042663E-1; im: 3.99624199845646829E-1),
    (re: 9.16372282399289137E-1; im: 4.00327166265690094E-1),
    (re: 9.16064965799331692E-1; im: 4.01029897183575649E-1),
    (re: 9.15757110301956768E-1; im: 4.01732392185905002E-1),
    (re: 9.15448716088267820E-1; im: 4.02434650859418441E-1),
    (re: 9.15139783339685219E-1; im: 4.03136672790995282E-1),
    (re: 9.14830312237946142E-1; im: 4.03838457567654111E-1),
    (re: 9.14520302965104464E-1; im: 4.04540004776553023E-1),
    (re: 9.14209755703530655E-1; im: 4.05241314004989871E-1),
    (re: 9.13898670635911665E-1; im: 4.05942384840402505E-1),
    (re: 9.13587047945250827E-1; im: 4.06643216870369015E-1),
    (re: 9.13274887814867739E-1; im: 4.07343809682607974E-1),
    (re: 9.12962190428398165E-1; im: 4.08044162864978681E-1),
    (re: 9.12648955969793919E-1; im: 4.08744276005481403E-1),
    (re: 9.12335184623322764E-1; im: 4.09444148692257618E-1),
    (re: 9.12020876573568299E-1; im: 4.10143780513590256E-1),
    (re: 9.11706032005429851E-1; im: 4.10843171057903942E-1),
    (re: 9.11390651104122369E-1; im: 4.11542319913765238E-1),
    (re: 9.11074734055176310E-1; im: 4.12241226669882886E-1),
    (re: 9.10758281044437535E-1; im: 4.12939890915108047E-1),
    (re: 9.10441292258067197E-1; im: 4.13638312238434548E-1),
    (re: 9.10123767882541632E-1; im: 4.14336490228999117E-1),
    (re: 9.09805708104652250E-1; im: 4.15034424476081631E-1),
    (re: 9.09487113111505423E-1; im: 4.15732114569105355E-1),
    (re: 9.09167983090522377E-1; im: 4.16429560097637183E-1),
    (re: 9.08848318229439081E-1; im: 4.17126760651387878E-1),
    (re: 9.08528118716306137E-1; im: 4.17823715820212319E-1),
    (re: 9.08207384739488669E-1; im: 4.18520425194109737E-1),
    (re: 9.07886116487666212E-1; im: 4.19216888363223956E-1),
    (re: 9.07564314149832601E-1; im: 4.19913104917843640E-1),
    (re: 9.07241977915295861E-1; im: 4.20609074448402525E-1),
    (re: 9.06919107973678093E-1; im: 4.21304796545479668E-1),
    (re: 9.06595704514915365E-1; im: 4.22000270799799686E-1),
    (re: 9.06271767729257601E-1; im: 4.22695496802232992E-1),
    (re: 9.05947297807268464E-1; im: 4.23390474143796041E-1),
    (re: 9.05622294939825251E-1; im: 4.24085202415651569E-1),
    (re: 9.05296759318118774E-1; im: 4.24779681209108833E-1),
    (re: 9.04970691133653253E-1; im: 4.25473910115623852E-1),
    (re: 9.04644090578246200E-1; im: 4.26167888726799646E-1),
    (re: 9.04316957844028306E-1; im: 4.26861616634386478E-1),
    (re: 9.03989293123443332E-1; im: 4.27555093430282094E-1),
    (re: 9.03661096609247989E-1; im: 4.28248318706531962E-1),
    (re: 9.03332368494511831E-1; im: 4.28941292055329512E-1),
    (re: 9.03003108972617139E-1; im: 4.29634013069016378E-1),
    (re: 9.02673318237258807E-1; im: 4.30326481340082634E-1),
    (re: 9.02342996482444226E-1; im: 4.31018696461167038E-1),
    (re: 9.02012143902493176E-1; im: 4.31710658025057268E-1),
    (re: 9.01680760692037704E-1; im: 4.32402365624690165E-1),
    (re: 9.01348847046022015E-1; im: 4.33093818853151968E-1),
    (re: 9.01016403159702355E-1; im: 4.33785017303678560E-1),
    (re: 9.00683429228646898E-1; im: 4.34475960569655699E-1),
    (re: 9.00349925448735629E-1; im: 4.35166648244619264E-1),
    (re: 9.00015892016160229E-1; im: 4.35857079922255491E-1),
    (re: 8.99681329127423959E-1; im: 4.36547255196401213E-1),
    (re: 8.99346236979341548E-1; im: 4.37237173661044097E-1),
    (re: 8.99010615769039072E-1; im: 4.37926834910322887E-1),
    (re: 8.98674465693953843E-1; im: 4.38616238538527638E-1),
    (re: 8.98337786951834289E-1; im: 4.39305384140099957E-1),
    (re: 8.98000579740739840E-1; im: 4.39994271309633244E-1),
    (re: 8.97662844259040810E-1; im: 4.40682899641872924E-1),
    (re: 8.97324580705418281E-1; im: 4.41371268731716693E-1),
    (re: 8.96985789278863987E-1; im: 4.42059378174214749E-1),
    (re: 8.96646470178680196E-1; im: 4.42747227564570037E-1),
    (re: 8.96306623604479591E-1; im: 4.43434816498138483E-1),
    (re: 8.95966249756185156E-1; im: 4.44122144570429232E-1),
    (re: 8.95625348834030057E-1; im: 4.44809211377104887E-1),
    (re: 8.95283921038557522E-1; im: 4.45496016513981749E-1),
    (re: 8.94941966570620729E-1; im: 4.46182559577030050E-1),
    (re: 8.94599485631382678E-1; im: 4.46868840162374195E-1),
    (re: 8.94256478422316084E-1; im: 4.47554857866292998E-1),
    (re: 8.93912945145203251E-1; im: 4.48240612285219917E-1),
    (re: 8.93568886002135953E-1; im: 4.48926103015743296E-1),
    (re: 8.93224301195515320E-1; im: 4.49611329654606600E-1),
    (re: 8.92879190928051717E-1; im: 4.50296291798708652E-1),
    (re: 8.92533555402764622E-1; im: 4.50980989045103869E-1),
    (re: 8.92187394822982508E-1; im: 4.51665420991002503E-1),
    (re: 8.91840709392342728E-1; im: 4.52349587233770874E-1),
    (re: 8.91493499314791387E-1; im: 4.53033487370931608E-1),
    (re: 8.91145764794583228E-1; im: 4.53717121000163876E-1),
    (re: 8.90797506036281511E-1; im: 4.54400487719303626E-1),
    (re: 8.90448723244757890E-1; im: 4.55083587126343824E-1),
    (re: 8.90099416625192295E-1; im: 4.55766418819434688E-1),
    (re: 8.89749586383072812E-1; im: 4.56448982396883927E-1),
    (re: 8.89399232724195557E-1; im: 4.57131277457156973E-1),
    (re: 8.89048355854664563E-1; im: 4.57813303598877222E-1),
    (re: 8.88696955980891650E-1; im: 4.58495060420826266E-1),
    (re: 8.88345033309596312E-1; im: 4.59176547521944133E-1),
    (re: 8.87992588047805589E-1; im: 4.59857764501329518E-1),
    (re: 8.87639620402853948E-1; im: 4.60538710958240024E-1),
    (re: 8.87286130582383160E-1; im: 4.61219386492092394E-1),
    (re: 8.86932118794342179E-1; im: 4.61899790702462750E-1),
    (re: 8.86577585246987019E-1; im: 4.62579923189086824E-1),
    (re: 8.86222530148880632E-1; im: 4.63259783551860197E-1),
    (re: 8.85866953708892784E-1; im: 4.63939371390838536E-1),
    (re: 8.85510856136199933E-1; im: 4.64618686306237822E-1),
    (re: 8.85154237640285108E-1; im: 4.65297727898434594E-1),
    (re: 8.84797098430937780E-1; im: 4.65976495767966178E-1),
    (re: 8.84439438718253746E-1; im: 4.66654989515530924E-1),
    (re: 8.84081258712634999E-1; im: 4.67333208741988442E-1),
    (re: 8.83722558624789609E-1; im: 4.68011153048359835E-1),
    (re: 8.83363338665731595E-1; im: 4.68688822035827934E-1),
    (re: 8.83003599046780804E-1; im: 4.69366215305737533E-1),
    (re: 8.82643339979562786E-1; im: 4.70043332459595625E-1),
    (re: 8.82282561676008667E-1; im: 4.70720173099071633E-1),
    (re: 8.81921264348355030E-1; im: 4.71396736825997649E-1),
    (re: 8.81559448209143782E-1; im: 4.72073023242368661E-1),
    (re: 8.81197113471222037E-1; im: 4.72749031950342796E-1),
    (re: 8.80834260347741985E-1; im: 4.73424762552241549E-1),
    (re: 8.80470889052160771E-1; im: 4.74100214650550014E-1),
    (re: 8.80106999798240365E-1; im: 4.74775387847917127E-1),
    (re: 8.79742592800047441E-1; im: 4.75450281747155890E-1),
    (re: 8.79377668271953246E-1; im: 4.76124895951243610E-1),
    (re: 8.79012226428633478E-1; im: 4.76799230063322133E-1),
    (re: 8.78646267485068158E-1; im: 4.77473283686698074E-1),
    (re: 8.78279791656541505E-1; im: 4.78147056424843053E-1),
    (re: 8.77912799158641806E-1; im: 4.78820547881393928E-1),
    (re: 8.77545290207261292E-1; im: 4.79493757660153027E-1),
    (re: 8.77177265018596010E-1; im: 4.80166685365088381E-1),
    (re: 8.76808723809145698E-1; im: 4.80839330600333960E-1),
    (re: 8.76439666795713652E-1; im: 4.81511692970189902E-1),
    (re: 8.76070094195406607E-1; im: 4.82183772079122749E-1),
    (re: 8.75700006225634600E-1; im: 4.82855567531765675E-1),
    (re: 8.75329403104110850E-1; im: 4.83527078932918724E-1),
    (re: 8.74958285048851624E-1; im: 4.84198305887549041E-1),
    (re: 8.74586652278176113E-1; im: 4.84869248000791102E-1),
    (re: 8.74214505010706300E-1; im: 4.85539904877946948E-1),
    (re: 8.73841843465366835E-1; im: 4.86210276124486416E-1),
    (re: 8.73468667861384903E-1; im: 4.86880361346047376E-1),
    (re: 8.73094978418290099E-1; im: 4.87550160148435955E-1),
    (re: 8.72720775355914292E-1; im: 4.88219672137626774E-1),
    (re: 8.72346058894391505E-1; im: 4.88888896919763180E-1),
    (re: 8.71970829254157775E-1; im: 4.89557834101157477E-1),
    (re: 8.71595086655951035E-1; im: 4.90226483288291154E-1),
    (re: 8.71218831320810972E-1; im: 4.90894844087815123E-1),
    (re: 8.70842063470078908E-1; im: 4.91562916106549945E-1),
    (re: 8.70464783325397660E-1; im: 4.92230698951486064E-1),
    (re: 8.70086991108711419E-1; im: 4.92898192229784037E-1),
    (re: 8.69708687042265610E-1; im: 4.93565395548774766E-1),
    (re: 8.69329871348606771E-1; im: 4.94232308515959730E-1),
    (re: 8.68950544250582413E-1; im: 4.94898930739011211E-1),
    (re: 8.68570705971340895E-1; im: 4.95565261825772531E-1),
    (re: 8.68190356734331291E-1; im: 4.96231301384258280E-1),
    (re: 8.67809496763303257E-1; im: 4.96897049022654545E-1),
    (re: 8.67428126282306901E-1; im: 4.97562504349319144E-1),
    (re: 8.67046245515692652E-1; im: 4.98227666972781852E-1),
    (re: 8.66663854688111125E-1; im: 4.98892536501744637E-1),
    (re: 8.66280954024512993E-1; im: 4.99557112545081883E-1),
    (re: 8.65897543750148850E-1; im: 5.00221394711840628E-1),
    (re: 8.65513624090569083E-1; im: 5.00885382611240786E-1),
    (re: 8.65129195271623736E-1; im: 5.01549075852675385E-1),
    (re: 8.64744257519462378E-1; im: 5.02212474045710791E-1),
    (re: 8.64358811060533972E-1; im: 5.02875576800086937E-1),
    (re: 8.63972856121586738E-1; im: 5.03538383725717559E-1),
    (re: 8.63586392929668023E-1; im: 5.04200894432690418E-1),
    (re: 8.63199421712124166E-1; im: 5.04863108531267536E-1),
    (re: 8.62811942696600364E-1; im: 5.05525025631885419E-1),
    (re: 8.62423956111040539E-1; im: 5.06186645345155291E-1),
    (re: 8.62035462183687202E-1; im: 5.06847967281863321E-1),
    (re: 8.61646461143081322E-1; im: 5.07508991052970853E-1),
    (re: 8.61256953218062189E-1; im: 5.08169716269614632E-1),
    (re: 8.60866938637767279E-1; im: 5.08830142543107037E-1),
    (re: 8.60476417631632122E-1; im: 5.09490269484936307E-1),
    (re: 8.60085390429390164E-1; im: 5.10150096706766769E-1),
    (re: 8.59693857261072633E-1; im: 5.10809623820439070E-1),
    (re: 8.59301818357008405E-1; im: 5.11468850437970399E-1),
    (re: 8.58909273947823866E-1; im: 5.12127776171554724E-1),
    (re: 8.58516224264442778E-1; im: 5.12786400633563012E-1),
    (re: 8.58122669538086144E-1; im: 5.13444723436543461E-1),
    (re: 8.57728610000272070E-1; im: 5.14102744193221727E-1),
    (re: 8.57334045882815628E-1; im: 5.14760462516501152E-1),
    (re: 8.56938977417828723E-1; im: 5.15417878019462993E-1),
    (re: 8.56543404837719955E-1; im: 5.16074990315366647E-1),
    (re: 8.56147328375194481E-1; im: 5.16731799017649882E-1),
    (re: 8.55750748263253879E-1; im: 5.17388303739929058E-1),
    (re: 8.55353664735196010E-1; im: 5.18044504095999364E-1),
    (re: 8.54956078024614885E-1; im: 5.18700399699835035E-1),
    (re: 8.54557988365400521E-1; im: 5.19355990165589587E-1),
    (re: 8.54159395991738808E-1; im: 5.20011275107596041E-1),
    (re: 8.53760301138111370E-1; im: 5.20666254140367147E-1),
    (re: 8.53360704039295428E-1; im: 5.21320926878595616E-1),
    (re: 8.52960604930363658E-1; im: 5.21975292937154343E-1),
    (re: 8.52560004046684058E-1; im: 5.22629351931096635E-1),
    (re: 8.52158901623919808E-1; im: 5.23283103475656438E-1),
    (re: 8.51757297898029128E-1; im: 5.23936547186248562E-1),
    (re: 8.51355193105265142E-1; im: 5.24589682678468906E-1),
    (re: 8.50952587482175741E-1; im: 5.25242509568094690E-1),
    (re: 8.50549481265603440E-1; im: 5.25895027471084672E-1),
    (re: 8.50145874692685240E-1; im: 5.26547236003579384E-1),
    (re: 8.49741768000852490E-1; im: 5.27199134781901348E-1),
    (re: 8.49337161427830743E-1; im: 5.27850723422555310E-1),
    (re: 8.48932055211639624E-1; im: 5.28502001542228460E-1),
    (re: 8.48526449590592681E-1; im: 5.29152968757790660E-1),
    (re: 8.48120344803297251E-1; im: 5.29803624686294668E-1),
    (re: 8.47713741088654318E-1; im: 5.30453968944976367E-1),
    (re: 8.47306638685858371E-1; im: 5.31104001151254983E-1),
    (re: 8.46899037834397265E-1; im: 5.31753720922733319E-1),
    (re: 8.46490938774052078E-1; im: 5.32403127877197971E-1),
    (re: 8.46082341744896975E-1; im: 5.33052221632619562E-1),
    (re: 8.45673246987299059E-1; im: 5.33701001807152956E-1),
    (re: 8.45263654741918237E-1; im: 5.34349468019137494E-1),
    (re: 8.44853565249707073E-1; im: 5.34997619887097211E-1),
    (re: 8.44442978751910651E-1; im: 5.35645457029741061E-1),
    (re: 8.44031895490066428E-1; im: 5.36292979065963144E-1),
    (re: 8.43620315706004096E-1; im: 5.36940185614842931E-1),
    (re: 8.43208239641845437E-1; im: 5.37587076295645482E-1),
    (re: 8.42795667540004184E-1; im: 5.38233650727821678E-1),
    (re: 8.42382599643185874E-1; im: 5.38879908531008439E-1),
    (re: 8.41969036194387709E-1; im: 5.39525849325028949E-1),
    (re: 8.41554977436898410E-1; im: 5.40171472729892881E-1),
    (re: 8.41140423614298076E-1; im: 5.40816778365796621E-1),
    (re: 8.40725374970458040E-1; im: 5.41461765853123489E-1),
    (re: 8.40309831749540726E-1; im: 5.42106434812443964E-1),
    (re: 8.39893794195999505E-1; im: 5.42750784864515907E-1),
    (re: 8.39477262554578550E-1; im: 5.43394815630284782E-1),
    (re: 8.39060237070312694E-1; im: 5.44038526730883885E-1),
    (re: 8.38642717988527286E-1; im: 5.44681917787634559E-1),
    (re: 8.38224705554838043E-1; im: 5.45324988422046422E-1),
    (re: 8.37806200015150912E-1; im: 5.45967738255817589E-1),
    (re: 8.37387201615661917E-1; im: 5.46610166910834892E-1),
    (re: 8.36967710602857023E-1; im: 5.47252274009174105E-1),
    (re: 8.36547727223511984E-1; im: 5.47894059173100166E-1),
    (re: 8.36127251724692203E-1; im: 5.48535522025067398E-1),
    (re: 8.35706284353752580E-1; im: 5.49176662187719732E-1),
    (re: 8.35284825358337375E-1; im: 5.49817479283890930E-1),
    (re: 8.34862874986380056E-1; im: 5.50457972936604803E-1),
    (re: 8.34440433486103156E-1; im: 5.51098142769075438E-1),
    (re: 8.34017501106018125E-1; im: 5.51737988404707417E-1),
    (re: 8.33594078094925186E-1; im: 5.52377509467096036E-1),
    (re: 8.33170164701913186E-1; im: 5.53016705580027532E-1),
    (re: 8.32745761176359454E-1; im: 5.53655576367479300E-1),
    (re: 8.32320867767929649E-1; im: 5.54294121453620116E-1),
    (re: 8.31895484726577615E-1; im: 5.54932340462810357E-1),
    (re: 8.31469612302545237E-1; im: 5.55570233019602225E-1),
    (re: 8.31043250746362289E-1; im: 5.56207798748739962E-1),
    (re: 8.30616400308846289E-1; im: 5.56845037275160076E-1),
    (re: 8.30189061241102352E-1; im: 5.57481948223991561E-1),
    (re: 8.29761233794523042E-1; im: 5.58118531220556116E-1),
    (re: 8.29332918220788223E-1; im: 5.58754785890368363E-1),
    (re: 8.28904114771864912E-1; im: 5.59390711859136075E-1),
    (re: 8.28474823700007129E-1; im: 5.60026308752760387E-1),
    (re: 8.28045045257755752E-1; im: 5.60661576197336024E-1),
    (re: 8.27614779697938365E-1; im: 5.61296513819151514E-1),
    (re: 8.27184027273669112E-1; im: 5.61931121244689414E-1),
    (re: 8.26752788238348546E-1; im: 5.62565398100626525E-1),
    (re: 8.26321062845663480E-1; im: 5.63199344013834115E-1),
    (re: 8.25888851349586841E-1; im: 5.63832958611378137E-1),
    (re: 8.25456154004377514E-1; im: 5.64466241520519446E-1),
    (re: 8.25022971064580201E-1; im: 5.65099192368714026E-1),
    (re: 8.24589302785025264E-1; im: 5.65731810783613197E-1),
    (re: 8.24155149420828579E-1; im: 5.66364096393063848E-1),
    (re: 8.23720511227391385E-1; im: 5.66996048825108643E-1),
    (re: 8.23285388460400131E-1; im: 5.67627667707986248E-1),
    (re: 8.22849781375826332E-1; im: 5.68258952670131550E-1),
    (re: 8.22413690229926412E-1; im: 5.68889903340175868E-1),
    (re: 8.21977115279241556E-1; im: 5.69520519346947180E-1),
    (re: 8.21540056780597561E-1; im: 5.70150800319470337E-1),
    (re: 8.21102514991104679E-1; im: 5.70780745886967280E-1),
    (re: 8.20664490168157473E-1; im: 5.71410355678857264E-1),
    (re: 8.20225982569434661E-1; im: 5.72039629324757069E-1),
    (re: 8.19786992452898965E-1; im: 5.72668566454481221E-1),
    (re: 8.19347520076796961E-1; im: 5.73297166698042213E-1),
    (re: 8.18907565699658924E-1; im: 5.73925429685650715E-1),
    (re: 8.18467129580298679E-1; im: 5.74553355047715800E-1),
    (re: 8.18026211977813448E-1; im: 5.75180942414845155E-1),
    (re: 8.17584813151583697E-1; im: 5.75808191417845301E-1),
    (re: 8.17142933361272981E-1; im: 5.76435101687721810E-1),
    (re: 8.16700572866827798E-1; im: 5.77061672855679523E-1),
    (re: 8.16257731928477430E-1; im: 5.77687904553122766E-1),
    (re: 8.15814410806733789E-1; im: 5.78313796411655563E-1),
    (re: 8.15370609762391271E-1; im: 5.78939348063081862E-1),
    (re: 8.14926329056526596E-1; im: 5.79564559139405743E-1),
    (re: 8.14481568950498655E-1; im: 5.80189429272831637E-1),
    (re: 8.14036329705948362E-1; im: 5.80813958095764545E-1),
    (re: 8.13590611584798491E-1; im: 5.81438145240810251E-1),
    (re: 8.13144414849253530E-1; im: 5.82061990340775538E-1),
    (re: 8.12697739761799522E-1; im: 5.82685493028668408E-1),
    (re: 8.12250586585203913E-1; im: 5.83308652937698294E-1),
    (re: 8.11802955582515396E-1; im: 5.83931469701276277E-1),
    (re: 8.11354847017063757E-1; im: 5.84553942953015301E-1),
    (re: 8.10906261152459720E-1; im: 5.85176072326730389E-1),
    (re: 8.10457198252594792E-1; im: 5.85797857456438860E-1),
    (re: 8.10007658581641106E-1; im: 5.86419297976360543E-1),
    (re: 8.09557642404051268E-1; im: 5.87040393520917990E-1),
    (re: 8.09107149984558202E-1; im: 5.87661143724736694E-1),
    (re: 8.08656181588174992E-1; im: 5.88281548222645305E-1),
    (re: 8.08204737480194726E-1; im: 5.88901606649675840E-1),
    (re: 8.07752817926190341E-1; im: 5.89521318641063902E-1),
    (re: 8.07300423192014467E-1; im: 5.90140683832248893E-1),
    (re: 8.06847553543799272E-1; im: 5.90759701858874228E-1),
    (re: 8.06394209247956301E-1; im: 5.91378372356787553E-1),
    (re: 8.05940390571176324E-1; im: 5.91996694962040951E-1),
    (re: 8.05486097780429174E-1; im: 5.92614669310891165E-1),
    (re: 8.05031331142963598E-1; im: 5.93232295039799808E-1),
    (re: 8.04576090926307090E-1; im: 5.93849571785433576E-1),
    (re: 8.04120377398265741E-1; im: 5.94466499184664463E-1),
    (re: 8.03664190826924079E-1; im: 5.95083076874569975E-1),
    (re: 8.03207531480644910E-1; im: 5.95699304492433343E-1),
    (re: 8.02750399628069161E-1; im: 5.96315181675743737E-1),
    (re: 8.02292795538115725E-1; im: 5.96930708062196476E-1),
    (re: 8.01834719479981297E-1; im: 5.97545883289693246E-1),
    (re: 8.01376171723140219E-1; im: 5.98160706996342312E-1),
    (re: 8.00917152537344324E-1; im: 5.98775178820458726E-1),
    (re: 8.00457662192622772E-1; im: 5.99389298400564546E-1),
    (re: 7.99997700959281894E-1; im: 6.00003065375389045E-1),
    (re: 7.99537269107905034E-1; im: 6.00616479383868927E-1),
    (re: 7.99076366909352385E-1; im: 6.01229540065148533E-1),
    (re: 7.98614994634760838E-1; im: 6.01842247058580060E-1),
    (re: 7.98153152555543813E-1; im: 6.02454600003723770E-1),
    (re: 7.97690840943391108E-1; im: 6.03066598540348202E-1),
    (re: 7.97228060070268733E-1; im: 6.03678242308430385E-1),
    (re: 7.96764810208418751E-1; im: 6.04289530948156049E-1),
    (re: 7.96301091630359122E-1; im: 6.04900464099919836E-1),
    (re: 7.95836904608883536E-1; im: 6.05511041404325514E-1),
    (re: 7.95372249417061260E-1; im: 6.06121262502186186E-1),
    (re: 7.94907126328236972E-1; im: 6.06731127034524501E-1),
    (re: 7.94441535616030600E-1; im: 6.07340634642572869E-1),
    (re: 7.93975477554337165E-1; im: 6.07949784967773667E-1),
    (re: 7.93508952417326617E-1; im: 6.08558577651779453E-1),
    (re: 7.93041960479443674E-1; im: 6.09167012336453177E-1),
    (re: 7.92574502015407662E-1; im: 6.09775088663868389E-1),
    (re: 7.92106577300212352E-1; im: 6.10382806276309453E-1),
    (re: 7.91638186609125796E-1; im: 6.10990164816271754E-1),
    (re: 7.91169330217690172E-1; im: 6.11597163926461913E-1),
    (re: 7.90700008401721614E-1; im: 6.12203803249797991E-1),
    (re: 7.90230221437310055E-1; im: 6.12810082429409704E-1),
    (re: 7.89759969600819062E-1; im: 6.13416001108638632E-1),
    (re: 7.89289253168885675E-1; im: 6.14021558931038426E-1),
    (re: 7.88818072418420243E-1; im: 6.14626755540375021E-1),
    (re: 7.88346427626606262E-1; im: 6.15231590580626846E-1),
    (re: 7.87874319070900211E-1; im: 6.15836063695985028E-1),
    (re: 7.87401747029031390E-1; im: 6.16440174530853608E-1),
    (re: 7.86928711779001755E-1; im: 6.17043922729849746E-1),
    (re: 7.86455213599085758E-1; im: 6.17647307937803932E-1),
    (re: 7.85981252767830176E-1; im: 6.18250329799760195E-1),
    (re: 7.85506829564053957E-1; im: 6.18852987960976309E-1),
    (re: 7.85031944266848048E-1; im: 6.19455282066924005E-1),
    (re: 7.84556597155575233E-1; im: 6.20057211763289179E-1),
    (re: 7.84080788509869972E-1; im: 6.20658776695972098E-1),
    (re: 7.83604518609638232E-1; im: 6.21259976511087611E-1),
    (re: 7.83127787735057324E-1; im: 6.21860810854965358E-1),
    (re: 7.82650596166575738E-1; im: 6.22461279374149973E-1),
    (re: 7.82172944184912982E-1; im: 6.23061381715401297E-1),
    (re: 7.81694832071059407E-1; im: 6.23661117525694585E-1),
    (re: 7.81216260106276054E-1; im: 6.24260486452220710E-1),
    (re: 7.80737228572094478E-1; im: 6.24859488142386377E-1),
    (re: 7.80257737750316590E-1; im: 6.25458122243814323E-1),
    (re: 7.79777787923014485E-1; im: 6.26056388404343531E-1),
    (re: 7.79297379372530282E-1; im: 6.26654286272029431E-1),
    (re: 7.78816512381475953E-1; im: 6.27251815495144114E-1),
    (re: 7.78335187232733161E-1; im: 6.27848975722176531E-1),
    (re: 7.77853404209453088E-1; im: 6.28445766601832707E-1),
    (re: 7.77371163595056275E-1; im: 6.29042187783035943E-1),
    (re: 7.76888465673232450E-1; im: 6.29638238914927025E-1),
    (re: 7.76405310727940365E-1; im: 6.30233919646864430E-1),
    (re: 7.75921699043407625E-1; im: 6.30829229628424528E-1),
    (re: 7.75437630904130525E-1; im: 6.31424168509401798E-1),
    (re: 7.74953106594873878E-1; im: 6.32018735939809022E-1),
    (re: 7.74468126400670854E-1; im: 6.32612931569877500E-1),
    (re: 7.73982690606822804E-1; im: 6.33206755050057253E-1),
    (re: 7.73496799498899100E-1; im: 6.33800206031017227E-1),
    (re: 7.73010453362736961E-1; im: 6.34393284163645498E-1),
    (re: 7.72523652484441289E-1; im: 6.34985989099049483E-1),
    (re: 7.72036397150384498E-1; im: 6.35578320488556138E-1),
    (re: 7.71548687647206348E-1; im: 6.36170277983712168E-1),
    (re: 7.71060524261813773E-1; im: 6.36761861236284230E-1),
    (re: 7.70571907281380717E-1; im: 6.37353069898259139E-1),
    (re: 7.70082836993347959E-1; im: 6.37943903621844070E-1),
    (re: 7.69593313685422950E-1; im: 6.38534362059466767E-1),
    (re: 7.69103337645579639E-1; im: 6.39124444863775744E-1),
    (re: 7.68612909162058307E-1; im: 6.39714151687640489E-1),
    (re: 7.68122028523365395E-1; im: 6.40303482184151673E-1),
    (re: 7.67630696018273335E-1; im: 6.40892436006621347E-1),
    (re: 7.67138911935820381E-1; im: 6.41481012808583152E-1),
    (re: 7.66646676565310439E-1; im: 6.42069212243792520E-1),
    (re: 7.66153990196312894E-1; im: 6.42657033966226877E-1),
    (re: 7.65660853118662444E-1; im: 6.43244477630085850E-1),
    (re: 7.65167265622458926E-1; im: 6.43831542889791465E-1),
    (re: 7.64673227998067147E-1; im: 6.44418229399988356E-1),
    (re: 7.64178740536116713E-1; im: 6.45004536815543966E-1),
    (re: 7.63683803527501858E-1; im: 6.45590464791548746E-1),
    (re: 7.63188417263381272E-1; im: 6.46176012983316365E-1),
    (re: 7.62692582035177930E-1; im: 6.46761181046383908E-1),
    (re: 7.62196298134578924E-1; im: 6.47345968636512080E-1),
    (re: 7.61699565853535284E-1; im: 6.47930375409685408E-1),
    (re: 7.61202385484261814E-1; im: 6.48514401022112445E-1),
    (re: 7.60704757319236916E-1; im: 6.49098045130225970E-1),
    (re: 7.60206681651202417E-1; im: 6.49681307390683192E-1),
    (re: 7.59708158773163401E-1; im: 6.50264187460365949E-1),
    (re: 7.59209188978388033E-1; im: 6.50846684996380915E-1),
    (re: 7.58709772560407388E-1; im: 6.51428799656059797E-1),
    (re: 7.58209909813015276E-1; im: 6.52010531096959538E-1),
    (re: 7.57709601030268074E-1; im: 6.52591878976862521E-1),
    (re: 7.57208846506484548E-1; im: 6.53172842953776764E-1),
    (re: 7.56707646536245682E-1; im: 6.53753422685936129E-1),
    (re: 7.56206001414394507E-1; im: 6.54333617831800518E-1),
    (re: 7.55703911436035923E-1; im: 6.54913428050056074E-1),
    (re: 7.55201376896536528E-1; im: 6.55492852999615385E-1),
    (re: 7.54698398091524443E-1; im: 6.56071892339617682E-1),
    (re: 7.54194975316889142E-1; im: 6.56650545729429039E-1),
    (re: 7.53691108868781272E-1; im: 6.57228812828642576E-1),
    (re: 7.53186799043612482E-1; im: 6.57806693297078657E-1),
    (re: 7.52682046138055250E-1; im: 6.58384186794785091E-1),
    (re: 7.52176850449042705E-1; im: 6.58961292982037333E-1),
    (re: 7.51671212273768455E-1; im: 6.59538011519338681E-1),
    (re: 7.51165131909686411E-1; im: 6.60114342067420479E-1),
    (re: 7.50658609654510612E-1; im: 6.60690284287242313E-1),
    (re: 7.50151645806215051E-1; im: 6.61265837839992216E-1),
    (re: 7.49644240663033498E-1; im: 6.61841002387086860E-1),
    (re: 7.49136394523459326E-1; im: 6.62415777590171761E-1),
    (re: 7.48628107686245333E-1; im: 6.62990163111121477E-1),
    (re: 7.48119380450403572E-1; im: 6.63564158612039803E-1),
    (re: 7.47610213115205167E-1; im: 6.64137763755259976E-1),
    (re: 7.47100605980180144E-1; im: 6.64710978203344868E-1),
    (re: 7.46590559345117251E-1; im: 6.65283801619087188E-1),
    (re: 7.46080073510063780E-1; im: 6.65856233665509679E-1),
    (re: 7.45569148775325399E-1; im: 6.66428274005865317E-1),
    (re: 7.45057785441465962E-1; im: 6.66999922303637507E-1),
    (re: 7.44545983809307346E-1; im: 6.67571178222540284E-1),
    (re: 7.44033744179929264E-1; im: 6.68142041426518509E-1),
    (re: 7.43521066854669093E-1; im: 6.68712511579748067E-1),
    (re: 7.43007952135121694E-1; im: 6.69282588346636066E-1),
    (re: 7.42494400323139236E-1; im: 6.69852271391821030E-1),
    (re: 7.41980411720831019E-1; im: 6.70421560380173101E-1),
    (re: 7.41465986630563295E-1; im: 6.70990454976794236E-1),
    (re: 7.40951125354959091E-1; im: 6.71558954847018401E-1),
    (re: 7.40435828196898031E-1; im: 6.72127059656411768E-1),
    (re: 7.39920095459516155E-1; im: 6.72694769070772915E-1),
    (re: 7.39403927446205746E-1; im: 6.73262082756133021E-1),
    (re: 7.38887324460615148E-1; im: 6.73829000378756061E-1),
    (re: 7.38370286806648586E-1; im: 6.74395521605139004E-1),
    (re: 7.37852814788465992E-1; im: 6.74961646102012008E-1),
    (re: 7.37334908710482821E-1; im: 6.75527373536338618E-1),
    (re: 7.36816568877369875E-1; im: 6.76092703575315960E-1),
    (re: 7.36297795594053124E-1; im: 6.76657635886374938E-1),
    (re: 7.35778589165713524E-1; im: 6.77222170137180427E-1),
    (re: 7.35258949897786840E-1; im: 6.77786305995631474E-1),
    (re: 7.34738878095963465E-1; im: 6.78350043129861487E-1),
    (re: 7.34218374066188240E-1; im: 6.78913381208238434E-1),
    (re: 7.33697438114660276E-1; im: 6.79476319899365039E-1),
    (re: 7.33176070547832772E-1; im: 6.80038858872078972E-1),
    (re: 7.32654271672412835E-1; im: 6.80600997795453051E-1),
    (re: 7.32132041795361298E-1; im: 6.81162736338795428E-1),
    (re: 7.31609381223892544E-1; im: 6.81724074171649793E-1),
    (re: 7.31086290265474320E-1; im: 6.82285010963795561E-1),
    (re: 7.30562769227827561E-1; im: 6.82845546385248068E-1),
    (re: 7.30038818418926205E-1; im: 6.83405680106258769E-1),
    (re: 7.29514438146997013E-1; im: 6.83965411797315427E-1),
    (re: 7.28989628720519389E-1; im: 6.84524741129142310E-1),
    (re: 7.28464390448225196E-1; im: 6.85083667772700381E-1),
    (re: 7.27938723639098580E-1; im: 6.85642191399187498E-1),
    (re: 7.27412628602375778E-1; im: 6.86200311680038601E-1),
    (re: 7.26886105647544948E-1; im: 6.86758028286925908E-1),
    (re: 7.26359155084345977E-1; im: 6.87315340891759108E-1),
    (re: 7.25831777222770306E-1; im: 6.87872249166685556E-1),
    (re: 7.25303972373060742E-1; im: 6.88428752784090461E-1),
    (re: 7.24775740845711281E-1; im: 6.88984851416597083E-1),
    (re: 7.24247082951466921E-1; im: 6.89540544737066925E-1),
    (re: 7.23717999001323479E-1; im: 6.90095832418599922E-1),
    (re: 7.23188489306527413E-1; im: 6.90650714134534639E-1),
    (re: 7.22658554178575633E-1; im: 6.91205189558448459E-1),
    (re: 7.22128193929215321E-1; im: 6.91759258364157775E-1),
    (re: 7.21597408870443748E-1; im: 6.92312920225718184E-1),
    (re: 7.21066199314508089E-1; im: 6.92866174817424678E-1),
    (re: 7.20534565573905238E-1; im: 6.93419021813811834E-1),
    (re: 7.20002507961381629E-1; im: 6.93971460889654009E-1),
    (re: 7.19470026789933046E-1; im: 6.94523491719965528E-1),
    (re: 7.18937122372804444E-1; im: 6.95075113980000875E-1),
    (re: 7.18403795023489761E-1; im: 6.95626327345254888E-1),
    (re: 7.17870045055731736E-1; im: 6.96177131491462945E-1),
    (re: 7.17335872783521723E-1; im: 6.96727526094601158E-1),
    (re: 7.16801278521099508E-1; im: 6.97277510830886564E-1),
    (re: 7.16266262582953121E-1; im: 6.97827085376777311E-1),
    (re: 7.15730825283818654E-1; im: 6.98376249408972854E-1),
    (re: 7.15194966938680076E-1; im: 6.98925002604414141E-1),
    (re: 7.14658687862769044E-1; im: 6.99473344640283806E-1),
    (re: 7.14121988371564722E-1; im: 7.00021275194006357E-1),
    (re: 7.13584868780793593E-1; im: 7.00568793943248367E-1),
    (re: 7.13047329406429274E-1; im: 7.01115900565918661E-1),
    (re: 7.12509370564692328E-1; im: 7.01662594740168510E-1),
    (re: 7.11970992572050084E-1; im: 7.02208876144391815E-1),
    (re: 7.11432195745216442E-1; im: 7.02754744457225302E-1),
    (re: 7.10892980401151693E-1; im: 7.03300199357548707E-1),
    (re: 7.10353346857062334E-1; im: 7.03845240524484964E-1),
    (re: 7.09813295430400873E-1; im: 7.04389867637400397E-1),
    (re: 7.09272826438865651E-1; im: 7.04934080375904909E-1),
    (re: 7.08731940200400652E-1; im: 7.05477878419852166E-1),
    (re: 7.08190637033195313E-1; im: 7.06021261449339790E-1),
    (re: 7.07648917255684341E-1; im: 7.06564229144709545E-1)
  );
  {$ENDIF}

const
  SqrtHalf: Float = 0.70710678118654752440084436210484903;

  scalec2: Float = 0.5;
  scalec4: Float = 0.25;
  scalec8: Float = 0.125;
  scalec16: Float = 0.0625;
  scalec32: Float = 0.03125;
  scalec64: Float = 0.015625;
  scalec128: Float = 0.0078125;
  scalec256: Float = 0.00390625;
  scalec512: Float = 0.001953125;
  scalec1024: Float = 0.0009765625;
  scalec2048: Float = 0.00048828125;
  scalec4096: Float = 0.000244140625;
  scalec8192: Float = 0.0001220703125;

  procedure fft2      (a: PComplexArray);
  procedure fft4      (a: PComplexArray);
  procedure fft8      (a: PComplexArray);
  procedure fft16     (a: PComplexArray);
  procedure fft32     (a: PComplexArray);
  procedure fft64     (a: PComplexArray);
  procedure fft128    (a: PComplexArray);
  procedure fft256    (a: PComplexArray);
  procedure fft512    (a: PComplexArray);
  procedure fft1024   (a: PComplexArray);
  procedure fft2048   (a: PComplexArray);
  procedure fft4096   (a: PComplexArray);
  procedure fft8192   (a: PComplexArray);

  procedure ifft2     (a: PComplexArray);
  procedure ifft4     (a: PComplexArray);
  procedure ifft8     (a: PComplexArray);
  procedure ifft16    (a: PComplexArray);
  procedure ifft32    (a: PComplexArray);
  procedure ifft64    (a: PComplexArray);
  procedure ifft128   (a: PComplexArray);
  procedure ifft256   (a: PComplexArray);
  procedure ifft512   (a: PComplexArray);
  procedure ifft1024  (a: PComplexArray);
  procedure ifft2048  (a: PComplexArray);
  procedure ifft4096  (a: PComplexArray);
  procedure ifft8192  (a: PComplexArray);

  procedure scale2    (a: PComplexArray);
  procedure scale4    (a: PComplexArray);
  procedure scale8    (a: PComplexArray);
  procedure scale16   (a: PComplexArray);
  procedure scale32   (a: PComplexArray);
  procedure scale64   (a: PComplexArray);
  procedure scale128  (a: PComplexArray);
  procedure scale256  (a: PComplexArray);
  procedure scale512  (a: PComplexArray);
  procedure scale1024 (a: PComplexArray);
  procedure scale2048 (a: PComplexArray);
  procedure scale4096 (a: PComplexArray);
  procedure scale8192 (a: PComplexArray);

  procedure mul2      (a,b: PComplexArray);
  procedure mul4      (a,b: PComplexArray);
  procedure mul8      (a,b: PComplexArray);
  procedure mul16     (a,b: PComplexArray);
  procedure mul32     (a,b: PComplexArray);
  procedure mul64     (a,b: PComplexArray);
  procedure mul128    (a,b: PComplexArray);
  procedure mul256    (a,b: PComplexArray);
  procedure mul512    (a,b: PComplexArray);
  procedure mul1024   (a,b: PComplexArray);
  procedure mul2048   (a,b: PComplexArray);
  procedure mul4096   (a,b: PComplexArray);
  procedure mul8192   (a,b: PComplexArray);

implementation

procedure TRANSFORM(a0,a1,a2,a3: PComplex; wre,wim: Float);
var
  t1, t2, t3, t4, t5, t6: Float;
begin
  t5 := a0.re - a2.re;
  t6 := a0.im - a2.im;
  t4 := a1.re - a3.re;
  t3 := a1.im - a3.im;

  a0.re := a0.re + a2.re;
  a0.im := a0.im + a2.im;
  a1.im := a1.im + a3.im;
  a1.re := a1.re + a3.re;

  t1 := t5 - t3;
  t2 := t6 - t4;
  t5 := t5 + t3;
  t6 := t6 + t4;

  a2.re := (t1 * wre) - (t6 * wim);
  a3.im := (t2 * wre) - (t5 * wim);
  a2.im := (t6 * wre) + (t1 * wim);
  a3.re := (t5 * wre) + (t2 * wim);
end;

procedure TRANSFORMHALF(a0,a1,a2,a3: PComplex);
var
  t1, t2, t3, t4, t5: Float;
begin
  t5 := a0.re - a2.re;
  t3 := a0.im - a2.im;
  t1 := a1.re - a3.re;
  t4 := a1.im - a3.im;

  a0.re := a0.re + a2.re;
  a0.im := a0.im + a2.im;
  a1.re := a1.re + a3.re;
  a1.im := a1.im + a3.im;

  t2 := t3 + t1;
  t3 := t3 - t1;
  t1 := t5 - t4;
  t5 := t5 + t4;

  a3.re := (t5 + t3) * SqrtHalf;
  a3.im := (t3 - t5) * SqrtHalf;
  a2.re := (t1 - t2) * SqrtHalf;
  a2.im := (t2 + t1) * SqrtHalf;
end;

procedure TRANSFORMZERO(a0,a1,a2,a3: PComplex);
var
  t1, t2, t3, t4: Float;
begin
  t1 := a0.re - a2.re;
  t2 := a0.im - a2.im;
  t3 := a1.re - a3.re;
  t4 := a1.im - a3.im;

  a0.re := a0.re + a2.re;
  a0.im := a0.im + a2.im;
  a1.re := a1.re + a3.re;
  a1.im := a1.im + a3.im;

  a2.re := t1 - t4;
  a3.im := t2 - t3;
  a3.re := t1 + t4;
  a2.im := t2 + t3;
end;

procedure c2(a: PComplexArray);
var
  t1, t2, t3, t4: Float;
begin
  t1 := a^[0].re + a^[1].re;
  t2 := a^[0].im + a^[1].im;
  t3 := a^[0].re - a^[1].re;
  t4 := a^[0].im - a^[1].im;

  a^[0].re := t1;
  a^[0].im := t2;
  a^[1].re := t3;
  a^[1].im := t4;
end;

procedure c4(a: PComplexArray);
var
  t1, t2, t3, t4, t5, t6, t7, t8: Float;
begin
  t3 := a^[0].re + a^[2].re;
  t2 := a^[0].im - a^[2].im;
  t4 := a^[1].re + a^[3].re;
  t6 := a^[1].im + a^[3].im;
  t1 := a^[0].re - a^[2].re;
  t7 := a^[0].im + a^[2].im;
  t5 := a^[1].re - a^[3].re;
  t8 := a^[1].im - a^[3].im;

  a^[0].re := t3 + t4;
  a^[0].im := t7 + t6;
  a^[1].re := t3 - t4;
  a^[1].im := t7 - t6;
  a^[2].im := t2 + t5;
  a^[2].re := t1 - t8;
  a^[3].im := t2 - t5;
  a^[3].re := t1 + t8;
end;

procedure c8(a: PComplexArray);
var
  t1, t2, t3, t4, t5, t6: Float;
begin
  t1 := a^[0].re - a^[4].re;
  t2 := a^[0].im - a^[4].im;
  t3 := a^[2].re - a^[6].re;
  t4 := a^[2].im - a^[6].im;

  a^[0].re := a^[0].re + a^[4].re;
  a^[0].im := a^[0].im + a^[4].im;
  a^[2].re := a^[2].re + a^[6].re;
  a^[2].im := a^[2].im + a^[6].im;

  a^[4].re := t1 - t4;
  a^[4].im := t2 + t3;
  a^[6].re := t1 + t4;
  a^[6].im := t2 - t3;

  t3 := a^[1].re - a^[5].re;
  t4 := a^[1].im - a^[5].im;
  t5 := a^[3].re - a^[7].re;
  t6 := a^[3].im - a^[7].im;

  a^[1].re := a^[1].re + a^[5].re;
  a^[1].im := a^[1].im + a^[5].im;
  a^[3].re := a^[3].re + a^[7].re;
  a^[3].im := a^[3].im + a^[7].im;

  t1 := t3 - t6;
  t3 := t3 + t6;
  t2 := t4 - t5;
  t4 := t4 + t5;
  t6 := (t1 - t4) * SqrtHalf;
  t1 := (t1 + t4) * SqrtHalf;
  t5 := (t2 - t3) * SqrtHalf;
  t2 := (t2 + t3) * SqrtHalf;

  a^[5].re := a^[4].re - t6;
  a^[5].im := a^[4].im - t1;
  a^[4].re := a^[4].re + t6;
  a^[4].im := a^[4].im + t1;

  a^[7].re := a^[6].re - t2;
  a^[7].im := a^[6].im - t5;
  a^[6].re := a^[6].re + t2;
  a^[6].im := a^[6].im + t5;
  c4(a);
end;

procedure c16(a: PComplexArray);
begin
  TRANSFORMZERO(@a^[0],@a^[4],@a^[8],@a^[12]);
  TRANSFORM(@a^[1],@a^[5],@a^[9],@a^[13],d16[0].re,d16[0].im);
  TRANSFORMHALF(@a^[2],@a^[6],@a^[10],@a^[14]);
  TRANSFORM(@a^[3],@a^[7],@a^[11],@a^[15],d16[0].im,d16[0].re);
  c4(@a^[8]);
  c4(@a^[12]);
  c8(a);
end;

procedure cpass(a,w: PComplexArray; n: integer);
var
  k: integer;
  z: integer;
begin
  TRANSFORMZERO(@a^[0],@a^[2 * n],@a^[4 * n],@a^[6 * n]);
  k := 2 * n - 1;
  z := 0;
  while k > 0 do
  begin
    TRANSFORM(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z],w[z].re,w^[z].im);
    inc(z);
    dec(k);
  end;
end;

procedure c32(a: PComplexArray);
begin
  cpass(a,@d32,4);
  c8(@a^[16]);
  c8(@a^[24]);
  c16(a);
end;

procedure c64(a: PComplexArray);
begin
  cpass(a,@d64,8);
  c16(@a^[32]);
  c16(@a^[48]);
  c32(a);
end;

procedure c128(a: PComplexArray);
begin
  cpass(a,@d128,16);
  c32(@a^[64]);
  c32(@a^[96]);
  c64(a);
end;

procedure c256(a: PComplexArray);
begin
  cpass(a,@d256,32);
  c64(@a^[128]);
  c64(@a^[192]);
  c128(a);
end;

procedure c512(a: PComplexArray);
begin
  cpass(a,@d512,64);
  c128(@a^[384]);
  c128(@a^[256]);
  c256(a);
end;

procedure cpassbig(a,w: PComplexArray; n: integer);
var
  k: integer;
  z: integer;
begin
  TRANSFORMZERO(@a^[0],@a^[2 * n],@a^[4 * n],@a^[6 * n]);

  k := n - 1;

  z := 0;
  while k > 0 do
  begin
    TRANSFORM(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z],w[z].re,w^[z].im);
    inc(z);
    dec(k);
  end;

  TRANSFORMHALF(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z]);
  inc(z);
  k := n - 1;

  while k > 0 do
  begin
    TRANSFORM(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z],w[k - 1].im,w^[k - 1].re);
    inc(z);
    dec(k);
  end;
end;

procedure c1024(a: PComplexArray);
begin
  cpassbig(a,@d1024,128);
  c256(@a^[768]);
  c256(@a^[512]);
  c512(a);
end;

procedure c2048(a: PComplexArray);
begin
  cpassbig(a,@d2048,256);
  c512(@a^[1536]);
  c512(@a^[1024]);
  c1024(a);
end;

procedure c4096(a: PComplexArray);
begin
  cpassbig(a,@d4096,512);
  c1024(@a^[3072]);
  c1024(@a^[2048]);
  c2048(a);
end;

procedure c8192(a: PComplexArray);
begin
  cpassbig(a,@d8192,1024);
  c2048(@a^[6144]);
  c2048(@a^[4096]);
  c4096(a);
end;

procedure UNTRANSFORM(a0,a1,a2,a3: PComplex; wre,wim: Float);
var
  t1, t2, t3, t4, t5, t6: Float;
begin
  t1 := a2.re * wre;
  t3 := a2.im * wim;
  t5 := a3.re * wre;
  t2 := a2.im * wre;
  t4 := a2.re * wim;
  t6 := a3.im * wre;
  t1 := t1 + t3;
  t5 := t5 - a3.im * wim;
  t2 := t2 - t4;
  t6 := t6 + a3.re * wim;
  t3 := t5 + t1;
  t5 := t5 - t1;
  t4 := t2 - t6;
  t6 := t6 + t2;
  a2.im := a0.im - t6;
  a3.re := a1.re - t4;
  a2.re := a0.re - t3;
  a1.re := t4 + a1.re;
  a0.im := t6 + a0.im;
  a0.re := t3 + a0.re;
  a3.im := a1.im - t5;
  a1.im := t5 + a1.im;
end;

procedure UNTRANSFORMHALF(a0,a1,a2,a3: PComplex);
var
  t1, t2, t3, t4, t5, t6: Float;
begin
  t1 := (a2.re + a2.im) * sqrthalf;
  t2 := (a2.im - a2.re) * sqrthalf;
  t3 := (a3.re - a3.im) * sqrthalf;
  t4 := (a3.im + a3.re) * sqrthalf;
  t6 := t3 - t1;
  t5 := t2 - t4;
  t1 := t1 + t3;
  t2 := t2 + t4;
  a3.im := a1.im - t6;
  a1.im := t6 + a1.im;
  a3.re := a1.re - t5;
  a1.re := t5 + a1.re;
  a2.re := a0.re - t1;
  a0.re := t1 + a0.re;
  a2.im := a0.im - t2;
  a0.im := t2 + a0.im;
end;

procedure UNTRANSFORMZERO(a0,a1,a2,a3: PComplex);
var
  t1, t2, t3, t4: Float;
begin
  t1 := a2.re + a3.re;
  t2 := a2.im + a3.im;
  t3 := a2.im - a3.im;
  t4 := a3.re - a2.re;
  a2.re := a0.re - t1;
  a2.im := a0.im - t2;
  a3.re := a1.re - t3;
  a3.im := a1.im - t4;
  a0.re := a0.re + t1;
  a0.im := a0.im + t2;
  a1.re := a1.re + t3;
  a1.im := a1.im + t4;
end;

procedure u4(a: PComplexArray);
var
  t1, t2, t3, t4, t5, t6, t7, t8: Float;
begin
  t1 := a^[0].re + a^[1].re;
  t2 := a^[0].im + a^[1].im;
  t3 := a^[0].re - a^[1].re;
  t4 := a^[0].im - a^[1].im;
  t6 := a^[3].re + a^[2].re;
  t8 := a^[3].im + a^[2].im;
  t5 := a^[3].re - a^[2].re;
  t7 := a^[2].im - a^[3].im;


  a^[0].re := t1 + t6;
  a^[2].re := t1 - t6;
  a^[0].im := t2 + t8;
  a^[1].re := t3 + t7;
  a^[3].re := t3 - t7;
  a^[1].im := t4 + t5;
  a^[3].im := t4 - t5;
  a^[2].im := t2 - t8;
end;

procedure u8(a: PComplexArray);
var
  t1, t2, t3, t4, t5, t6: Float;
begin
  u4(a);

  t1 := a^[4].re + a^[5].re;
  t2 := a^[4].im + a^[5].im;
  t3 := a^[6].re + a^[7].re;
  t4 := a^[6].im + a^[7].im;

  a^[5].re := a^[4].re - a^[5].re;
  a^[5].im := a^[4].im - a^[5].im;
  a^[7].re := a^[6].re - a^[7].re;
  a^[7].im := a^[6].im - a^[7].im;

  t5 := t2 - t4;
  t6 := t3 - t1;
  t1 := t1 + t3;
  t2 := t2 + t4;

  a^[6].re := a^[2].re - t5;
  a^[6].im := a^[2].im - t6;
  a^[4].re := a^[0].re - t1;
  a^[4].im := a^[0].im - t2;
  a^[2].re := a^[2].re + t5;
  a^[2].im := a^[2].im + t6;
  a^[0].re := a^[0].re + t1;
  a^[0].im := a^[0].im + t2;

  t1 := (a[5].re + a^[5].im) * sqrthalf;
  t4 := (a[7].im + a^[7].re) * sqrthalf;
  t2 := (a[5].im - a^[5].re) * sqrthalf;
  t3 := (a[7].re - a^[7].im) * sqrthalf;

  t6 := t3 - t1;
  t1 := t1 + t3;
  t5 := t2 - t4;
  t2 := t2 + t4;

  a^[7].re := a^[3].re - t5;
  a^[7].im := a^[3].im - t6;
  a^[5].re := a^[1].re - t1;
  a^[5].im := a^[1].im - t2;
  a^[3].re := a^[3].re + t5;
  a^[3].im := a^[3].im + t6;
  a^[1].re := a^[1].re + t1;
  a^[1].im := a^[1].im + t2;
end;

procedure u16(a: PComplexArray);
begin
  u8(a);
  u4(@a^[8]);
  u4(@a^[12]);

  UNTRANSFORMZERO(@a^[0],@a^[4],@a^[8],@a^[12]);
  UNTRANSFORMHALF(@a^[2],@a^[6],@a^[10],@a^[14]);
  UNTRANSFORM(@a^[1],@a^[5],@a^[9],@a^[13],d16[0].re,d16[0].im);
  UNTRANSFORM(@a^[3],@a^[7],@a^[11],@a^[15],d16[0].im,d16[0].re);
end;

procedure upass(a,w: PComplexArray; n: integer);
var
  k: integer;
  z: integer;
begin
  UNTRANSFORMZERO(@a^[0],@a^[2 * n],@a^[4 * n],@a^[6 * n]);
  k := 2 * n - 1;
  z := 0;

  while k > 0 do
  begin
    UNTRANSFORM(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z],w^[z].re,w^[z].im);
    inc(z);
    dec(k);
  end;
end;

procedure u32(a: PComplexArray);
begin
  u16(a);
  u8(@a^[16]);
  u8(@a^[24]);
  upass(a,@d32,4);
end;

procedure u64(a: PComplexArray);
begin
  u32(a);
  u16(@a^[32]);
  u16(@a^[48]);
  upass(a,@d64,8);
end;

procedure u128(a: PComplexArray);
begin
  u64(a);
  u32(@a^[64]);
  u32(@a^[96]);
  upass(a,@d128,16);
end;

procedure u256(a: PComplexArray);
begin
  u128(a);
  u64(@a^[128]);
  u64(@a^[192]);
  upass(a,@d256,32);
end;

procedure u512(a: PComplexArray);
begin
  u256(a);
  u128(@a^[256]);
  u128(@a^[384]);
  upass(a,@d512,64);
end;

procedure upassbig(a,w: PComplexArray; n: integer);
var
  k: integer;
  z: integer;
begin
  UNTRANSFORMZERO(@a^[0],@a^[2 * n],@a^[4 * n],@a^[6 * n]);
  k := n - 1;

  z := 0;
  while k > 0 do
  begin
    UNTRANSFORM(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z],w^[z].re,w^[z].im);
    inc(z);
    dec(k);
  end;

  UNTRANSFORMHALF(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z]);
  inc(z);
  k := n - 1;

  while k > 0 do
  begin
    UNTRANSFORM(@a^[1 + z],@a^[2 * n + 1 + z],@a^[4 * n + 1 + z],@a^[6 * n + 1 + z],w^[k - 1].im,w^[k - 1].re);
    inc(z);
    dec(k);
  end;
end;

procedure u1024(a: PComplexArray);
begin
  u512(a);
  u256(@a^[512]);
  u256(@a^[768]);
  upassbig(a,@d1024,128);
end;

procedure u2048(a: PComplexArray);
begin
  u1024(a);
  u512(@a^[1024]);
  u512(@a^[1536]);
  upassbig(a,@d2048,256);
end;

procedure u4096(a: PComplexArray);
begin
  u2048(a);
  u1024(@a^[2048]);
  u1024(@a^[3072]);
  upassbig(a,@d4096,512);
end;

procedure u8192(a: PComplexArray);
begin
  u4096(a);
  u2048(@a^[4096]);
  u2048(@a^[6144]);
  upassbig(a,@d8192,1024);
end;


procedure fft2(a: PComplexArray);
begin
  c2(a);
end;

procedure fft4(a: PComplexArray);
begin
  c4(a);
end;

procedure fft8(a: PComplexArray);
begin
  c8(a);
end;

procedure fft16(a: PComplexArray);
begin
  c16(a);
end;

procedure fft32(a: PComplexArray);
begin
  c32(a);
end;

procedure fft64(a: PComplexArray);
begin
  c64(a);
end;

procedure fft128(a: PComplexArray);
begin
  c128(a);
end;

procedure fft256(a: PComplexArray);
begin
  c256(a);
end;

procedure fft512(a: PComplexArray);
begin
  c512(a);
end;

procedure fft1024(a: PComplexArray);
begin
  c1024(a);
end;

procedure fft2048(a: PComplexArray);
begin
  c2048(a);
end;

procedure fft4096(a: PComplexArray);
begin
  c4096(a);
end;

procedure fft8192(a: PComplexArray);
begin
  c8192(a);
end;

procedure ifft2(a: PComplexArray);
begin
  c2(a);
end;

procedure ifft4(a: PComplexArray);
begin
  u4(a);
end;

procedure ifft8(a: PComplexArray);
begin
  u8(a);
end;

procedure ifft16(a: PComplexArray);
begin
  u16(a);
end;

procedure ifft32(a: PComplexArray);
begin
  u32(a);
end;

procedure ifft64(a: PComplexArray);
begin
  u64(a);
end;

procedure ifft128(a: PComplexArray);
begin
  u128(a);
end;

procedure ifft256(a: PComplexArray);
begin
  u256(a);
end;

procedure ifft512(a: PComplexArray);
begin
  u512(a);
end;

procedure ifft1024(a: PComplexArray);
begin
  u1024(a);
end;

procedure ifft2048(a: PComplexArray);
begin
  u2048(a);
end;

procedure ifft4096(a: PComplexArray);
begin
  u4096(a);
end;

procedure ifft8192(a: PComplexArray);
begin
  u8192(a);
end;

procedure scalec(a: PComplexArray; n: integer; u: Float);
var
  i: integer;
begin
  for i := 0 to n -1 do
  begin
    a^[i].re := a^[i].re * u;
    a^[i].im := a^[i].im * u;
  end;
end;

procedure scale2(a: PComplexArray);
begin
  scalec(a,2,scalec2);
end;

procedure scale4(a: PComplexArray);
begin
  scalec(a,4,scalec4);
end;

procedure scale8(a: PComplexArray);
begin
  scalec(a,8,scalec8);
end;

procedure scale16(a: PComplexArray);
begin
  scalec(a,16,scalec16);
end;

procedure scale32(a: PComplexArray);
begin
  scalec(a,32,scalec32);
end;

procedure scale64(a: PComplexArray);
begin
  scalec(a,64,scalec64);
end;

procedure scale128(a: PComplexArray);
begin
  scalec(a,128,scalec128);
end;

procedure scale256(a: PComplexArray);
begin
  scalec(a,256,scalec256);
end;

procedure scale512(a: PComplexArray);
begin
  scalec(a,512,scalec512);
end;

procedure scale1024(a: PComplexArray);
begin
  scalec(a,1024,scalec1024);
end;

procedure scale2048(a: PComplexArray);
begin
  scalec(a,2048,scalec2048);
end;

procedure scale4096(a: PComplexArray);
begin
  scalec(a,4096,scalec4096);
end;

procedure scale8192(a: PComplexArray);
begin
  scalec(a,8192,scalec8192);
end;

procedure mulc(a,b: PComplexArray; n: integer);
var
  t1, t2, t3, t4: Float;
  z: integer;
begin
  z := 0;
  while (z < n) do
  begin
    t1 := (a^[z].re * b^[z].re) - (a^[z].im * b^[z].im);
    t2 := (a^[z].im * b^[z].re) + (a^[z].re * b^[z].im);
    t3 := (a^[z + 1].re * b^[z + 1].re) - (a^[z + 1].im * b^[z + 1].im);
    t4 := (a^[z + 1].im * b^[z + 1].re) + (a^[z + 1].re * b^[z + 1].im);
    a^[z].re := t1;
    a^[z + 1].re := t3;
    a^[z].im := t2;
    a^[z + 1].im := t4;
    inc(z,2);
  end;
end;

procedure mul2(a,b: PComplexArray);
begin
  mulc(a,b,2);
end;

procedure mul4(a,b: PComplexArray);
begin
  mulc(a,b,4);
end;

procedure mul8(a,b: PComplexArray);
begin
  mulc(a,b,8);
end;

procedure mul16(a,b: PComplexArray);
begin
  mulc(a,b,16);
end;

procedure mul32(a,b: PComplexArray);
begin
  mulc(a,b,32);
end;

procedure mul64(a,b: PComplexArray);
begin
  mulc(a,b,64);
end;

procedure mul128(a,b: PComplexArray);
begin
  mulc(a,b,128);
end;

procedure mul256(a,b: PComplexArray);
begin
  mulc(a,b,256);
end;

procedure mul512(a,b: PComplexArray);
begin
  mulc(a,b,512);
end;

procedure mul1024(a,b: PComplexArray);
begin
  mulc(a,b,1024);
end;

procedure mul2048(a,b: PComplexArray);
begin
  mulc(a,b,2048);
end;

procedure mul4096(a,b: PComplexArray);
begin
  mulc(a,b,4096);
end;

procedure mul8192(a,b: PComplexArray);
begin
  mulc(a,b,8192);
end;
{$IFDEF CALC_SINCOS_TABLE}
procedure InitSinCosTable;

  procedure SinCosTable(n: Integer; s: PComplexArray);
  var
    tmp: Extended;
    i: integer;
    m: integer;
    {$IFNDEF EXTENDED_PRECISION}
    fs,fc: Extended;
    {$ENDIF}
  begin
    if n > 512 then m := n shr 3
               else m := n shr 2;
    tmp := 2 * PI / n;
    for i := 1 to m -1 do
    begin
    {$IFDEF EXTENDED_PRECISION}
      SinCos(tmp * i,s^[i-1].im,s^[i-1].re);
    {$ELSE}
      SinCos(tmp * i,fs,fc);
      s^[i-1].re := fc;
      s^[i-1].im := fs;
    {$ENDIF}
    end;
  end;

begin
  SinCosTable(16,@d16);
  SinCosTable(32,@d32);
  SinCosTable(64,@d64);
  SinCosTable(128,@d128);
  SinCosTable(256,@d256);
  SinCosTable(512,@d512);
  SinCosTable(1024,@d1024);
  SinCosTable(2048,@d2048);
  SinCosTable(4096,@d4096);
  SinCosTable(8192,@d8192);
end;

{$ENDIF}

{$IFDEF CALC_REVBITS_TABLE}
procedure InitRevBitsTable;

  procedure CopyFromTo(pFrom, pTo: PWORDArray; x,z,m: PInteger);
  var
    i: integer;
  begin
    if x^ = 0 then x^ := 1 else x^ := 0;
    z^ := z^ shl 1 - x^;
    m^ := m^ shl 1;
    for i := 0 to (m^ shr 1 - 1) do
    begin
      pTo^[i]            := pFrom^[i] * 2;
      pTo^[i + m^ shr 1] := pFrom^[i] * 2;
    end;
    for i := z^ to (m^ - (m^ shr 1 - (z^ - 1))) do inc(pTo^[i]);
  end;

var
  i: integer;
  z: integer;
  x: integer;
  m: integer;
begin
  x := 1;
  z := 1;
  m := 2;
  for i := 0 to 1 do RevBits2[i] := i;
  CopyFromTo(@RevBits2,@RevBits4,@x,@z,@m);
  CopyFromTo(@RevBits4,@RevBits8,@x,@z,@m);
  CopyFromTo(@RevBits8,@RevBits16,@x,@z,@m);
  CopyFromTo(@RevBits16,@RevBits32,@x,@z,@m);
  CopyFromTo(@RevBits32,@RevBits64,@x,@z,@m);
  CopyFromTo(@RevBits64,@RevBits128,@x,@z,@m);
  CopyFromTo(@RevBits128,@RevBits256,@x,@z,@m);
  CopyFromTo(@RevBits256,@RevBits512,@x,@z,@m);
  CopyFromTo(@RevBits512,@RevBits1024,@x,@z,@m);
  CopyFromTo(@RevBits1024,@RevBits2048,@x,@z,@m);
  CopyFromTo(@RevBits2048,@RevBits4096,@x,@z,@m);
  CopyFromTo(@RevBits4096,@RevBits8192,@x,@z,@m);
end;
{$ENDIF}
initialization
  {$IFDEF CALC_REVBITS_TABLE} InitRevBitsTable; {$ENDIF}
  {$IFDEF CALC_SINCOS_TABLE}  InitSinCosTable; {$ENDIF}

end.

